create or replace package plzip as

/**
<config>
  <pck-name>PL/ZIP</pck-name>
  <pck-title>User's Guide</pck-title>
  <pck-version>v1.1.0</pck-version>
   <header-prc>plpdf_doc_xml.plpdf_header</header-prc>
  <header-size>10</header-size>
  <footer-prc>plpdf_doc_xml.plpdf_footer</footer-prc>
  <footer-size>10</footer-size>
</config>
*/

/**
<h1>Introdution</h1>
<br/>
<p>
  PL/ZIP is a PL/SQL package for creating ZIP files. The method consist of three easy steps, create new archive,
  add files and finally save the complete ZIP. TRIAL limitation is a Random message: It''s not error! Certification is TRIAL!
</p>
<br/>
<h2>Installation</h2>
<p>
System requirements: Oracle 10g RDBMS Release 2 or higher. Oracle 10g Express Edition is supported.
</p>
<br/>
*/

/**
<newpage/>
<h1>Procedures and Functions </h1>
<br/>
*/

/**
<name>GetVersion</name>
<type>function</type>
<desc>
Gets the version number of PL/ZIP package.
</desc>
<version>v1.0.0</version>
<params>-</params>
<return>
  <return-def>varchar2</return-def>
  <return-desc>number of current version</return-desc>
</return>
*/
function getVersion return varchar2;

/**
 <name>CertKeyCheck</name>
 <type>Function</type>
 <desc>
  Checks the certification key.<br/>
  Usage:<br/>
  declare                            <br/>
    l_ret boolean;                   <br/>
  begin                              <br/>
    l_ret := plzip.CertKeyCheck;     <br/>
    if l_ret then                    <br/>
      dbms_output.put_line('true');  <br/>
    else                             <br/>
      dbms_output.put_line('false'); <br/>
    end if;                          <br/>
  end;                               <br/>
 </desc>
 <version>v1.1.0</version>
 <params>-</params>
 <return>
  <return-def>boolean</return-def>
  <return-desc>validity of the key</return-desc>
 </return>
*/
function CertKeyCheck
  return boolean;

/**
<name>createNewZip</name>
<type>Procedure</type>
<desc>
  Initializes the package, creates a new zip archive.
</desc>
<version>v1.0.0</version>
<params>-</params>
<return>-</return>
*/
procedure createNewZip;

/**
<name>addFile</name>
<type>Procedure</type>
<desc>
  Adds a file to the ZIP archive. To place a file into a subdirectory inside the ZIP archive, set the full path as p_filename.
</desc>
<version>v1.0.0</version>
<params>
  <param>
   <param-def>p_filename varchar2</param-def>
   <param-desc>[<i>path/</i>]name of the file</param-desc>
  </param>
  <param>
   <param-def>p_file varchar2</param-def>
   <param-desc>file</param-desc>
  </param>
</params>
<return>-</return>
*/
procedure addFile(
  p_filename varchar2,
  p_file blob
  );

/**
<name>saveZip</name>
<type>Function</type>
<desc>
  Builds entries to ZIP file format.
</desc>
<version>v1.0.0</version>
<params>-</params>
<return>
  <return-def>blob</return-def>
  <return-desc>The ZIP archive</return-desc>
</return>
*/
function saveZip
  return blob;

end plzip;
/

create or replace package body plzip wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
b
9200000
1
4
0 
e3
2 :e:
1PACKAGE:
1BODY:
1PLZIP:
1G_VERSION:
1CONSTANT:
1VARCHAR2:
1CHAR:
15:
11.1.0:
1V_PAD_CHR:
11:
1~:
1V_CERT_KEY:
1100:
1V_CERT_OK:
1BOOLEAN:
1FALSE:
1V_CERT_ERR_MISSING:
1PLPDF_TYPE:
1V2AVG:
1Certification key is missing.:
1V_CERT_ERR_INVALID:
1Certification key is invalid. Please contact Support.:
1V_TRIAL_ERROR:
1255:
1Random message:: It's not error! Certification is TRIAL!:
1V_BLOB_FILE:
1BLOB:
1FUNCTION:
1GETVERSION:
1RETURN:
1RAISE_ERROR:
1P_MSG:
1RAISE_APPLICATION_ERROR:
1-:
120000:
1CR_ERROR:
1P_CODE:
1P_1:
1L_MSG:
1=:
1301:
1Stream error:: &1.:
1ELSIF:
1302:
1Buffer error:: &1.:
1303:
1Data error:: &1.:
1IS NOT NULL:
1REPLACE:
1&1:
1SUBSTR:
1ERR-:
1||:
1 :
1GETADDRSTRING:
1L_RET:
1UTL_INADDR:
1GET_HOST_ADDRESS:
1DBMS_STANDARD:
1DATABASE_NAME:
1DUAL:
1ROWNUM:
1<:
12:
1GETDBID:
1TO_CHAR:
1DBID:
1SYS:
1V_$DATABASE:
1CHECKKEY:
1P_KEY:
1P_CACTH:
1TRUE:
1L_STR:
1L_DATE:
1DATE:
1L_ADDR:
1L_RAW:
1RAW:
12048:
1L_CHECK_KEY:
1L_DEVLIC:
1UTL_RAW:
1CAST_TO_RAW:
1SQRT:
113:
13:
138:
1DBMS_OBFUSCATION_TOOLKIT:
1DESDECRYPT:
1INPUT:
1HEXTORAW:
1KEY:
1DECRYPTED_DATA:
1RTRIM:
1CAST_TO_VARCHAR2:
1TO_DATE:
120:
16:
1YYYYMMDD:
17:
1ASPASIA:
1COGNOTEC:
1ISDHR:
1PERFIT:
1DBVALLEY:
1QUINN:
1BERENBERG:
1MYTHICS:
1ELUCID:
1MCGILL:
1SOCHO:
1CAISO:
1DCDK12:
1NTUEDUSG:
1GWIC:
1OHIO:
1FORCES:
1PROMATA:
1SUMNEVA:
1FHG:
1SITE01:
1SITE02:
1SITE03:
1SITE04:
1SITE05:
1DEV01:
1DEV02:
1DEV03:
1DEV04:
1DEV05:
14:
1!=:
1TRUNC:
1SYSDATE:
1<=:
1OTHERS:
1RAISE:
1CERTKEYCHECK:
1PLPDF_CERT:
1SETCERTKEY:
1IS NULL:
1UPPER:
1TRIAL:
1P_PROC:
1ERROR:: proc:::
1,msg:: :
1CREATENEWZIP:
1DBMS_LOB:
1CREATETEMPORARY:
1LITTLE_ENDIAN:
1P_BIG:
1NUMBER:
1P_BYTES:
1PLS_INTEGER:
1L_BIG:
1>:
12147483647:
14294967296:
1CAST_FROM_BINARY_INTEGER:
1ADDFILE:
1P_FILENAME:
1P_FILE:
1L_NOW:
1L_BLOB:
1L_CLEN:
1INTEGER:
1UTL_COMPRESS:
1LZ_COMPRESS:
1GETLENGTH:
1APPEND:
1CONCAT:
1504B0304:
11400:
10000:
10800:
1TO_NUMBER:
1ss:
1/:
1+:
1mi:
1*:
132:
1hh24:
1dd:
1mm:
1yyyy:
11980:
1512:
118:
1LENGTH:
1COPY:
111:
1FREETEMPORARY:
1ADDPRECOMPRESSEDFILE:
1P_CRC32:
1P_OSIZE:
1CREATEPRECOMPRESSEDFILE:
1P_CFILE:
1OUT:
1NOCOPY:
1SAVEZIP:
1L_CNT:
10:
1L_OFFS:
1L_OFFS_DIR_HEADER:
1L_OFFS_END_HEADER:
1L_COMMENT:
132767:
1PL/PDF PL/ZIP:
1L_SS:
1NOT:
1SS:
1MOD:
110:
1INSTR:
1WHILE:
1LOOP:
1504B0102:
126:
10100:
12000B681:
1CAST_TO_BINARY_INTEGER:
130:
1504B0506:
1NVL:
0

0
0
5a8
2
0 :2 a0 97 87 :3 a0 51 a5 1c
6e 1b b0 a3 :2 a0 51 a5 1c
6e 81 b0 a3 :2 a0 51 a5 1c
81 b0 a3 a0 1c a0 81 b0
a3 :2 a0 6b 1c 6e 81 b0 a3
:2 a0 6b 1c 6e 81 b0 a3 :2 a0
51 a5 1c 6e 81 b0 a3 a0
1c 81 b0 a0 8d a0 b4 a0
2c 6a :2 a0 65 b7 a4 b1 11
68 4f 9a 8f a0 b0 3d b4
55 6a a0 7e 51 b4 2e a0
a5 57 b7 a4 b1 11 68 4f
9a 8f a0 b0 3d 8f a0 b0
3d b4 55 6a a3 :2 a0 51 a5
1c 81 b0 a0 7e 6e b4 2e
a0 6e d a0 b7 a0 7e 6e
b4 2e a0 6e d a0 b7 19
a0 7e 6e b4 2e a0 6e d
b7 :2 19 3c a0 7e b4 2e :3 a0
6e a0 a5 b d b7 19 3c
:2 a0 6e 7e a0 b4 2e 7e 6e
b4 2e 7e a0 b4 2e :2 51 a5
b d a0 7e 51 b4 2e a0
a5 57 b7 a4 b1 11 68 4f
a0 8d a0 b4 a0 2c 6a a3
:2 a0 6b 1c 81 b0 :2 a0 6b 7e
:2 a0 6b b4 2e ac :2 a0 b2 ee
a0 7e 51 b4 2e ac e5 d0
b2 e9 :2 a0 65 b7 a4 b1 11
68 4f a0 8d a0 b4 a0 2c
6a a3 :2 a0 6b 1c 81 b0 :2 a0
a5 b ac :3 a0 6b b2 ee a0
7e 51 b4 2e ac e5 d0 b2
e9 :2 a0 65 b7 a4 b1 11 68
4f a0 8d 8f a0 b0 3d 8f
:2 a0 b0 3d b4 :2 a0 2c 6a a3
a0 1c a0 81 b0 a3 :2 a0 6b
1c 81 b0 a3 a0 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c a0
81 b0 :3 a0 6b :3 a0 51 a5 b
a5 b :2 51 a5 b a5 b d
:2 a0 6b :3 a0 a5 b e :2 a0 e
:2 a0 e a5 57 :4 a0 6b a0 a5
b a0 a5 b d :2 a0 6e 7e
:2 a0 :2 51 a5 b b4 2e 6e a5
b d :3 a0 51 a5 b d a0
3e :1e 6e 5 48 :2 a0 d b7 19
3c :2 a0 :2 51 a5 b 7e 6e b4
2e :3 a0 a5 b a0 7e b4 2e
:2 a0 d b7 :2 a0 d b7 :2 19 3c
b7 :2 a0 7e b4 2e :2 a0 a5 b
a0 7e b4 2e a 10 :2 a0 d
b7 :2 a0 d b7 :2 19 3c b7 :2 19
3c b7 :2 a0 51 a5 b a0 7e
b4 2e :2 a0 a5 b a0 7e b4
2e a 10 :2 a0 d b7 :2 a0 d
b7 :2 19 3c b7 :2 19 3c b7 a0
53 :3 a0 d b7 a0 62 b7 :2 19
3c b7 a6 9 a4 b1 11 4f
:2 a0 65 b7 a4 b1 11 68 4f
a0 8d a0 b4 a0 2c 6a a3
a0 1c 81 b0 :2 a0 6b 7e b4
2e :2 a0 d a0 b7 :3 a0 6b a5
b 7e 6e b4 2e :2 a0 d b7
19 :4 a0 6b a0 a5 b d b7
:2 19 3c :2 a0 65 b7 a4 b1 11
68 4f 9a 8f a0 b0 3d 8f
a0 b0 3d b4 55 6a a0 7e
51 b4 2e 6e 7e a0 b4 2e
7e 6e b4 2e 7e a0 b4 2e
a5 57 b7 a4 b1 11 68 4f
9a b4 55 6a :2 a0 6b :2 a0 a5
57 b7 a4 b1 11 68 4f a0
8d 8f a0 b0 3d 8f a0 51
b0 3d b4 :2 a0 2c 6a a3 a0
1c 81 b0 :2 a0 d a0 7e 51
b4 2e :2 a0 7e 51 b4 2e d
b7 19 3c :3 a0 6b :2 a0 6b :3 a0
6b a5 b 51 a0 a5 b 65
b7 a4 b1 11 68 4f 9a 8f
a0 b0 3d 8f a0 b0 3d b4
55 6a a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 :2 a0 d :3 a0 6b a0 a5 b
d :3 a0 6b a0 a5 b d :2 a0
6b :3 a0 6b a0 6e a5 b a0
6e a5 b a0 6e a5 b a0
6e a5 b :4 a0 6e a5 b a5
b 7e 51 b4 2e 7e :3 a0 6e
a5 b a5 b 7e 51 b4 2e
b4 2e 7e :3 a0 6e a5 b a5
b 7e 51 b4 2e b4 2e 51
a5 b :4 a0 6e a5 b a5 b
7e :3 a0 6e a5 b a5 b 7e
51 b4 2e b4 2e 7e :3 a0 6e
a5 b a5 b 7e 51 b4 2e
5a 7e 51 b4 2e b4 2e 51
a5 b :2 a0 6b a0 51 a0 7e
51 b4 2e a5 b :2 a0 7e 51
b4 2e a5 b :3 a0 6b a0 a5
b a5 b :3 a0 a5 b 51 a5
b a0 6e a5 b :2 a0 6b a0
a5 b a5 b a5 57 :2 a0 6b
:3 a0 7e 51 b4 2e :2 a0 6b a0
a5 b 7e 51 b4 2e 51 a5
57 :2 a0 6b a0 a5 57 b7 a4
b1 11 68 4f 9a 8f a0 b0
3d 8f a0 b0 3d 8f a0 b0
3d 8f a0 b0 3d b4 55 6a
4f b7 a4 b1 11 68 4f 9a
8f a0 b0 3d 96 :3 a0 b0 54
96 :3 a0 b0 54 96 :3 a0 b0 54
b4 55 6a 4f b7 a4 b1 11
68 4f a0 8d a0 b4 a0 2c
6a a3 a0 1c 51 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
51 a5 1c :2 a0 6b 6e a5 b
81 b0 a3 a0 1c 81 b0 :3 a0
6b d a0 7e b4 2e :2 a0 a5
b 7e 6e b4 2e :2 a0 d b7
:3 a0 a5 b d b7 :2 19 3c b7
:2 a0 a5 57 b7 :2 19 3c a0 5a
7e b4 2e :2 a0 a5 57 b7 19
3c :2 a0 a5 b 7e 6e b4 2e
:4 a0 6e a5 b a5 b d :2 a0
51 7e a5 2e 7e 51 b4 2e
:2 a0 a5 57 b7 19 3c b7 19
3c :3 a0 6b a0 a5 b d :3 a0
6b :2 a0 6e a5 b 51 a5 b
d :2 a0 7e 51 a0 b4 2e 82
:2 a0 7e 51 b4 2e d :2 a0 6b
:3 a0 6b a0 6e a5 b a0 6e
a5 b :2 a0 6b a0 51 a0 7e
51 b4 2e a5 b a0 6e a5
b a0 6e a5 b a0 6e a5
b a0 6e a5 b :2 a0 7e 51
b4 2e a5 b :2 a0 6b :3 a0 6b
:2 a0 6b a0 51 a0 7e 51 b4
2e a5 b :2 a0 6b a5 b a0
7e 51 b4 2e a5 b a5 b
a5 57 :3 a0 6b :2 a0 6e a5 b
a0 7e 51 b4 2e a5 b d
b7 a0 47 :3 a0 6b a0 a5 b
d :2 a0 6b :3 a0 6b a0 6e a5
b a0 6e a5 b a0 6e a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 7e a0 b4 2e a5 b
:2 a0 a5 b :4 a0 6b a0 a5 b
51 a5 b 51 a5 b a0 a5
b a5 57 :2 a0 65 b7 a4 b1
11 68 4f b1 b7 a4 11 a0
b1 56 4f 1d 17 b5 
5a8
2
0 3 7 b 3a 19 1d 21
25 28 29 31 36 18 60 45
49 15 4d 4e 56 5b 44 81
6b 6f 41 73 74 7c 6a a1
8c 90 98 9c 67 c5 a8 ac
b0 b3 bb c0 8b ea d0 d4
88 d8 e0 e5 cf 110 f5 f9
cc fd fe 106 10b f4 12c 11b
11f 127 f1 117 133 147 14b 14c
150 154 158 15c 160 164 166 16a
16c 178 17c 17e 19a 196 195 1a2
192 1a7 1ab 1af 1b3 1b6 1b9 1ba
1bf 1c3 1c4 1c9 1cb 1cf 1d1 1dd
1e1 1e3 1ff 1fb 1fa 207 214 210
1f7 21c 20f 221 225 243 22d 231
20c 235 236 23e 22c 24a 229 24e
253 254 259 25d 262 266 26a 26c
270 273 278 279 27e 282 287 28b
28f 291 295 299 29c 2a1 2a2 2a7
2ab 2b0 2b4 2b6 2ba 2be 2c1 2c5
2c8 2c9 2ce 2d2 2d6 2da 2df 2e3
2e4 2e6 2ea 2ec 2f0 2f3 2f7 2fb
300 303 307 308 30d 310 315 316
31b 31e 322 323 328 32b 32e 32f
331 335 339 33c 33f 340 345 349
34a 34f 351 355 357 363 367 369
36d 381 385 386 38a 38e 3ae 396
39a 39e 3a1 3a9 395 3b5 3b9 392
3bd 3c0 3c4 3c8 3cb 3cc 3d1 3d2
3d6 3da 3db 3e2 3e6 3e9 3ec 3ed
3f2 3f3 3f9 3fd 3fe 403 407 40b
40f 411 415 417 423 427 429 42d
441 445 446 44a 44e 46e 456 45a
45e 461 469 455 475 479 452 47d
47f 480 484 488 48c 48f 490 497
49b 49e 4a1 4a2 4a7 4a8 4ae 4b2
4b3 4b8 4bc 4c0 4c4 4c6 4ca 4cc
4d8 4dc 4de 4e2 4fe 4fa 4f9 506
517 50f 513 4f6 51f 50e 524 528
52c 530 54d 538 53c 544 548 50b
56c 554 558 55c 55f 567 537 588
577 57b 583 534 5a7 58f 593 597
59a 5a2 576 5c4 5b2 573 5b6 5b7
5bf 5b1 5e1 5cf 5ae 5d3 5d4 5dc
5ce 601 5ec 5f0 5f8 5fc 5cb 5e8
608 60c 610 613 617 61b 61f 622
623 625 626 628 62b 62e 62f 631
632 634 638 63c 640 643 647 64b
64f 650 652 654 658 65c 65e 662
666 668 669 66e 672 676 67a 67e
681 685 686 688 68c 68d 68f 693
697 69b 6a0 6a3 6a7 6ab 6ae 6b1
6b2 6b4 6b5 6ba 6bf 6c0 6c2 6c6
6ca 6ce 6d2 6d5 6d6 6d8 6dc 1
6e0 6e5 6ea 6ef 6f4 6f9 6fe 703
708 70d 712 717 71c 721 726 72b
730 735 73a 73f 744 749 74e 753
758 75d 762 767 76c 771 776 77a
77d 781 785 789 78b 78f 792 796
79a 79d 7a0 7a1 7a3 7a6 7ab 7ac
7b1 7b5 7b9 7bd 7be 7c0 7c4 7c7
7c8 7cd 7d1 7d5 7d9 7db 7df 7e3
7e7 7e9 7ed 7f1 7f4 7f6 7fa 7fe
801 802 807 80b 80f 810 812 816
819 81a 1 81f 824 828 82c 830
832 836 83a 83e 840 844 848 84b
84d 851 855 858 85a 85e 862 865
866 868 86c 86f 870 875 879 87d
87e 880 884 887 888 1 88d 892
896 89a 89e 8a0 8a4 8a8 8ac 8ae
8b2 8b6 8b9 8bb 8bf 8c3 8c6 8c8
1 8cc 8d0 8d4 8d8 8dc 8de 8e2
8e5 8e7 8eb 8ef 8f2 8f4 8f5 8fa
8fe 900 90c 90e 912 916 91a 91c
920 922 92e 932 934 938 94c 950
951 955 959 972 961 965 96d 960
979 97d 95d 981 984 985 98a 98e
992 996 99a 99c 9a0 9a4 9a8 9ab
9ac 9ae 9b1 9b6 9b7 9bc 9c0 9c4
9c8 9ca 9ce 9d2 9d6 9da 9de 9e1
9e5 9e6 9e8 9ec 9ee 9f2 9f6 9f9
9fd a01 a05 a07 a0b a0d a19 a1d
a1f a3b a37 a36 a43 a50 a4c a33
a58 a4b a5d a61 a65 a48 a69 a6c
a6d a72 a77 a7a a7e a7f a84 a87
a8c a8d a92 a95 a99 a9a a9f aa0
aa5 aa7 aab aad ab9 abd abf ad3
ad4 ad8 adc ae0 ae4 ae7 aeb aef
af0 af5 af7 afb afd b09 b0d b0f
b13 b2f b2b b2a b37 b44 b40 b27
b3f b4c b3c b51 b55 b59 b5d b76
b65 b69 b71 b64 b7d b81 b85 b89
b61 b8d b90 b91 b96 b9a b9e ba1
ba4 ba5 baa bae bb0 bb4 bb7 bbb
bbf bc3 bc6 bca bce bd1 bd5 bd9
bdd be0 be1 be3 be6 bea beb bed
bf1 bf3 bf7 bf9 c05 c09 c0b c27
c23 c22 c2f c3c c38 c1f c44 c37
c49 c4d c66 c55 c59 c61 c34 c7e
c6d c71 c79 c54 c9a c89 c8d c95
c51 c85 ca1 ca5 ca9 cad cb1 cb5
cb8 cbc cbd cbf cc3 cc7 ccb ccf
cd2 cd6 cd7 cd9 cdd ce1 ce5 ce8
cec cf0 cf4 cf7 cfb d00 d01 d03
d07 d0c d0d d0f d13 d18 d19 d1b
d1f d24 d25 d27 d2b d2f d33 d37
d3c d3d d3f d40 d42 d45 d48 d49
d4e d51 d55 d59 d5d d62 d63 d65
d66 d68 d6b d6e d6f d74 d75 d7a
d7d d81 d85 d89 d8e d8f d91 d92
d94 d97 d9a d9b da0 da1 da6 da9
daa dac db0 db4 db8 dbc dc1 dc2
dc4 dc5 dc7 dca dce dd2 dd6 ddb
ddc dde ddf de1 de4 de7 de8 ded
dee df3 df6 dfa dfe e02 e07 e08
e0a e0b e0d e10 e13 e14 e19 e1c
e1f e22 e23 e28 e29 e2e e31 e32
e34 e38 e3c e3f e43 e46 e4a e4d
e50 e51 e56 e57 e59 e5d e61 e64
e67 e68 e6d e6e e70 e74 e78 e7c
e7f e83 e84 e86 e87 e89 e8d e91
e95 e96 e98 e9b e9c e9e ea2 ea7
ea8 eaa eae eb2 eb5 eb9 eba ebc
ebd ebf ec0 ec5 ec9 ecd ed0 ed4
ed8 edc edf ee2 ee3 ee8 eec ef0
ef3 ef7 ef8 efa efd f00 f01 f06
f09 f0a f0f f13 f17 f1a f1e f1f
f24 f26 f2a f2c f38 f3c f3e f5a
f56 f55 f62 f6f f6b f52 f77 f80
f7c f6a f88 f95 f91 f67 f9d f90
fa2 fa6 f8d faa fac fb0 fb2 fbe
fc2 fc4 fe0 fdc fdb fe8 ffd ff1
ff5 ff9 fd8 1004 1015 1009 100d 1011
ff0 101c 1031 1025 1029 102d fed 1038
1024 103d 1041 1021 1045 1047 104b 104d
1059 105d 105f 1063 1077 107b 107c 1080
1084 10a0 108c 1090 1098 109b 108b 10bc
10ab 10af 10b7 1088 10d4 10c3 10c7 10cf
10aa 10f0 10df 10e3 10eb 10a7 111f 10f7
10fb 10fe 10ff 1107 110b 110f 1112 1117
1118 111a 10de 113b 112a 112e 1136 10db
1126 1142 1146 114a 114d 1151 1155 1158
1159 115e 1162 1166 1167 1169 116c 1171
1172 1177 117b 117f 1183 1185 1189 118d
1191 1192 1194 1198 119a 119e 11a2 11a5
11a7 11ab 11af 11b0 11b5 11b7 11bb 11bf
11c2 11c6 11c9 11cc 11cd 11d2 11d6 11da
11db 11e0 11e2 11e6 11e9 11ed 11f1 11f2
11f4 11f7 11fc 11fd 1202 1206 120a 120e
1212 1217 1218 121a 121b 121d 1221 1225
1229 122c 122f 1230 1235 1238 123b 123c
1241 1245 1249 124a 124f 1251 1255 1258
125a 125e 1261 1265 1269 126d 1270 1274
1275 1277 127b 127f 1283 1287 128a 128e
1292 1297 1298 129a 129d 129e 12a0 12a4
12a8 12ac 12af 12b2 12b6 12b7 12bc 12be
12c2 12c6 12c9 12cc 12cd 12d2 12d6 12da
12de 12e1 12e5 12e9 12ed 12f0 12f4 12f9
12fa 12fc 1300 1305 1306 1308 130c 1310
1313 1317 131a 131e 1321 1324 1325 132a
132b 132d 1331 1336 1337 1339 133d 1342
1343 1345 1349 134e 134f 1351 1355 135a
135b 135d 1361 1365 1368 136b 136c 1371
1372 1374 1378 137c 137f 1383 1387 138b
138e 1392 1396 1399 139d 13a0 13a4 13a7
13aa 13ab 13b0 13b1 13b3 13b7 13bb 13be
13bf 13c1 13c5 13c8 13cb 13cc 13d1 13d2
13d4 13d5 13d7 13d8 13dd 13e1 13e5 13e9
13ec 13f0 13f4 13f9 13fa 13fc 1400 1403
1406 1407 140c 140d 140f 1413 1415 1419
1420 1424 1428 142c 142f 1433 1434 1436
143a 143e 1442 1445 1449 144d 1451 1454
1458 145d 145e 1460 1464 1469 146a 146c
1470 1475 1476 1478 147c 1480 1483 1484
1486 148a 148e 1491 1492 1494 1498 149c
149f 14a3 14a4 14a9 14aa 14ac 14b0 14b4
14b5 14b7 14bb 14bf 14c3 14c7 14ca 14ce
14cf 14d1 14d4 14d5 14d7 14da 14db 14dd
14e1 14e2 14e4 14e5 14ea 14ee 14f2 14f6
14f8 14fc 14fe 150a 150e 1510 1512 1514
1518 1524 1528 152a 152d 152f 1530 1539 
5a8
2
0 1 9 e 1 b 14 1f
:2 1c 14 28 b 1 3 11 1c
:2 19 11 25 11 :2 3 e 1b :2 16
:2 e :2 3 :2 d 18 d :2 3 16 21
:2 16 2a 16 :2 3 16 21 :2 16 2b
16 :2 3 11 1e :2 19 11 27 11
:2 3 :3 f 3 2 b 5 0 c
:2 2 5 c 5 :2 3 :4 2 b 3
9 :2 3 16 :2 1 3 1b 1c :2 1b
22 :2 3 :6 1 b 3 a :3 3 7
:2 3 13 :2 1 3 9 16 :2 11 :2 9
3 6 d f :2 d 5 e 5
3 15 9 10 12 :2 10 5 e
5 3 18 15 9 10 12 :2 10
5 e 5 18 15 :2 3 :4 6 5
e 16 1c 21 :2 e 5 16 :3 3
b 12 19 1c :2 12 23 26 :2 12
2a 2d :2 12 33 35 :2 b :2 3 1b
1c :2 1b 22 :2 3 :7 1 a 3 0
a :2 1 3 9 14 :3 9 3 a
:2 15 26 29 :2 37 :4 a 8 3 8
9 10 12 :2 10 :6 3 a 3 :7 1
a 3 0 a :2 1 3 9 14
:3 9 3 a 12 :4 a 8 c 8
3 8 9 10 12 :2 10 :6 3 a
3 :7 1 a 3 9 :3 3 b 1b
:2 3 12 5 c :2 1 3 :2 9 14
9 :2 3 9 14 :3 9 :2 3 :3 a :2 3
a 15 :3 a :2 3 9 d c :2 9
:2 3 11 15 14 :2 11 :2 3 :2 c 17
c 3 5 14 :2 1c 28 2f 37
3c :2 37 :2 2f 41 43 :2 28 :2 14 :2 5
:2 1e 7 10 19 :2 10 :2 7 e :2 7
19 7 :2 5 3 c 12 :2 1a 2b
:2 12 32 :2 c :2 3 d 15 1a 1d
24 2a 2c :2 1d :2 15 2f :2 d :2 3
d 14 1a :2 d 3 :2 7 13 1e
2a 12 1b 26 2e 12 1c :2 12
1a 22 12 1d 24 2b 34 3e
:2 12 1b 24 2d 36 12 1a 22
2a 32 :2 7 5 11 5 15 :2 4
6 d 14 16 :2 6 19 1c :2 19
8 a 10 :2 a 1c :3 19 9 12
9 23 9 12 9 :4 7 11 a
13 :3 11 25 2b :2 25 37 :3 34 :2 a
9 12 9 3e 9 12 9 :4 7
:4 5 23 8 f 16 :2 8 1b :3 19
27 2d :2 27 39 :3 36 :2 8 7 10
7 40 7 10 7 :5 5 :4 3 :2 a
8 5 e 5 10 :2 7 :4 5 11
:2 5 3 :3 1 3 a 3 :7 1 a
3 0 a :2 1 3 :3 9 3 6
:2 11 :3 6 5 e 5 3 24 9
f :2 1a :2 9 26 28 :2 26 5 e
5 30 24 5 e 17 :2 22 2d
:2 e 5 :5 3 a 3 :6 1 b 17
1e :2 17 28 2e :2 28 16 :2 1 5
1d 1e :2 1d 25 34 37 :2 25 3e
41 :2 25 4a 4d :2 25 :2 5 :2 3 :4 1
b 0 :2 1 3 :2 c 1c 29 :2 3
:7 1 a 3 9 :3 3 b 1a :2 3
17 5 c :2 1 3 :3 9 :2 3 c
3 6 c e :2 c 5 e 14
16 :2 e 5 19 :3 3 a :2 12 19
:2 21 3a 40 :2 48 :2 19 57 59 :2 a
3 :6 1 b 3 e :3 3 a :2 3
12 :2 1 3 :3 a :2 3 :3 a :2 3 :3 a
:2 3 d :2 3 d :2 1a 26 :2 d :2 3
d :2 16 20 :2 d :2 3 :2 c :2 13 :2 1b
22 2b :2 22 37 40 :2 37 48 51
:2 48 59 62 :2 59 22 30 3a 42
49 :2 3a :2 30 50 52 :2 30 54 30
3a 42 49 :2 3a :2 30 50 52 :4 30
55 30 3a 42 48 :2 3a :2 30 51
53 :4 30 58 :3 22 30 3a 42 49
:2 3a :2 30 50 30 3a 42 49 :2 3a
:2 30 50 52 :4 30 55 31 3b 43
49 :2 3b :2 31 52 54 :2 31 30 5a
5c :4 30 60 :3 22 :2 2b 32 3a 3d
44 46 :2 3d :2 22 24 32 39 3b
:2 32 :3 24 32 :2 3b 45 :2 32 :3 24 32
39 :2 32 46 :3 24 2d :3 24 :2 2c 38
:2 24 :2 13 :3 3 :2 c :3 11 18 1a :3 11
:2 1a 24 :2 11 31 33 :3 11 :3 3 :2 c
1a :2 3 :6 1 b 3 e :3 3 a
:3 3 b :3 3 b :2 3 1f :2 1 3
:6 1 b 3 d :3 3 b f 16
:3 3 b f 16 :3 3 b f 16
:2 3 22 :2 1 3 :7 1 a 3 0
a :2 1 3 :2 15 24 15 :2 3 :3 15
:2 3 :3 15 :2 3 :3 15 :2 3 15 19 18
15 23 :2 2b 37 :2 23 15 :2 3 :3 8
:2 3 11 :2 1c 3 :4 6 8 e :2 8
1a 1c :2 1a 7 14 7 24 7
14 1d :2 14 7 :4 5 1d 5 11
:2 5 :4 3 a 9 :3 6 5 11 :2 5
15 :2 3 6 c :2 6 18 1a :2 18
3 b 15 1d 25 :2 15 :2 b 3
8 c 11 :3 8 15 17 :2 15 8
14 :2 8 19 :2 5 22 :3 3 18 :2 21
2b :2 18 :2 3 18 :2 21 27 33 3c
:2 33 48 :2 18 :2 3 9 10 12 14
:2 10 3 5 e 14 16 :2 e :2 5
:2 e :2 15 :2 1d 24 2d :3 24 2d :3 24
:2 2d 34 40 43 4a 4c :2 43 :3 24
2d :3 24 2d :3 24 2d :3 24 2d :3 24
32 39 3b :2 32 :3 24 :2 2d :2 34 :2 3c
34 :2 3d 44 50 52 59 5b :2 52
:2 34 5f :2 67 :3 34 3b 3d :2 34 :2 24
:2 15 :3 5 f :2 18 1e 2a 33 :2 2a
3f 46 48 :2 3f :2 f 5 14 7
:2 3 18 :2 21 2b :2 18 3 5 :2 e
:2 15 :2 1d 24 2d :3 24 2d :3 24 2d
:3 24 32 39 :3 24 32 39 :3 24 32
44 46 :2 32 :3 24 32 :3 24 32 36
:2 3e 45 :2 36 50 :2 32 53 :3 24 :2 15
:2 5 3 a 3 :6 1 :4 2 5 :6 1

5a8
4
0 :3 1 :a 3 :9 7
:8 8 :6 9 :8 b :8 c
:9 d :5 f :2 11 12
0 12 :2 11 :3 14
:2 13 :4 11 17 :4 18
:3 17 :8 1c :2 1a :4 17
1f :4 20 :4 21 :3 1f
:8 24 :5 26 :3 27 28
26 :5 28 :3 29 2a
28 26 :5 2a :3 2b
2a :3 26 :4 2d :8 2e
:3 2d :14 30 :8 32 :2 25
:4 1f :2 36 37 0
37 :2 36 :7 38 :a 3a
3b :3 3c :5 3d 3c
:4 3a :3 3f :2 39 :4 36
:2 42 43 0 43
:2 42 :7 44 :5 46 47
:5 48 :5 49 48 :4 46
:3 4b :2 45 :4 42 :2 4e
:4 4f :5 50 4e :2 51
:2 4e :6 52 :7 53 :5 54
:7 55 :7 56 :7 57 :6 58
:13 5b :3 5c :6 5d :3 5e
:3 5f :2 5c :c 60 :10 61
:7 62 :5 64 :4 65 :2 66
67 :3 68 :6 69 6a
:5 6b :5 6c :2 64 :3 6e
6d :2 64 :a 71 72
:8 73 :3 74 73 :3 76
75 :3 73 72 :f 79
:3 7a 79 :3 7c 7b
:3 79 78 :3 72 71
:13 80 :3 81 80 :3 83
82 :3 80 7f :3 71
5a :2 87 88 :3 89
88 :2 8b 8a :3 88
:3 87 86 :3 59 :3 8f
:2 59 :4 4e :2 92 93
0 93 :2 92 :5 94
:6 96 :3 97 98 96
:a 98 :3 99 98 96
:9 9b 9a :3 96 :3 9d
:2 95 :4 92 :c a0 :14 a2
:2 a1 :4 a0 a5 0
:2 a5 :7 a8 :2 a7 :4 a5
:2 ab :4 ac :5 ad ab
:2 ae :2 ab :5 af :3 b1
:5 b2 :7 b3 :3 b2 :12 b5
:2 b0 :4 ab b8 :4 b9
:4 ba :3 b8 :5 bc :5 bd
:5 be :3 c0 :8 c1 :8 c2
:4 c3 :13 c4 :e c5 :c c6
:2 c5 c6 :c c7 :2 c5
c7 :2 c5 :a c8 :c c9
:2 c8 c9 :11 ca :2 c8
ca :2 c8 :c cb :8 cc
:9 cd :8 ce :4 cf :6 d0
:2 c4 :2 c3 :4 d3 d4
:5 d5 :a d6 d7 :2 d3
:6 d8 :2 bf :4 b8 db
:4 dc :4 dd :4 de :4 df
:3 db e2 :2 e1 :4 db
e5 :4 e6 :6 e7 :6 e8
:6 e9 :3 e5 ec :2 eb
:4 e5 :2 ef f0 0
f0 :2 ef :6 f1 :5 f2
:5 f3 :5 f4 :d f5 :5 f6
:5 f9 :4 fa :8 fb :3 fc
fb :6 fe fd :3 fb
fa :4 101 100 :3 fa
:5 103 :4 104 :3 103 :8 107
:a 108 :a 109 :4 10a :3 109
:3 107 :8 10f :d 110 :8 112
:7 113 :4 114 :7 115 :4 116
:c 117 :4 118 :4 119 :4 11a
:4 11b :8 11c :4 11d :3 11e
:f 11f :2 11e :5 120 :2 11d
:2 115 :2 114 :11 124 112
125 112 :8 127 :4 128
:7 129 :4 12a :4 12b :5 12c
:5 12d :8 12e :4 12f :e 130
131 :2 129 :2 128 :3 133
:2 f7 :4 ef :4 11 139
:6 1 
153b
4
:3 0 1 :3 0 2
:3 0 3 :6 0 1
:2 0 b :2 0 6
5 :3 0 6 :3 0
7 :3 0 8 :2 0
3 6 9 :6 0
9 :4 0 d a
b 5a2 4 :6 0
e :2 0 b 6
:3 0 7 :3 0 8
f 12 :6 0 c
:4 0 16 13 14
5a2 0 a :6 0
12 88 0 10
6 :3 0 7 :3 0
d 18 1b :6 0
1e 1c 0 5a2
0 d :6 0 2e
2f 0 14 10
:3 0 20 :7 0 11
:3 0 24 21 22
5a2 0 f :6 0
13 :3 0 14 :2 0
4 26 27 0
28 :7 0 15 :4 0
2c 29 2a 5a2
0 12 :6 0 19
:2 0 16 13 :3 0
14 :2 0 4 30
:7 0 17 :4 0 34
31 32 5a2 0
16 :6 0 1d 117
0 1b 6 :3 0
7 :3 0 18 36
39 :6 0 1a :4 0
3d 3a 3b 5a2
0 18 :6 0 1d
:3 0 1c :3 0 3f
:7 0 42 40 0
5a2 0 1b :6 0
1e :a 0 51 2
:7 0 1f :4 0 6
:3 0 46 47 0
51 44 48 :2 0
1f :3 0 4 :3 0
4b :2 0 4d 1f
50 :3 0 50 0
50 4f 4d 4e
:6 0 51 1 0
44 48 50 5a2
:2 0 20 :a 0 67
3 :7 0 23 :2 0
21 6 :3 0 21
:7 0 56 55 :3 0
58 :2 0 67 53
59 :2 0 22 :3 0
23 :2 0 24 :2 0
25 5c 5e :3 0
21 :3 0 27 5b
61 :2 0 63 2a
66 :3 0 66 0
66 65 63 64
:6 0 67 1 0
53 59 66 5a2
:2 0 25 :a 0 cd
4 :7 0 2e 20c
0 2c 6 :3 0
26 :7 0 6c 6b
:3 0 19 :2 0 30
6 :3 0 27 :7 0
70 6f :3 0 72
:2 0 cd 69 73
:2 0 29 :2 0 36
6 :3 0 7 :3 0
33 76 79 :6 0
7c 7a 0 cb
0 28 :6 0 26
:3 0 2a :4 0 3a
7e 80 :3 0 28
:3 0 2b :4 0 82
83 0 86 2c
:3 0 3d 9c 26
:3 0 29 :2 0 2d
:4 0 41 88 8a
:3 0 28 :3 0 2e
:4 0 8c 8d 0
90 2c :3 0 44
91 8b 90 0
9d 26 :3 0 29
:2 0 2f :4 0 48
93 95 :3 0 28
:3 0 30 :4 0 97
98 0 9a 4b
9b 96 9a 0
9d 81 86 0
9d 4d 0 c9
27 :3 0 31 :2 0
51 9f a0 :3 0
28 :3 0 32 :3 0
28 :3 0 33 :4 0
27 :3 0 53 a3
a7 a2 a8 0
aa 57 ab a1
aa 0 ac 59
0 c9 28 :3 0
34 :3 0 35 :4 0
36 :2 0 26 :3 0
5b b0 b2 :3 0
36 :2 0 37 :4 0
5e b4 b6 :3 0
36 :2 0 28 :3 0
61 b8 ba :3 0
b :2 0 19 :2 0
64 ae be ad
bf 0 c9 22
:3 0 23 :2 0 24
:2 0 68 c2 c4
:3 0 28 :3 0 6a
c1 c7 :2 0 c9
6d cc :3 0 cc
72 cc cb c9
ca :6 0 cd 1
0 69 73 cc
5a2 :2 0 1d :3 0
38 :a 0 fc 5
:7 0 1f :4 0 6
:3 0 d2 d3 0
fc d0 d4 :2 0
dd de 0 74
13 :3 0 14 :2 0
4 d7 d8 0
d9 :7 0 dc da
0 fa 0 39
:6 0 3a :3 0 3b
:3 0 36 :2 0 3c
:3 0 3d :3 0 e1
e2 0 76 e0
e4 :3 0 79 39
:3 0 3e :3 0 7b
e9 ef 0 f0
:3 0 3f :3 0 40
:2 0 41 :2 0 7f
ec ee :4 0 f2
f3 :5 0 e6 ea
0 82 0 f1
:2 0 f8 1f :3 0
39 :3 0 f6 :2 0
f8 84 fb :3 0
fb 87 fb fa
f8 f9 :6 0 fc
1 0 d0 d4
fb 5a2 :2 0 1d
:3 0 42 :a 0 128
6 :7 0 1f :4 0
6 :3 0 101 102
0 128 ff 103
:2 0 8b :2 0 89
13 :3 0 14 :2 0
4 106 107 0
108 :7 0 10b 109
0 126 0 39
:6 0 43 :3 0 44
:3 0 10c 10e 8d
39 :3 0 45 :3 0
46 :2 0 4 112
113 0 8f 115
11b 0 11c :3 0
3f :3 0 40 :2 0
41 :2 0 93 118
11a :4 0 11e 11f
:5 0 110 116 0
96 0 11d :2 0
124 1f :3 0 39
:3 0 122 :2 0 124
98 127 :3 0 127
9b 127 126 124
125 :6 0 128 1
0 ff 103 127
5a2 :2 0 1d :3 0
47 :a 0 252 7
:7 0 9f 50b 0
9d 6 :3 0 48
:7 0 12e 12d :3 0
a4 534 0 a1
10 :3 0 4a :3 0
49 :7 0 133 131
132 :2 0 1f :3 0
10 :3 0 135 137
0 252 12b 138
:2 0 a8 573 0
a6 10 :3 0 13b
:7 0 11 :3 0 13f
13c 13d 250 0
39 :6 0 13 :3 0
14 :2 0 4 141
142 0 143 :7 0
146 144 0 250
0 4b :6 0 51
:2 0 aa 4d :3 0
148 :7 0 14b 149
0 250 0 4c
:6 0 13 :3 0 14
:2 0 4 14d 14e
0 14f :7 0 152
150 0 250 0
4e :6 0 51 :2 0
ae 50 :3 0 ac
154 156 :6 0 159
157 0 250 0
4f :6 0 b4 5e8
0 b2 50 :3 0
b0 15b 15d :6 0
160 15e 0 250
0 52 :6 0 52
:3 0 10 :3 0 162
:7 0 11 :3 0 166
163 164 250 0
53 :6 0 54 :3 0
55 :3 0 168 169
0 34 :3 0 43
:3 0 56 :3 0 57
:2 0 b6 16d 16f
b8 16c 171 58
:2 0 59 :2 0 ba
16b 175 be 16a
177 167 178 0
236 5a :3 0 5b
:3 0 17a 17b 0
5c :3 0 5d :3 0
48 :3 0 c0 17e
180 17d 181 5e
:3 0 52 :3 0 183
184 5f :3 0 4f
:3 0 186 187 c2
17c 189 :2 0 236
4b :3 0 60 :3 0
54 :3 0 61 :3 0
18d 18e 0 4f
:3 0 c6 18f 191
a :3 0 c8 18c
194 18b 195 0
236 4c :3 0 62
:3 0 63 :4 0 36
:2 0 34 :3 0 4b
:3 0 b :2 0 64
:2 0 cb 19b 19f
cf 19a 1a1 :3 0
65 :4 0 d2 198
1a4 197 1a5 0
236 4e :3 0 34
:3 0 4b :3 0 66
:2 0 d5 1a8 1ab
1a7 1ac 0 236
4e :3 0 67 :4 0
68 :4 0 69 :4 0
6a :4 0 6b :4 0
6c :4 0 6d :4 0
6e :4 0 6f :4 0
70 :4 0 71 :4 0
72 :4 0 73 :4 0
74 :4 0 75 :4 0
76 :4 0 77 :4 0
78 :4 0 79 :4 0
7a :4 0 7b :4 0
7c :4 0 7d :4 0
7e :4 0 7f :4 0
80 :4 0 81 :4 0
82 :4 0 83 :4 0
84 :4 0 d8 :3 0
1ae 1af 1ce 53
:3 0 4a :3 0 1d0
1d1 0 1d3 f7
1d4 1cf 1d3 0
1d5 f9 0 236
34 :3 0 4e :3 0
b :2 0 85 :2 0
fb 1d6 1da 86
:2 0 44 :4 0 101
1dc 1de :3 0 53
:3 0 87 :3 0 88
:3 0 104 1e1 1e3
4c :3 0 89 :2 0
108 1e6 1e7 :3 0
39 :3 0 4a :3 0
1e9 1ea 0 1ec
10b 1f1 39 :3 0
11 :3 0 1ed 1ee
0 1f0 10d 1f2
1e8 1ec 0 1f3
0 1f0 0 1f3
10f 0 1f4 112
210 4e :3 0 38
:3 0 29 :2 0 116
1f7 1f8 :3 0 87
:3 0 88 :3 0 119
1fa 1fc 4c :3 0
89 :2 0 11d 1ff
200 :3 0 1f9 202
201 :2 0 39 :3 0
4a :3 0 204 205
0 207 120 20c
39 :3 0 11 :3 0
208 209 0 20b
122 20d 203 207
0 20e 0 20b
0 20e 124 0
20f 127 211 1e0
1f4 0 212 0
20f 0 212 129
0 213 12c 233
34 :3 0 4e :3 0
8 :2 0 12e 214
217 42 :3 0 29
:2 0 133 21a 21b
:3 0 87 :3 0 88
:3 0 136 21d 21f
4c :3 0 89 :2 0
13a 222 223 :3 0
21c 225 224 :2 0
39 :3 0 4a :3 0
227 228 0 22a
13d 22f 39 :3 0
11 :3 0 22b 22c
0 22e 13f 230
226 22a 0 231
0 22e 0 231
141 0 232 144
234 1df 213 0
235 0 232 0
235 146 0 236
149 249 8a :3 0
49 :3 0 39 :3 0
11 :3 0 23a 23b
0 23d 151 241
8b :5 0 240 153
242 239 23d 0
243 0 240 0
243 155 0 244
158 246 15a 245
244 :2 0 247 15c
:2 0 249 0 249
248 236 247 :6 0
24e 7 :3 0 1f
:3 0 39 :3 0 24c
:2 0 24e 15e 251
:3 0 251 161 251
250 24e 24f :6 0
252 1 0 12b
138 251 5a2 :2 0
1d :3 0 8c :a 0
28e 9 :7 0 1f
:4 0 10 :3 0 257
258 0 28e 255
259 :2 0 260 261
0 169 10 :3 0
25c :7 0 25f 25d
0 28c 0 39
:6 0 8d :3 0 8e
:3 0 8f :2 0 16b
263 264 :3 0 39
:3 0 11 :3 0 266
267 0 26a 2c
:3 0 16d 284 90
:3 0 8d :3 0 8e
:3 0 26c 26d 0
16f 26b 26f 29
:2 0 91 :4 0 173
271 273 :3 0 39
:3 0 4a :3 0 275
276 0 278 176
279 274 278 0
286 39 :3 0 47
:3 0 8d :3 0 8e
:3 0 27c 27d 0
11 :3 0 178 27b
280 27a 281 0
283 17b 285 265
26a 0 286 0
283 0 286 17d
0 28a 1f :3 0
39 :3 0 288 :2 0
28a 181 28d :3 0
28d 184 28d 28c
28a 28b :6 0 28e
1 0 255 259
28d 5a2 :2 0 20
:a 0 2b4 a :7 0
188 a48 0 186
6 :3 0 92 :7 0
293 292 :3 0 23
:2 0 18a 6 :3 0
21 :7 0 297 296
:3 0 299 :2 0 2b4
290 29a :2 0 22
:3 0 24 :2 0 18d
29d 29f :3 0 93
:4 0 36 :2 0 92
:3 0 18f 2a2 2a4
:3 0 36 :2 0 94
:4 0 192 2a6 2a8
:3 0 36 :2 0 21
:3 0 195 2aa 2ac
:3 0 198 29c 2ae
:2 0 2b0 19b 2b3
:3 0 2b3 0 2b3
2b2 2b0 2b1 :6 0
2b4 1 0 290
29a 2b3 5a2 :2 0
95 :a 0 2c5 b
:8 0 2b7 :2 0 2c5
2b6 2b8 :2 0 96
:3 0 97 :3 0 2ba
2bb 0 1b :3 0
4a :3 0 19d 2bc
2bf :2 0 2c1 1a0
2c4 :3 0 2c4 0
2c4 2c3 2c1 2c2
:6 0 2c5 1 0
2b6 2b8 2c4 5a2
:2 0 1d :3 0 98
:a 0 304 c :7 0
85 :2 0 1a2 9a
:3 0 99 :7 0 2cb
2ca :3 0 1a6 :2 0
1a4 9c :3 0 9b
:7 0 2d0 2ce 2cf
:2 0 1f :3 0 50
:3 0 2d2 2d4 0
304 2c8 2d5 :2 0
9e :2 0 1a9 9a
:3 0 2d8 :7 0 2db
2d9 0 302 0
9d :6 0 9d :3 0
99 :3 0 2dc 2dd
0 300 9d :3 0
9f :2 0 1ad 2e0
2e2 :3 0 9d :3 0
9d :3 0 23 :2 0
a0 :2 0 1b0 2e6
2e8 :3 0 2e4 2e9
0 2eb 1b3 2ec
2e3 2eb 0 2ed
1b5 0 300 1f
:3 0 54 :3 0 34
:3 0 2ef 2f0 0
54 :3 0 a1 :3 0
2f2 2f3 0 9d
:3 0 54 :3 0 98
:3 0 2f6 2f7 0
1b7 2f4 2f9 b
:2 0 9b :3 0 1ba
2f1 2fd 2fe :2 0
300 1be 303 :3 0
303 1c2 303 302
300 301 :6 0 304
1 0 2c8 2d5
303 5a2 :2 0 a2
:a 0 3fc d :7 0
1c6 c34 0 1c4
6 :3 0 a3 :7 0
309 308 :3 0 1cb
c51 0 1c8 1c
:3 0 a4 :7 0 30d
30c :3 0 30f :2 0
3fc 306 310 :2 0
1cf c85 0 1cd
4d :3 0 313 :7 0
316 314 0 3fa
0 a5 :6 0 1c
:3 0 318 :7 0 31b
319 0 3fa 0
a6 :6 0 a5 :3 0
a8 :3 0 31d :7 0
320 31e 0 3fa
0 a7 :6 0 88
:3 0 321 322 0
3f8 a6 :3 0 a9
:3 0 aa :3 0 325
326 0 a4 :3 0
1d1 327 329 324
32a 0 3f8 a7
:3 0 96 :3 0 ab
:3 0 32d 32e 0
a6 :3 0 1d3 32f
331 32c 332 0
3f8 96 :3 0 ac
:3 0 334 335 0
1b :3 0 54 :3 0
ad :3 0 338 339
0 5d :3 0 ae
:4 0 1d5 33b 33d
5d :3 0 af :4 0
1d7 33f 341 5d
:3 0 b0 :4 0 1d9
343 345 5d :3 0
b1 :4 0 1db 347
349 98 :3 0 b2
:3 0 43 :3 0 a5
:3 0 b3 :4 0 1dd
34d 350 1e0 34c
352 b4 :2 0 41
:2 0 1e2 354 356
:3 0 b5 :2 0 b2
:3 0 43 :3 0 a5
:3 0 b6 :4 0 1e5
35a 35d 1e8 359
35f b7 :2 0 b8
:2 0 1ea 361 363
:3 0 1ed 358 365
:3 0 b5 :2 0 b2
:3 0 43 :3 0 a5
:3 0 b9 :4 0 1f0
369 36c 1f3 368
36e b7 :2 0 51
:2 0 1f5 370 372
:3 0 1f8 367 374
:3 0 41 :2 0 1fb
34b 377 98 :3 0
b2 :3 0 43 :3 0
a5 :3 0 ba :4 0
1fe 37b 37e 201
37a 380 b5 :2 0
b2 :3 0 43 :3 0
a5 :3 0 bb :4 0
203 384 387 206
383 389 b7 :2 0
b8 :2 0 208 38b
38d :3 0 20b 382
38f :3 0 b5 :2 0
b2 :3 0 43 :3 0
a5 :3 0 bc :4 0
20e 393 396 211
392 398 23 :2 0
bd :2 0 213 39a
39c :3 0 39d :2 0
b7 :2 0 be :2 0
216 39f 3a1 :3 0
219 391 3a3 :3 0
41 :2 0 21c 379
3a6 96 :3 0 34
:3 0 3a8 3a9 0
a6 :3 0 85 :2 0
a7 :3 0 23 :2 0
66 :2 0 21f 3ae
3b0 :3 0 222 3aa
3b2 98 :3 0 a7
:3 0 23 :2 0 bf
:2 0 226 3b6 3b8
:3 0 229 3b4 3ba
98 :3 0 96 :3 0
ab :3 0 3bd 3be
0 a4 :3 0 22b
3bf 3c1 22d 3bc
3c3 98 :3 0 c0
:3 0 a3 :3 0 22f
3c6 3c8 41 :2 0
231 3c5 3cb 5d
:3 0 b0 :4 0 234
3cd 3cf 54 :3 0
55 :3 0 3d1 3d2
0 a3 :3 0 236
3d3 3d5 238 33a
3d7 245 336 3d9
:2 0 3f8 96 :3 0
c1 :3 0 3db 3dc
0 1b :3 0 a6
:3 0 a7 :3 0 23
:2 0 bf :2 0 248
3e1 3e3 :3 0 96
:3 0 ab :3 0 3e5
3e6 0 1b :3 0
24b 3e7 3e9 b5
:2 0 b :2 0 24d
3eb 3ed :3 0 c2
:2 0 250 3dd 3f0
:2 0 3f8 96 :3 0
c3 :3 0 3f2 3f3
0 a6 :3 0 256
3f4 3f6 :2 0 3f8
258 3fb :3 0 3fb
25f 3fb 3fa 3f8
3f9 :6 0 3fc 1
0 306 310 3fb
5a2 :2 0 c4 :a 0
417 e :7 0 265
f67 0 263 6
:3 0 a3 :7 0 401
400 :3 0 269 f8d
0 267 1c :3 0
a4 :7 0 405 404
:3 0 50 :3 0 c5
:7 0 409 408 :4 0
413 0 26b 50
:3 0 c6 :7 0 40d
40c :3 0 40f :2 0
417 3fe 410 :2 0
270 416 :3 0 416
0 416 415 413
414 :6 0 417 1
0 3fe 410 416
5a2 :2 0 c7 :a 0
438 f :7 0 274
fed 0 272 1c
:3 0 a4 :7 0 41c
41b :3 0 278 1021
0 276 c9 :3 0
ca :3 0 1c :3 0
c8 :5 0 1 422
421 :3 0 c9 :3 0
ca :3 0 50 :3 0
c5 :5 0 1 428
427 :4 0 434 0
27a c9 :3 0 ca
:3 0 50 :3 0 c6
:5 0 1 42e 42d
:3 0 430 :2 0 438
419 431 :2 0 27f
437 :3 0 437 0
437 436 434 435
:6 0 438 1 0
419 431 437 5a2
:2 0 1d :3 0 cb
:a 0 59b 10 :7 0
1f :4 0 1c :3 0
43d 43e 0 59b
43b 43f :2 0 283
10a7 0 281 9c
:3 0 442 :7 0 cd
:2 0 446 443 444
599 0 cc :6 0
287 10db 0 285
a8 :3 0 448 :7 0
44b 449 0 599
0 ce :6 0 a8
:3 0 44d :7 0 450
44e 0 599 0
cf :6 0 28f 1126
0 28d a8 :3 0
452 :7 0 455 453
0 599 0 d0
:6 0 50 :3 0 d2
:2 0 289 457 459
:6 0 54 :3 0 55
:3 0 45b 45c 0
d3 :4 0 28b 45d
45f 462 45a 460
599 0 d1 :6 0
d :3 0 9a :3 0
464 :7 0 467 465
0 599 0 d4
:6 0 8d :3 0 8e
:3 0 469 46a 0
468 46b 0 597
d :3 0 31 :2 0
291 46e 46f :3 0
90 :3 0 d :3 0
293 471 473 29
:2 0 91 :4 0 297
475 477 :3 0 f
:3 0 4a :3 0 479
47a 0 47c 29a
484 f :3 0 47
:3 0 d :3 0 29c
47e 480 47d 481
0 483 29e 485
478 47c 0 486
0 483 0 486
2a0 0 487 2a3
48d 20 :3 0 12
:3 0 2a5 488 48a
:2 0 48c 2a7 48e
470 487 0 48f
0 48c 0 48f
2a9 0 597 f
:3 0 490 :2 0 d5
:2 0 2ac 492 493
:3 0 20 :3 0 16
:3 0 2ae 495 497
:2 0 499 2b0 49a
494 499 0 49b
2b2 0 597 90
:3 0 d :3 0 2b4
49c 49e 29 :2 0
91 :4 0 2b8 4a0
4a2 :3 0 d4 :3 0
b2 :3 0 43 :3 0
88 :3 0 d6 :4 0
2bb 4a6 4a9 2be
4a5 4ab 4a4 4ac
0 4bf d7 :3 0
d4 :3 0 d8 :2 0
d7 :2 0 2c0 4b1
4b2 :3 0 29 :2 0
cd :2 0 2c5 4b4
4b6 :3 0 20 :3 0
18 :3 0 2c8 4b8
4ba :2 0 4bc 2ca
4bd 4b7 4bc 0
4be 2cc 0 4bf
2ce 4c0 4a3 4bf
0 4c1 2d1 0
597 cf :3 0 96
:3 0 ab :3 0 4c3
4c4 0 1b :3 0
2d3 4c5 4c7 4c2
4c8 0 597 ce
:3 0 96 :3 0 d9
:3 0 4cb 4cc 0
1b :3 0 5d :3 0
ae :4 0 2d5 4cf
4d1 b :2 0 2d7
4cd 4d4 4ca 4d5
0 597 da :3 0
ce :3 0 9e :2 0
cd :2 0 db :3 0
2dd 4d9 4dc :3 0
4dd 54f cc :3 0
cc :3 0 b5 :2 0
b :2 0 2e0 4e1
4e3 :3 0 4df 4e4
0 54d 96 :3 0
ac :3 0 4e6 4e7
0 1b :3 0 54
:3 0 ad :3 0 4ea
4eb 0 5d :3 0
dc :4 0 2e3 4ed
4ef 5d :3 0 af
:4 0 2e5 4f1 4f3
96 :3 0 34 :3 0
4f5 4f6 0 1b
:3 0 dd :2 0 ce
:3 0 b5 :2 0 85
:2 0 2e7 4fb 4fd
:3 0 2ea 4f7 4ff
5d :3 0 b0 :4 0
2ee 501 503 5d
:3 0 b0 :4 0 2f0
505 507 5d :3 0
de :4 0 2f2 509
50b 5d :3 0 df
:4 0 2f4 50d 50f
98 :3 0 ce :3 0
23 :2 0 b :2 0
2f6 513 515 :3 0
2f9 511 517 96
:3 0 34 :3 0 519
51a 0 1b :3 0
54 :3 0 e0 :3 0
51d 51e 0 96
:3 0 34 :3 0 520
521 0 1b :3 0
41 :2 0 ce :3 0
b5 :2 0 dd :2 0
2fb 526 528 :3 0
2fe 522 52a 54
:3 0 98 :3 0 52c
52d 0 302 51f
52f ce :3 0 b5
:2 0 e1 :2 0 305
532 534 :3 0 308
51b 536 30c 4ec
538 316 4e8 53a
:2 0 54d ce :3 0
96 :3 0 d9 :3 0
53d 53e 0 1b
:3 0 5d :3 0 ae
:4 0 319 541 543
ce :3 0 b5 :2 0
b8 :2 0 31b 546
548 :3 0 31e 53f
54a 53c 54b 0
54d 322 54f db
:3 0 4de 54d :4 0
597 d0 :3 0 96
:3 0 ab :3 0 551
552 0 1b :3 0
326 553 555 550
556 0 597 96
:3 0 ac :3 0 558
559 0 1b :3 0
54 :3 0 ad :3 0
55c 55d 0 5d
:3 0 e2 :4 0 328
55f 561 5d :3 0
b0 :4 0 32a 563
565 5d :3 0 b0
:4 0 32c 567 569
98 :3 0 cc :3 0
41 :2 0 32e 56b
56e 98 :3 0 cc
:3 0 41 :2 0 331
570 573 98 :3 0
d0 :3 0 23 :2 0
cf :3 0 334 577
579 :3 0 337 575
57b 98 :3 0 cf
:3 0 339 57d 57f
98 :3 0 e3 :3 0
54 :3 0 c0 :3 0
583 584 0 d1
:3 0 33b 585 587
cd :2 0 33d 582
58a 41 :2 0 340
581 58d d1 :3 0
343 55e 590 34d
55a 592 :2 0 597
1f :3 0 1b :3 0
595 :2 0 597 350
59a :3 0 59a 35b
59a 599 597 598
:6 0 59b 1 0
43b 43f 59a 5a2
:3 0 5a0 0 5a0
:3 0 5a0 5a2 59e
59f :6 0 5a3 :2 0
3 :3 0 362 0
3 5a0 5a6 :3 0
5a5 5a3 5a7 :8 0

379
4
:3 0 2 8 7
1 4 2 11
10 1 e 2
1a 19 1 17
1 1f 1 25
1 2d 2 38
37 1 35 1
3e 1 4c 1
54 1 57 1
5d 2 5f 60
1 62 1 6a
1 6e 2 6d
71 2 78 77
1 75 1 7f
2 7d 7f 1
84 1 89 2
87 89 1 8e
1 94 2 92
94 1 99 3
9c 91 9b 1
9e 3 a4 a5
a6 1 a9 1
ab 2 af b1
2 b3 b5 2
b7 b9 3 bb
bc bd 1 c3
2 c5 c6 4
9d ac c0 c8
1 7b 1 d6
2 df e3 1
e5 1 e8 1
ed 2 eb ed
1 e7 2 f4
f7 1 db 1
105 1 10d 1
10f 1 114 1
119 2 117 119
1 111 2 120
123 1 10a 1
12c 1 130 2
12f 134 1 13a
1 140 1 147
1 14c 1 155
1 153 1 15c
1 15a 1 161
1 16e 1 170
3 172 173 174
1 176 1 17f
3 182 185 188
1 190 2 192
193 3 19c 19d
19e 2 199 1a0
2 1a2 1a3 2
1a9 1aa 1e 1b0
1b1 1b2 1b3 1b4
1b5 1b6 1b7 1b8
1b9 1ba 1bb 1bc
1bd 1be 1bf 1c0
1c1 1c2 1c3 1c4
1c5 1c6 1c7 1c8
1c9 1ca 1cb 1cc
1cd 1 1d2 1
1d4 3 1d7 1d8
1d9 1 1dd 2
1db 1dd 1 1e2
1 1e5 2 1e4
1e5 1 1eb 1
1ef 2 1f1 1f2
1 1f3 1 1f6
2 1f5 1f6 1
1fb 1 1fe 2
1fd 1fe 1 206
1 20a 2 20c
20d 1 20e 2
210 211 1 212
2 215 216 1
219 2 218 219
1 21e 1 221
2 220 221 1
229 1 22d 2
22f 230 1 231
2 233 234 7
179 18a 196 1a6
1ad 1d5 235 1
23c 1 23f 2
241 242 1 243
1 238 1 246
2 249 24d 7
13e 145 14a 151
158 15f 165 1
25b 1 262 1
268 1 26e 1
272 2 270 272
1 277 2 27e
27f 1 282 3
284 279 285 2
286 289 1 25e
1 291 1 295
2 294 298 1
29e 2 2a1 2a3
2 2a5 2a7 2
2a9 2ab 2 2a0
2ad 1 2af 2
2bd 2be 1 2c0
1 2c9 1 2cd
2 2cc 2d1 1
2d7 1 2e1 2
2df 2e1 2 2e5
2e7 1 2ea 1
2ec 2 2f5 2f8
3 2fa 2fb 2fc
3 2de 2ed 2ff
1 2da 1 307
1 30b 2 30a
30e 1 312 1
317 1 31c 1
328 1 330 1
33c 1 340 1
344 1 348 2
34e 34f 1 351
2 353 355 2
35b 35c 1 35e
2 360 362 2
357 364 2 36a
36b 1 36d 2
36f 371 2 366
373 2 375 376
2 37c 37d 1
37f 2 385 386
1 388 2 38a
38c 2 381 38e
2 394 395 1
397 2 399 39b
2 39e 3a0 2
390 3a2 2 3a4
3a5 2 3ad 3af
3 3ab 3ac 3b1
2 3b5 3b7 1
3b9 1 3c0 1
3c2 1 3c7 2
3c9 3ca 1 3ce
1 3d4 c 33e
342 346 34a 378
3a7 3b3 3bb 3c4
3cc 3d0 3d6 2
337 3d8 2 3e0
3e2 1 3e8 2
3ea 3ec 5 3de
3df 3e4 3ee 3ef
1 3f5 6 323
32b 333 3da 3f1
3f7 3 315 31a
31f 1 3ff 1
403 1 407 1
40b 4 402 406
40a 40e 1 412
1 41a 1 41e
1 424 1 42a
4 41d 423 429
42f 1 433 1
441 1 447 1
44c 1 451 1
458 1 45e 1
456 1 463 1
46d 1 472 1
476 2 474 476
1 47b 1 47f
1 482 2 484
485 1 486 1
489 1 48b 2
48d 48e 1 491
1 496 1 498
1 49a 1 49d
1 4a1 2 49f
4a1 2 4a7 4a8
1 4aa 2 4af
4b0 1 4b5 2
4b3 4b5 1 4b9
1 4bb 1 4bd
2 4ad 4be 1
4c0 1 4c6 1
4d0 3 4ce 4d2
4d3 1 4da 2
4d8 4da 2 4e0
4e2 1 4ee 1
4f2 2 4fa 4fc
3 4f8 4f9 4fe
1 502 1 506
1 50a 1 50e
2 512 514 1
516 2 525 527
3 523 524 529
2 52b 52e 2
531 533 3 51c
530 535 9 4f0
4f4 500 504 508
50c 510 518 537
2 4e9 539 1
542 2 545 547
3 540 544 549
3 4e5 53b 54c
1 554 1 560
1 564 1 568
2 56c 56d 2
571 572 2 576
578 1 57a 1
57e 1 586 2
588 589 2 58b
58c 9 562 566
56a 56f 574 57c
580 58e 58f 2
55b 591 a 46c
48f 49b 4c1 4c9
4d6 54f 557 593
596 6 445 44a
44f 454 461 466
16 c 15 1d
23 2b 33 3c
41 51 67 cd
fc 128 252 28e
2b4 2c5 304 3fc
417 438 59b 
1
4
0 
5a6
0
1
14
11
3f
0 1 1 1 1 1 1 7
1 1 1 1 1 1 1 1
10 0 0 0 
2b6 1 b
41e f 0
43b 1 10
2d 1 0
424 f 0
407 e 0
31c d 0
317 d 0
ff 1 6
e 1 0
2c9 c 0
153 7 0
75 4 0
25b 9 0
13a 7 0
105 6 0
d6 5 0
42a f 0
40b e 0
419 1 f
312 d 0
463 10 0
6a 4 0
290 1 a
53 1 3
4 1 0
41a f 0
403 e 0
30b d 0
3ff e 0
307 d 0
451 10 0
44c 10 0
35 1 0
2d7 c 0
255 1 9
140 7 0
6e 4 0
d0 1 5
130 7 0
14c 7 0
12c 7 0
1f 1 0
291 a 0
3 0 1
3fe 1 e
15a 7 0
441 10 0
44 1 2
2cd c 0
295 a 0
54 3 0
447 10 0
3e 1 0
12b 1 7
2c8 1 c
69 1 4
161 7 0
147 7 0
456 10 0
306 1 d
25 1 0
17 1 0
0

/
