CREATE OR REPLACE PACKAGE plpdf_toolkit is
/**
 <config>
  <pck-name>PL/PDF Toolkit</pck-name>
  <pck-title>User's Guide</pck-title>
  <pck-version>v2.0.6</pck-version>
  <header-prc>plpdf_doc_xml.plpdf_header</header-prc>
  <header-size>15</header-size>
  <footer-prc>plpdf_doc_xml.plpdf_footer</footer-prc>
  <footer-size>10</footer-size>
 </config>
*/

/**
<h1>Introdution</h1>
<br/>
<p>
 PL/PDF Toolkit is a java library with PL/SQL interface for manipulating existing PDF documents.
</p>
<newpage/>
*/

/**
<h1>Certification</h1>
<h2>GetCertKey</h2>
<type>Function</type>
<desc>
  Generates preliminary certification key.
  This function should be run once when the PL/PDF package is installed. The function generates a string
  that should be sent to <a>mailto:info@plpdf.com</a>. Our representatives will send a certificate key back that should
  be used as the return value in the <i>pl_pdf_cert.SetCertKey</i> function.
</desc>
<params>-</params>
<return>
 <return-def>varchar2</return-def>
 <return-desc>Preliminary certificate key</return-desc>
</return>
<newpage/>
*/
function GetCertKey
  return varchar2;

/**
<h1>Types And Constants</h1>
<h2>t14font</h2>
<type>Subtype, VARHCAR2(30 CHAR)</type>
<desc>
 Standard Type 1 Fonts<br/>
 The PostScript names of 14 Type 1 fonts, known as the standard fonts.
 These fonts, or their font metrics and suitable substitution fonts, are required to be available to the viewer application.
</desc>
<br/>
*/
subtype t_14font is varchar2(30 char);

/**
<h2>t_color</h2>
<type>Record</type>
<desc>
Represents the RGB color triplet.
</desc>
<fields>
 <field>
  <field-def>r number</field-def>
  <field-desc>Value of the red component</field-desc>
 </field>
 <field>
  <field-def>g number</field-def>
  <field-desc>Value of the green component</field-desc>
 </field>
 <field>
  <field-def>b number</field-def>
  <field-desc>Value of the blue component</field-desc>
 </field>
</fields>
*/
type t_color is record (
  r number,
  g number,
  b number
  );
/**
<br/>
<h2>times-roman</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Times-Roman</constant-desc>
</constant>

<h2>times_bold</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Times-Bold</constant-desc>
</constant>

<h2>times_italic</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Times-Italic</constant-desc>
</constant>

<h2>times_bold_italic</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Times-BoldItalic</constant-desc>
</constant>

<h2>helvetica</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Helvetica</constant-desc>
</constant>

<h2>helvetica_bold</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Helvetica-Bold</constant-desc>
</constant>

<h2>helvetica_oblique</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Helvetica-Oblique</constant-desc>
</constant>

<h2>helvetica_bold_oblique</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Helvetica-BoldOblique</constant-desc>
</constant>

<h2>courier</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Courier</constant-desc>
</constant>

<h2>courier_bold</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Courier-Bold</constant-desc>
</constant>

<h2>courier_oblique</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Courier-Oblique</constant-desc>
</constant>

<h2>courier_bold_oblique</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Courier-BoldOblique</constant-desc>
</constant>

<h2>symbol</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Symbol</constant-desc>
</constant>

<h2>zapf_dingbats</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>ZapfDingbats</constant-desc>
</constant>
<newpage/>
*/
  times_roman constant t_14font := 'Times-Roman';
  times_bold constant t_14font := 'Times-Bold';
  times_italic constant t_14font := 'Times-Italic';
  times_bold_italic constant t_14font := 'Times-BoldItalic';
  helvetica constant t_14font := 'Helvetica';
  helvetica_bold constant t_14font := 'Helvetica-Bold';
  helvetica_oblique constant t_14font := 'Helvetica-Oblique';
  helvetica_bold_oblique constant t_14font := 'Helvetica-BoldOblique';
  courier constant t_14font := 'Courier';
  courier_bold constant t_14font := 'Courier-Bold';
  courier_oblique constant t_14font := 'Courier-Oblique';
  courier_bold_oblique constant t_14font := 'Courier-BoldOblique';
  symbol constant t_14font := 'Symbol';
  zapf_dingbats constant t_14font := 'ZapfDingbats';

/**
<br/>
<h2>Metadata</h2>
<type>Record</type>
<desc>
  A PDF document may include general information such as the document?s title,
  author, and creation and modification dates. Such global information about the
  document itself (as opposed to its content or structure) is called metadata, and is
  intended to assist in cataloguing and searching for documents in external databases.
</desc>
<fields>
 <field>
  <field-def>Title</field-def>
  <field-desc>The document?s title</field-desc>
 </field>
 <field>
  <field-def>Author</field-def>
  <field-desc>The name of the person who created the document</field-desc>
 </field>
 <field>
  <field-def>Subject</field-def>
  <field-desc>The subject of the document</field-desc>
 </field>
 <field>
  <field-def>Creator</field-def>
  <field-desc>If the document was converted to PDF from another format, the
   name of the application (for example, Adobe FrameMaker?) that created the
   original document from which it was converted.
  </field-desc>
 </field>
 <field>
  <field-def>Keywords</field-def>
  <field-desc>Keywords associated with the document</field-desc>
 </field>
 <field>
  <field-def>Producer</field-def>
  <field-desc>If the document was converted to PDF from another format, the
   name of the application (for example, Acrobat Distiller) that converted it to PDF.
  </field-desc>
 </field>
 <field>
  <field-def>CreationDate</field-def>
  <field-desc>The date and time the document was created, in human-readable form</field-desc>
 </field>
 <field>
  <field-def>ModDate</field-def>
  <field-desc>The date and time the document was most recently modified, in human-readable form</field-desc>
 </field>
</fields>
*/
type t_metadata is record (
  Title varchar2(2000 char),
  Author varchar2(2000 char),
  Subject varchar2(2000 char),
  Creator varchar2(2000 char),
  Keywords varchar2(2000 char),
  Producer varchar2(2000 char),
  CreationDate date,
  ModDate date
  );

/**
<br/>
<h2>Merge input</h2>
<type>Record</type>
<desc>
  PDF document with some properties.
</desc>
<fields>
 <field>
  <field-def>inputfile</field-def>
  <field-desc>Source PDF file</field-desc>
 </field>
 <field>
  <field-def>password</field-def>
  <field-desc>The owner password of the PDF file (if encrypted).</field-desc>
 </field>
 <field>
  <field-def>overwrite_rect_x</field-def>
  <field-desc>Overwrite rectangle x coordinate</field-desc>
 </field>
 <field>
  <field-def>overwrite_rect_y</field-def>
  <field-desc>Overwrite rectangle y coordinate</field-desc>
 </field>
 <field>
  <field-def>overwrite_rect_w</field-def>
  <field-desc>Overwrite rectangle width</field-desc>
 </field>
 <field>
  <field-def>overwrite_rect_h</field-def>
  <field-desc>Overwrite rectangle heigth</field-desc>
 </field><field>
  <field-def>overwrite_rect_color</field-def>
  <field-desc>Overwrite rectangle fill color</field-desc>
 </field>
</fields>
*/
type t_merge_input is record (
  inputfile blob,
  password varchar2(255 char),
  overwrite_rect_x number,
  overwrite_rect_y number,
  overwrite_rect_w number,
  overwrite_rect_h number,
  overwrite_rect_color t_color
  );

/**
<br/>
<h2>Merge inputs</h2>
<type>Table</type>
<desc>
  Table of Merge input records.
</desc>
<records>
 <record>
  <record-def>Input record</field-def>
  <recordd-desc>PDF document with some properties</field-desc>
 </record>
</records>
*/
type t_merge_inputs is table of t_merge_input index by pls_integer;

/**
<newpage/>
<h1>Functions</h1>
<br/>
<h2>Encryption</h2>
<p>
  A PDF document can be encrypted to protect its contents from unauthorized
  access. Encryption applies to all strings and streams in the document?s
  PDF file, but not to other object types such as integers and boolean values, which
  are used primarily to convey information about the document?s structure rather
  than its content. Leaving these values unencrypted allows random access to the
  objects within a document, while encrypting the strings and streams protects the
  document?s substantive contents.
</p>
*/

/**
<h2>Encrypt40</h2>
<type>Function</type>
<desc>
  Encrypt any PDF document using standard PDF 40 RC4 bit encryption.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_opassword varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_upassword varchar2 default null</param-def>
  <param-desc>the user password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_canextractcontent boolean default false</param-def>
  <param-desc>The user is allowed to copy or otherwise
    extract text and graphics from the document, including extracting text and graphics
    (in support of accessibility to disabled users or for other purposes).
  </param-desc>
 </param>
 <param>
  <param-def>p_canmodify boolean default false</param-def>
  <param-desc>The user is allowed to modify the contents of the document.</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyannotations boolean default false</param-def>
  <param-desc>The user is allowed to add or modify text annotations,
    fill in interactive form fields, and, if "modify" is also set, create or modify interactive form fields
    (including signature fields).
  </param-desc>
 </param>
 <param>
  <param-def>p_canprint boolean default false</param-def>
  <param-desc>The user is allowed to print the document.</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function Encrypt40(
  p_inputfile blob,
  p_opassword varchar2,
  p_upassword varchar2 default null,
  p_canextractcontent boolean default false,
  p_canmodify boolean default false,
  p_canmodifyannotations boolean default false,
  p_canprint boolean default false
  ) return blob;

/**
<h2>Encrypt128</h2>
<type>Function</type>
<desc>
  Encrypt any PDF document using standard PDF 128 RC4 bit encryption.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_opassword varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_upassword varchar2 default null</param-def>
  <param-desc>the user password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_canassemble boolean default false</param-def>
  <param-desc>The user is allowed to assemble the document
   (insert, rotate, or delete pages and create bookmarks or thumbnail images).
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractcontent boolean default false</param-def>
  <param-desc>The user is allowed to copy or otherwise
    extract text and graphics from the document.
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractforaccessibility boolean default false</param-def>
  <param-desc>The user is allowed to extract text and graphics
   (in support of accessibility to disabled users or for other purposes).
  </param-desc>
 </param>
 <param>
  <param-def>p_canfillinform boolean default false</param-def>
  <param-desc>The user is allowed to fill in existing interactive form fields
   (including signature fields)
  </param-desc>
 </param>
 <param>
  <param-def>p_canmodify boolean default false</param-def>
  <param-desc>The user is allowed to modify the contents of the document</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyannotations boolean default false</param-def>
  <param-desc>Add or modify text annotations, fill in interactive form fields.</param-desc>
 </param>
 <param>
  <param-def>p_canprint boolean default false</param-def>
  <param-desc>Print the document to a representation from which a faithful digital copy
  of the PDF content could be generated.</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyprintresolution boolean default false</param-def>
  <param-desc>The user is not allowed to print in highest quality.</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function Encrypt128(
  p_inputfile blob,
  p_opassword varchar2,
  p_upassword varchar2 default null,
  p_canassemble boolean default false,
  p_canextractcontent boolean default false,
  p_canextractforaccessibility boolean default false,
  p_canfillinform boolean default false,
  p_canmodify boolean default false,
  p_canmodifyannotations boolean default false,
  p_canprint boolean default false,
  p_canmodifyprintresolution boolean default false
  ) return blob;

/**
<h2>AESEncrypt128</h2>
<type>Function</type>
<desc>
  Encrypt any PDF document using standard PDF 128 AES bit encryption.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_opassword varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_upassword varchar2 default null</param-def>
  <param-desc>the user password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_canassemble boolean default false</param-def>
  <param-desc>The user is allowed to assemble the document
   (insert, rotate, or delete pages and create bookmarks or thumbnail images).
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractcontent boolean default false</param-def>
  <param-desc>The user is allowed to copy or otherwise
    extract text and graphics from the document.
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractforaccessibility boolean default false</param-def>
  <param-desc>The user is allowed to extract text and graphics
   (in support of accessibility to disabled users or for other purposes).
  </param-desc>
 </param>
 <param>
  <param-def>p_canfillinform boolean default false</param-def>
  <param-desc>The user is allowed to fill in existing interactive form fields
   (including signature fields)
  </param-desc>
 </param>
 <param>
  <param-def>p_canmodify boolean default false</param-def>
  <param-desc>The user is allowed to modify the contents of the document</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyannotations boolean default false</param-def>
  <param-desc>Add or modify text annotations, fill in interactive form fields.</param-desc>
 </param>
 <param>
  <param-def>p_canprint boolean default false</param-def>
  <param-desc>Print the document to a representation from which a faithful digital copy
  of the PDF content could be generated.</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyprintresolution boolean default false</param-def>
  <param-desc>The user is not allowed to print in highest quality.</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function AESEncrypt128(
  p_inputfile blob,
  p_opassword varchar2,
  p_upassword varchar2 default null,
  p_canassemble boolean default false,
  p_canextractcontent boolean default false,
  p_canextractforaccessibility boolean default false,
  p_canfillinform boolean default false,
  p_canmodify boolean default false,
  p_canmodifyannotations boolean default false,
  p_canprint boolean default false,
  p_canmodifyprintresolution boolean default false
  ) return blob;


/**
<h2>PublicKeyEncrypt40</h2>
<type>Function</type>
<desc>
  Encrypt any PDF document using standard PDF 40 RC4 bit encryption and public key certificate.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_certfile blob</param-def>
  <param-desc>the certificate file</param-desc>
 </param>
 <param>
  <param-def>p_canextractcontent boolean default false</param-def>
  <param-desc>The user is allowed to copy or otherwise
    extract text and graphics from the document, including extracting text and graphics
    (in support of accessibility to disabled users or for other purposes).
  </param-desc>
 </param>
 <param>
  <param-def>p_canmodify boolean default false</param-def>
  <param-desc>The user is allowed to modify the contents of the document.</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyannotations boolean default false</param-def>
  <param-desc>The user is allowed to add or modify text annotations,
    fill in interactive form fields, and, if "modify" is also set, create or modify interactive form fields
    (including signature fields).
  </param-desc>
 </param>
 <param>
  <param-def>p_canprint boolean default false</param-def>
  <param-desc>The user is allowed to print the document.</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function PublicKeyEncrypt40(
  p_inputfile blob,
  p_certfile blob,
  p_canextractcontent boolean default false,
  p_canmodify boolean default false,
  p_canmodifyannotations boolean default false,
  p_canprint boolean default false
  ) return blob;

/**
<h2>PublicKeyEncrypt128</h2>
<type>Function</type>
<desc>
  Encrypt any PDF document using standard PDF 128 RC4 bit encryption and public key certificate.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_certfile blob</param-def>
  <param-desc>the certificate file</param-desc>
 </param>
 <param>
  <param-def>p_canassemble boolean default false</param-def>
  <param-desc>The user is allowed to assemble the document
   (insert, rotate, or delete pages and create bookmarks or thumbnail images).
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractcontent boolean default false</param-def>
  <param-desc>The user is allowed to copy or otherwise
    extract text and graphics from the document.
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractforaccessibility boolean default false</param-def>
  <param-desc>The user is allowed to extract text and graphics
   (in support of accessibility to disabled users or for other purposes).
  </param-desc>
 </param>
 <param>
  <param-def>p_canfillinform boolean default false</param-def>
  <param-desc>The user is allowed to fill in existing interactive form fields
   (including signature fields)
  </param-desc>
 </param>
 <param>
  <param-def>p_canmodify boolean default false</param-def>
  <param-desc>The user is allowed to modify the contents of the document</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyannotations boolean default false</param-def>
  <param-desc>Add or modify text annotations, fill in interactive form fields.</param-desc>
 </param>
 <param>
  <param-def>p_canprint boolean default false</param-def>
  <param-desc>Print the document to a representation from which a faithful digital copy
  of the PDF content could be generated.</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyprintresolution boolean default false</param-def>
  <param-desc>The user is not allowed to print in highest quality.</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function PublicKeyEncrypt128(
  p_inputfile blob,
  p_certfile blob,
  p_canassemble boolean default false,
  p_canextractcontent boolean default false,
  p_canextractforaccessibility boolean default false,
  p_canfillinform boolean default false,
  p_canmodify boolean default false,
  p_canmodifyannotations boolean default false,
  p_canprint boolean default false,
  p_canmodifyprintresolution boolean default false
  ) return blob;

/**
<h2>Decrypt</h2>
<type>Function</type>
<desc>
  Decrypt an encrypted (40 or 128 bits) PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 </params>
<return>
  <return-def>blob</return-def>
  <return-desc>result PDF document</return-desc>
</return>
*/
function Decrypt(
  p_inputfile blob,
  p_password varchar2
  ) return blob;

/**
<h2>PublicKeyDecrypt</h2>
<type>Function</type>
<desc>
  Decrypt an encrypted (40 or 128 bits with certificate) PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_certfile blob</param-def>
  <param-desc>the certificate file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the password to the certificate file</param-desc>
 </param>
 </params>
<return>
  <return-def>blob</return-def>
  <return-desc>result PDF document</return-desc>
</return>
*/
function PublicKeyDecrypt(
  p_inputfile blob,
  p_certFile blob,
  p_password varchar2
  ) return blob;

/**
<h2>conv</h2>
<type>Function</type>
<desc>
  Util function for convert a measure to point (pt).
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_mes number</param-def>
  <param-desc>original measure</param-desc>
  <param-ul>
   <param-li>pt: point</param-li>
   <param-li>mm: millimeter</param-li>
   <param-li>cm: centimeter</param-li>
   <param-li>in: inch</param-li>
  </param-ul>
 </param>
 <param>
  <param-def>p_unit varchar2</param-def>
  <param-desc>original unit of measure</param-desc>
 </param>
</params>
<return>
 <return-def>number</return-def>
 <return-desc>measure in point</return-desc>
</return>
*/
function conv(
  p_mes number,
  p_unit varchar2   --pt,mm,cm,in
  ) return number;  --pt

/**
<h2>ExtractText</h2>
<type>Function</type>
<desc>
  Extract text content of any PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_encoding varchar2 default null</param-def>
  <param-desc>encoding of result text file (case-sensitive) see <a>http://java.sun.com/j2se/1.4.2/docs/guide/intl/encoding.doc.html</a>
  </param-desc>
 </param>
 <param>
  <param-def>p_startPage number default null</param-def>
  <param-desc>the start page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_endPage number default null</param-def>
  <param-desc>the end page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result TEXT document</return-desc>
</return>
*/
function ExtractText(
  p_inputfile blob,
  p_encoding varchar2 default null,
  p_startPage number default null,
  p_endPage number default null,
  p_password varchar2 default null
  ) return blob;

/**
<h2>Merge</h2>
<type>Function</type>
<desc>
Merge two PDF documents to a new file.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile1 blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_inputfile2 blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password1 varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_password2 varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function Merge(
  p_inputfile1 blob,
  p_inputfile2 blob,
  p_password1 varchar2 default null,
  p_password2 varchar2 default null
  ) return blob;

/**
<h2>MergeX</h2>
<type>Function</type>
<desc>
Merge PDF documents to a new file.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfiles t_merge_inputs</param-def>
  <param-desc>source PDF files</param-desc>
 </param>
 <param>
  <param-def>p_x number default 0</param-def>
  <param-desc>X coordinate (top left) for the numbering, -1:center, -2: right
   (unit in plpdf_toolkit_par.GetDefaultUOM function)</param-desc>
 </param>
 <param>
  <param-def>p_y number default 0</param-def>
  <param-desc>Y coordinate (top left) for the numbering, -1:center, -2: bottom
   (unit in plpdf_toolkit_par.GetDefaultUOM function)</param-desc>
 </param>
 <param>
  <param-def> p_font t_14font</param-def>
  <param-desc>Standard Base 14 Font</param-desc>
 </param>
 <param>
  <param-def> p_fontSize number</param-def>
  <param-desc> font size in point</param-desc>
 </param>
 <param>
  <param-def> p_color t_color default null</param-def>
  <param-desc>color of text
   see <a>http://www.forret.com/tools/color_palette.asp</a>
  </param-desc>
 </param>
 <param>
  <param-def>p_startNumber number default 1</param-def>
  <param-desc>Start number of the page numbering</param-desc>
 </param>
 <param>
  <param-def>p_beginNumber number default 1</param-def>
  <param-desc>Start page index from which you want to start the page numbering</param-desc>
 </param>
 <param>
  <param-def>p_nbAlias varchar2 default null</param-def>
  <param-desc>Page number alias, example 'nb'</param-desc>
 </param>
 <param>
  <param-def>p_cpAlias varchar2 default null</param-def>
  <param-desc>Current page number alias, example 'cp'</param-desc>
 </param>
 <param>
  <param-def>p_format varchar2 default null</param-def>
  <param-desc>Page numbering format, example 'cp / nb'</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function MergeX(
  p_inputfiles t_merge_inputs,
  p_x number default 0, -- -1:center, -2:right
  p_y number default 0, -- -1:center, -2: bottom
  p_font t_14font,
  p_fontSize number,
  p_color t_color default null,
  p_startNumber number default 1,
  p_beginNumber number default 1,
  p_nbAlias varchar2 default null,--LL20110920
  p_cpAlias varchar2 default null, --LL20110920
  p_format varchar2 default null  --LL20110920
  ) return blob;

/**
<h2>MergeX</h2>
<type>Function</type>
<desc>
Merge PDF documents to a new file. PDF files stored in plpdf_tk_merge_inputs table.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_tr_id number</param-def>
  <param-desc>Transaction ID of the source PDF files</param-desc>
 </param>
 <param>
  <param-def>p_x number default 0</param-def>
  <param-desc>X coordinate (top left) for the numbering, -1:center, -2: right
   (unit in plpdf_toolkit_par.GetDefaultUOM function)</param-desc>
 </param>
 <param>
  <param-def>p_y number default 0</param-def>
  <param-desc>Y coordinate (top left) for the numbering, -1:center, -2: bottom
   (unit in plpdf_toolkit_par.GetDefaultUOM function)</param-desc>
 </param>
 <param>
  <param-def> p_font t_14font</param-def>
  <param-desc>Standard Base 14 Font</param-desc>
 </param>
 <param>
  <param-def> p_fontSize number</param-def>
  <param-desc> font size in point</param-desc>
 </param>
 <param>
  <param-def> p_color t_color default null</param-def>
  <param-desc>color of text
   see <a>http://www.forret.com/tools/color_palette.asp</a>
  </param-desc>
 </param>
 <param>
  <param-def>p_startNumber number default 1</param-def>
  <param-desc>Start number of the page numbering</param-desc>
 </param>
 <param>
  <param-def>p_beginNumber number default 1</param-def>
  <param-desc>Start page index from which you want to start the page numbering</param-desc>
 </param>
 <param>
  <param-def>p_nbAlias varchar2 default null</param-def>
  <param-desc>Page number alias, example 'nb'</param-desc>
 </param>
 <param>
  <param-def>p_cpAlias varchar2 default null</param-def>
  <param-desc>Current page number alias, example 'cp'</param-desc>
 </param>
 <param>
  <param-def>p_format varchar2 default null</param-def>
  <param-desc>Page numbering format, example 'cp / nb'</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function MergeX(
  p_tr_id number,
  p_x number default 0, -- -1:center, -2:right
  p_y number default 0, -- -1:center, -2: bottom
  p_font t_14font,
  p_fontSize number,
  p_color t_color default null,
  p_startNumber number default 1,
  p_beginNumber number default 1,
  p_nbAlias varchar2 default null,
  p_cpAlias varchar2 default null,
  p_format varchar2 default null
  ) return blob;

--20170605
function MergeXTOC(
  p_tr_id number,
  p_pageNum number,
  p_x number,
  p_y number,
  p_tocItemHeight number,
  p_tocItemWidth number,
  p_tocSeparator varchar2,
  p_font t_14font,
  p_fontSize number,
  p_color t_color default null
  ) return blob;

/**
<h2>MergeEncrypt128</h2>
<type>Function</type>
<desc>
  Merge two PDF files and encrypt using standard PDF 128 RC4 bit encryption.
</desc>
<version>v2.0.5</version>
<params>
 <param>
  <param-def>p_inputfile1 blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_inputfile2 blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password1 varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_password2 varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_opassword varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_upassword varchar2 default null</param-def>
  <param-desc>the user password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_canassemble boolean default false</param-def>
  <param-desc>The user is allowed to assemble the document
   (insert, rotate, or delete pages and create bookmarks or thumbnail images).
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractcontent boolean default false</param-def>
  <param-desc>The user is allowed to copy or otherwise
    extract text and graphics from the document.
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractforaccessibility boolean default false</param-def>
  <param-desc>The user is allowed to extract text and graphics
   (in support of accessibility to disabled users or for other purposes).
  </param-desc>
 </param>
 <param>
  <param-def>p_canfillinform boolean default false</param-def>
  <param-desc>The user is allowed to fill in existing interactive form fields
   (including signature fields)
  </param-desc>
 </param>
 <param>
  <param-def>p_canmodify boolean default false</param-def>
  <param-desc>The user is allowed to modify the contents of the document</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyannotations boolean default false</param-def>
  <param-desc>Add or modify text annotations, fill in interactive form fields.</param-desc>
 </param>
 <param>
  <param-def>p_canprint boolean default false</param-def>
  <param-desc>Print the document to a representation from which a faithful digital copy
  of the PDF content could be generated.</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyprintresolution boolean default false</param-def>
  <param-desc>The user is not allowed to print in highest quality.</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function MergeEncrypt128(
  p_inputfile1 blob,
  p_inputfile2 blob,
  p_password1 varchar2 default null,
  p_password2 varchar2 default null,
  p_opassword varchar2,
  p_upassword varchar2 default null,
  p_canassemble boolean default false,
  p_canextractcontent boolean default false,
  p_canextractforaccessibility boolean default false,
  p_canfillinform boolean default false,
  p_canmodify boolean default false,
  p_canmodifyannotations boolean default false,
  p_canprint boolean default false,
  p_canmodifyprintresolution boolean default false
  ) return blob;

/**
<h2>ReplaceUrl</h2>
<type>Function</type>
<desc>
  Replace an URL in a PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_oldURI varchar2</param-def>
  <param-desc>original URL</param-desc>
 </param>
 <param>
  <param-def>p_newURI varchar2</param-def>
  <param-desc>new URL</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function ReplaceUrl(
   p_inputfile blob,
   p_oldURI varchar2,
   p_newURI varchar2,
   p_password varchar2 default null
  ) return blob;

/**
<h2>JPGStamp</h2>
<type>Function</type>
<desc>
  Stamp content into a PDF document with a JPG image.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_imagefile blob</param-def>
  <param-desc>JPG image</param-desc>
 </param>
 <param>
  <param-def>p_x number</param-def>
  <param-desc>X coordinate (top left) for the image, -1: center, -2: right
    (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def>p_y number</param-def>
  <param-desc>Y coordinate (top left) for the image, -1: center, -2: bottom
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def>p_width number default -1</param-def>
  <param-desc>Image width, if -1 then the image is displayed in its actual width
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def>p_height number default -1</param-def>
  <param-desc>Image height, if -1 then the image is displayed in its actual height
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def>p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_opacity number default 1</param-def>
  <param-desc>the constant opacity value to be used for the transparent imaging model, opacity vary from 0.0 (no contribution) to 1.0 (maximum contribution)</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function JPGStamp(
  p_inputfile blob,
  p_imagefile blob,
  p_x number,
  p_y number,
  p_width number default -1,
  p_height number default -1,
  p_password varchar2 default null,
  p_opacity number default 1
  ) return blob
;

/**
<h2>JPGWaterMark</h2>
<type>Function</type>
<desc>
  Watermark content into a PDF document with a JPG image.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_imagefile blob</param-def>
  <param-desc>JPG image</param-desc>
 </param>
 <param>
  <param-def> p_x number</param-def>
  <param-desc>X coordinate (top left) for the image, -1:center, -2: right
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_y number</param-def>
  <param-desc>Y coordinate (top left) for the image, -1:center, -2: bottom
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_width number default -1</param-def>
  <param-desc>Image width, if -1 then the image is displayed in its actual width
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_height number default -1</param-def>
  <param-desc>Image height, if -1 then the image is displayed in its actual height
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_opacity number default 1</param-def>
  <param-desc>the constant opacity value to be used for the transparent imaging model, opacity vary from 0.0 (no contribution) to 1.0 (maximum contribution)</param-desc>
 </param>
 </params>
 <return>
  <return-def>blob</return-def>
  <return-desc>result PDF document</return-desc>
 </return>
*/
function JPGWaterMark(
  p_inputfile blob,
  p_imagefile blob,
  p_x number,
  p_y number,
  p_width number default -1,
  p_height number default -1,
  p_password varchar2 default null,
  p_opacity number default 1
  ) return blob;

/**
<h2>MetadataFromXML</h2>
<type>Function</type>
<desc>Set PDF metadata from an XML file.<br/>
  an example XML file:<br/>
  <i>
  &lt;?xml version="1.0" encoding="UTF-8"?&gt;<br/>
  &lt;pdf-metadata&gt;<br/>
  &lt;title&gt;PL/PDF Toolkit - User's Guide&lt;/title&gt;<br/>
  &lt;author&gt;PLPDF&lt;/author&gt;<br/>
  &lt;subject&gt;plpdf toolkit&lt;/subject&gt;<br/>
  &lt;creator&gt;PL/PDF v2.0.0&lt;/creator&gt;<br/>
  &lt;keywords&gt;Oracle PDF&lt;/keywords&gt;<br/>
  &lt;producer&gt;www.plpdf.com&lt;/producer&gt;<br/>
  &lt;createtime&gt;20080903183019&lt;/createtime&gt;<br/>
  &lt;modificationdate&gt;20080904114023&lt;/modificationdate&gt;<br/>
  &lt;/pdf-metadata&gt;<br/>
  </i>
  createtime and modificationdate format are YYYYMMDDHH24MISS
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_xmlfile blob</param-def>
  <param-desc>metadata XML file</param-desc>
 </param>
 <param>
  <param-def> p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function MetadataFromXML(
  p_inputfile blob,
  p_xmlfile blob,
  p_password varchar2 default null
  ) return blob;

/**
<h2>MetadataFromPars</h2>
<type>Function</type>
<desc>
-
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_title varchar2 default null</param-def>
  <param-desc> The document?s title.</param-desc>
 </param>
 <param>
  <param-def> p_author varchar2 default null</param-def>
  <param-desc>The name of the person who created the document.</param-desc>
 </param>
 <param>
  <param-def> p_subject varchar2 default null</param-def>
  <param-desc>The subject of the document.</param-desc>
 </param>
 <param>
  <param-def> p_creator varchar2 default null</param-def>
  <param-desc>If the document was converted to PDF from another format, the
    name of the application (for example, Adobe FrameMaker?) that created the
    original document from which it was converted.
  </param-desc>
 </param>
 <param>
  <param-def> p_keywords varchar2 default null</param-def>
  <param-desc>Keywords associated with the document.</param-desc>
 </param>
 <param>
  <param-def> p_producer varchar2 default null</param-def>
  <param-desc>If the document was converted to PDF from another format, the
   name of the application (for example, Acrobat Distiller) that converted it to PDF.
  </param-desc>
 </param>
 <param>
  <param-def> p_createtime date default null</param-def>
  <param-desc>The date and time the document was created, in human-readable form.</param-desc>
 </param>
 <param>
  <param-def> p_modificationdate date default null</param-def>
  <param-desc>The date and time the document was most recently modified,
   in human-readable form.
  </param-desc>
 </param>
 <param>
  <param-def> p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function MetadataFromPars(
  p_inputfile blob,
  p_title varchar2 default null,
  p_author varchar2 default null,
  p_subject varchar2 default null,
  p_creator varchar2 default null,
  p_keywords varchar2 default null,
  p_producer varchar2 default null,
  p_createtime date default null,
  p_modificationdate date default null,
  p_password varchar2 default null
  ) return blob;

/**
<h2>MetadataToXML</h2>
<type>Function</type>
<desc>
  Extract PDF metadata into an XML file.<br/>
  An example XML file:<br/>
  <i>
  &lt;?xml version="1.0" encoding="UTF-8"?&gt;<br/>
  &lt;pdf-metadata&gt;<br/>
  &lt;title&gt;PL/PDF Toolkit - User's Guide&lt;/title&gt;<br/>
  &lt;author&gt;PLPDF&lt;/author&gt;<br/>
  &lt;subject&gt;plpdf toolkit&lt;/subject&gt;<br/>
  &lt;creator&gt;PL/PDF v2.0.0&lt;/creator&gt;<br/>
  &lt;keywords&gt;Oracle PDF&lt;/keywords&gt;<br/>
  &lt;producer&gt;www.plpdf.com&lt;/producer&gt;<br/>
  &lt;createtime&gt;20080903183019&lt;/createtime&gt;<br/>
  &lt;modificationdate&gt;20080904114023&lt;/modificationdate&gt;<br/>
  &lt;/pdf-metadata&gt;<br/>
  </i>
  createtime and modificationdate format are YYYYMMDDHH24MISS
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result XML document</return-desc>
</return>
*/
function MetadataToXML(
  p_inputfile blob,
  p_password varchar2 default null
  ) return blob;

/**
<h2>MetadataToRecord</h2>
<type>Function</type>
<desc>
 Extract PDF metadata into the t_metadata record.
</desc>
<version>v2.0.0</version>
<params>
<param>
<param-def>p_inputfile blob</param-def>
<param-desc>source PDF file</param-desc>
</param>
<param>
<param-def>p_password varchar2 default null</param-def>
<param-desc>the owner password of the PDF file (if encrypted).</param-desc>
</param>
</params>
<return>
<return-def>t_metadata</return-def>
<return-desc>PDF metadata</return-desc>
</return>
*/
function MetadataToRecord(
  p_inputfile blob,
  p_password varchar2 default null
  ) return t_metadata;

/**
<h2>TextStamp</h2>
<type>Function</type>
<desc>
  Stamp content into a PDF document with a text.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_message</param-def>
  <param-desc>stamp text (encoding: plpdf_toolkit_par.GetDefaultEncoding)</param-desc>
 </param>
 <param>
  <param-def> p_x number</param-def>
  <param-desc>X coordinate (top left) for the image, -1:center, -2: right
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_y number</param-def>
  <param-desc>Y coordinate (top left) for the image, -1:center, -2: bottom
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_font t_14font</param-def>
  <param-desc>Standard Base 14 Font</param-desc>
 </param>
 <param>
  <param-def> p_fontSize number</param-def>
  <param-desc> font size in point</param-desc>
 </param>
 <param>
  <param-def> p_color t_color default null</param-def>
  <param-desc>color of text
   see <a>http://www.forret.com/tools/color_palette.asp</a>
  </param-desc>
 </param>
 <param>
 <param-def> p_password varchar2 default null</param-def>
 <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_startPage number default null</param-def>
  <param-desc>the start page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_endPage number default null</param-def>
  <param-desc>the end page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_rotation number default 0</param-def>
  <param-desc>Text rotation angle</param-desc>
 </param>
 <param>
  <param-def>p_opacity number default 1</param-def>
  <param-desc>the constant opacity value to be used for the transparent imaging model, opacity vary from 0.0 (no contribution) to 1.0 (maximum contribution)</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function TextStamp(
  p_inputfile blob,
  p_message varchar2,
  p_x number,
  p_y number,
  p_font t_14font,
  p_fontSize number,
  p_color t_color default null,
  p_password varchar2 default null,
  p_startPage number default null,
  p_endPage number default null,
  p_rotation number default 0,
  p_opacity number default 1
  ) return blob;

/**
<h2>TextStampTTF</h2>
<type>Function</type>
<desc>
  Stamp content into a PDF document with a text (TTF font type).
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_message</param-def>
  <param-desc>stamp text (encoding: plpdf_toolkit_par.GetDefaultEncoding)</param-desc>
 </param>
 <param>
  <param-def> p_x number</param-def>
  <param-desc>X coordinate (top left) for the image, -1:center, -2: right
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_y number</param-def>
  <param-desc>Y coordinate (top left) for the image, -1:center, -2: bottom
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_font blob</param-def>
  <param-desc>TTF (TrueType Font) file</param-desc>
 </param>
 <param>
  <param-def> p_fontSize number</param-def>
  <param-desc>font size in point</param-desc>
 </param>
 <param>
  <param-def> p_color t_color default null</param-def>
  <param-desc>color of text
   see <a>http://www.forret.com/tools/color_palette.asp</a>
  </param-desc>
 </param>
 <param>
 <param-def> p_password varchar2 default null</param-def>
 <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_startPage number default null</param-def>
  <param-desc>the start page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_endPage number default null</param-def>
  <param-desc>the end page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_rotation number default 0</param-def>
  <param-desc>Text rotation angle</param-desc>
 </param>
 <param>
  <param-def>p_opacity number default 1</param-def>
  <param-desc>the constant opacity value to be used for the transparent imaging model, opacity vary from 0.0 (no contribution) to 1.0 (maximum contribution)</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function TextStampTTF(
  p_inputfile blob,
  p_message varchar2,
  p_x number,
  p_y number,
  p_font blob,
  p_fontSize number,
  p_color t_color default null,
  p_password varchar2 default null,
  p_startPage number default null,
  p_endPage number default null,
  p_rotation number default 0,
  p_opacity number default 1
  ) return blob;

/**
<h2>TextWaterMark</h2>
<type>Function</type>
<desc>
  Watermark content into a PDF document with a text.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_message</param-def>
  <param-desc>watermark text (encoding: plpdf_toolkit_par.GetDefaultEncoding)</param-desc>
 </param>
 <param>
  <param-def> p_x number</param-def>
  <param-desc>X coordinate (top left) for the image, -1:center, -2: right
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_y number</param-def>
  <param-desc>Y coordinate (top left) for the image, -1:center, -2: bottom
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_font t_14font</param-def>
  <param-desc>Standard Base 14 Font</param-desc>
 </param>
 <param>
  <param-def> p_fontSize number</param-def>
  <param-desc>font size in point</param-desc>
 </param>
 <param>
  <param-def> p_color plpdf_type.t_color default null</param-def>
  <param-desc>color of text see <a>http://www.forret.com/tools/color_palette.asp</a></param-desc>
 </param>
 <param>
  <param-def> p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_rotation number default 0</param-def>
  <param-desc>Text rotation angle</param-desc>
 </param>
 <param>
  <param-def>p_opacity number default 1</param-def>
  <param-desc>the constant opacity value to be used for the transparent imaging model, opacity vary from 0.0 (no contribution) to 1.0 (maximum contribution)</param-desc>
 </param>
 <param>
  <param-def>p_reencrypt boolean default false</param-def>
  <param-desc>Reencrypt document if encrypted.</param-desc>
 </param>
 </params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function TextWaterMark(
  p_inputfile blob,
  p_message varchar2,
  p_x number,
  p_y number,
  p_font t_14font,
  p_fontSize number,
  p_color t_color default null,
  p_password varchar2 default null,
  p_rotation number default 0,
  p_opacity number default 1,
  p_reencrypt boolean default false
  ) return blob;

/**
<h2>PDFWatermark</h2>
<type>Function</type>
<desc>
  Overlay on PDF document with another one PDF.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_overlayinputfile blob</param-def>
  <param-desc>overlay PDF file</param-desc>
 </param>
 <param>
  <param-def> p_overlaypassword varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def> p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/

function PDFWatermark(
  p_inputfile blob,
  p_overlayinputfile blob,
  p_password varchar2 default null,
  p_overlaypassword varchar2 default null
  ) return blob;

/**
<name>ExportFDF</name>
<type>Function</type>
<desc>
  Export PDF Form data as an FDF file.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>FDF document</return-desc>
</return>
*/
function ExportFDF(
  p_inputfile blob,
  p_password varchar2 default null
  ) return blob;

/**
<name>ExportXFDF</name>
<type>Function</type>
<desc>
  Export PDF Form data as an XFDF file.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_exportnull boolean default true</param-def>
  <param-desc>export empty fields</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>XFDF document</return-desc>
</return>
*/
function ExportXFDF(
  p_inputfile blob,
  p_password varchar2 default null,
  p_exportnull boolean default true
  ) return blob;

/**
<name>ImportFDF</name>
<type>Function</type>
<desc>
  Import an FDF file into the PDF Form's fields.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_fdffile blob</param-def>
  <param-desc>FDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>FDF document</return-desc>
</return>
*/
function ImportFDF(
  p_inputfile blob,
  p_fdffile blob,
  p_password varchar2 default null
  ) return blob;

/**
<name>ImportXFDF</name>
<type>Function</type>
<desc>
  Import an XFDF file into the PDF Form's fields.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_xfdffile blob</param-def>
  <param-desc>XFDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_needapp boolean default true</param-def>
  <param-desc>Set NeedAppearances option in PDF source.
	When NeedAppearances is true then force compliant PDF readers to render the fields.
	If false then toolkit automatically generates the appearance streams for all form fields.
  </param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>XFDF document</return-desc>
</return>
*/
function ImportXFDF(
  p_inputfile blob,
  p_xfdffile blob,
  p_password varchar2 default null,
  p_needapp boolean default true
  ) return blob;

/**
<h2>ExtractPages</h2>
<type>Function</type>
<desc>
  Extract pages of any PDF document into a new PDF.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_startPage number default null</param-def>
  <param-desc>the start page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_endPage number default null</param-def>
  <param-desc>the end page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function ExtractPages(
  p_inputfile blob,
  p_startPage number default null,
  p_endPage number default null,
  p_password varchar2 default null
  ) return blob;

/**
<h2>GetNumberOfPages</h2>
<type>Function</type>
<desc>
  Get number of pages of any PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>number</return-def>
 <return-desc>number of pages</return-desc>
</return>
*/
function GetNumberOfPages(
  p_inputfile blob,
  p_password varchar2 default null
  ) return number;

/**
<h2>JPGCompress</h2>
<type>Function</type>
<desc>
  Sets the compression quality to a value between 0  and 1 of the JPG images in a PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_compress number</param-def>
  <param-desc>compression quality to a value between 0  and 1</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function JPGCompress(
   p_inputfile blob,
   p_compress number,
   p_password varchar2 default null
  ) return blob;

/**
<h2>DigSign</h2>
<type>Function</type>
<desc>
  Digital sign a PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_keystore blob</param-def>
  <param-desc>keystore file</param-desc>
 </param>
 <param>
  <param-def>p_certAlias varchar2 default null</param-def>
  <param-desc>certificate alias in keystore file, null means first the first alias</param-desc>
 </param>
 <param>
  <param-def>p_keystorePassword varchar2 default null</param-def>
  <param-desc>password of keystore</param-desc>
 </param>
 <param>
  <param-def>p_privkeyPassword varchar2 default null</param-def>
  <param-desc>password of private key</param-desc>
 </param>
 <param>
   <param-def>p_Name varchar2 default null</param-def>
   <param-desc>The name of the person or authority signing the document.</param-desc>
  </param>
  <param>
   <param-def>p_Location varchar2 default null</param-def>
   <param-desc>The CPU host name or physical location of the signing.</param-desc>
  </param>
  <param>
   <param-def>p_Reason varchar2 default null</param-def>
   <param-desc>The reason for the signing, such as (I agree?).</param-desc>
  </param>
  <param>
   <param-def>p_ContactInfo varchar2 default null</param-def>
   <param-desc>Information provided by the signer to allow a recipient to contact the signer to verify the signature; for example, a phone number.</param-desc>
  </param>
  <param>
   <param-def>p_page number default 0</param-def>
   <param-desc>page number of digital signature's postion </param-desc>
  </param>
  <param>
   <param-def>p_x number default 0</param-def>
   <param-desc>X coordinate for the top left corner of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_y number default 0</param-def>
   <param-desc>Y coordinate for the top left corner of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_w number default 0</param-def>
   <param-desc>The width of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_h number default 0</param-def>
   <param-desc>The height of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_access_perms</param-def>
   <param-desc>The access permissions granted for this document. Defined values are:</param-desc>
   <param-ul>
     <param-li>1: No changes to the document are permitted; any change to the document invalidates the signature.</param-li>
     <param-li>2: Permitted changes are filling in forms, instantiating page templates, and signing; other changes invalidate the signature.</param-li>
     <param-li>3: Permitted changes are those allowed by 2, as well as annotation creation, deletion, and modification; other changes invalidate the signature.</param-li>
    </param-ul>
  </param>
 <param>
  <param-def>p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function DigSign(
   p_inputfile blob,
   p_keystore blob,
   p_certAlias varchar2 default null,
   p_keystorePassword varchar2 default null,
   p_privkeyPassword varchar2 default null,
   p_Name varchar2 default null,
   p_Location varchar2 default null,
   p_Reason varchar2 default null,
   p_ContactInfo varchar2 default null,
   p_page number default 0,
   p_x number default 0,
   p_y number default 0,
   p_width number default 0,
   p_height number default 0,
   p_accessPerms number default 1,
   p_password varchar2  default null
  ) return blob;

/**
<h2>DigSignEncrypt</h2>
<type>Function</type>
<desc>
  Digital sign and encrypt a PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_keystore blob</param-def>
  <param-desc>keystore file</param-desc>
 </param>
 <param>
  <param-def>p_certAlias varchar2 default null</param-def>
  <param-desc>certificate alias in keystore file, null means first the first alias</param-desc>
 </param>
 <param>
  <param-def>p_keystorePassword varchar2 default null</param-def>
  <param-desc>password of keystore</param-desc>
 </param>
 <param>
  <param-def>p_privkeyPassword varchar2 default null</param-def>
  <param-desc>password of private key</param-desc>
 </param>
 <param>
   <param-def>p_Name varchar2 default null</param-def>
   <param-desc>The name of the person or authority signing the document.</param-desc>
  </param>
  <param>
   <param-def>p_Location varchar2 default null</param-def>
   <param-desc>The CPU host name or physical location of the signing.</param-desc>
  </param>
  <param>
   <param-def>p_Reason varchar2 default null</param-def>
   <param-desc>The reason for the signing, such as (I agree?).</param-desc>
  </param>
  <param>
   <param-def>p_ContactInfo varchar2 default null</param-def>
   <param-desc>Information provided by the signer to allow a recipient to contact the signer to verify the signature; for example, a phone number.</param-desc>
  </param>
  <param>
   <param-def>p_page number default 0</param-def>
   <param-desc>page number of digital signature's postion </param-desc>
  </param>
  <param>
   <param-def>p_x number default 0</param-def>
   <param-desc>X coordinate for the top left corner of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_y number default 0</param-def>
   <param-desc>Y coordinate for the top left corner of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_w number default 0</param-def>
   <param-desc>The width of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_h number default 0</param-def>
   <param-desc>The height of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_access_perms</param-def>
   <param-desc>The access permissions granted for this document. Defined values are:</param-desc>
   <param-ul>
     <param-li>1: No changes to the document are permitted; any change to the document invalidates the signature.</param-li>
     <param-li>2: Permitted changes are filling in forms, instantiating page templates, and signing; other changes invalidate the signature.</param-li>
     <param-li>3: Permitted changes are those allowed by 2, as well as annotation creation, deletion, and modification; other changes invalidate the signature.</param-li>
    </param-ul>
  </param>
 <param>
  <param-def>p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_opassword varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_upassword varchar2 default null</param-def>
  <param-desc>the user password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_canassemble boolean default false</param-def>
  <param-desc>The user is allowed to assemble the document
   (insert, rotate, or delete pages and create bookmarks or thumbnail images).
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractcontent boolean default false</param-def>
  <param-desc>The user is allowed to copy or otherwise
    extract text and graphics from the document.
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractforaccessibility boolean default false</param-def>
  <param-desc>The user is allowed to extract text and graphics
   (in support of accessibility to disabled users or for other purposes).
  </param-desc>
 </param>
 <param>
  <param-def>p_canfillinform boolean default false</param-def>
  <param-desc>The user is allowed to fill in existing interactive form fields
   (including signature fields)
  </param-desc>
 </param>
 <param>
  <param-def>p_canmodify boolean default false</param-def>
  <param-desc>The user is allowed to modify the contents of the document</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyannotations boolean default false</param-def>
  <param-desc>Add or modify text annotations, fill in interactive form fields.</param-desc>
 </param>
 <param>
  <param-def>p_canprint boolean default false</param-def>
  <param-desc>Print the document to a representation from which a faithful digital copy
  of the PDF content could be generated.</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyprintresolution boolean default false</param-def>
  <param-desc>The user is not allowed to print in highest quality.</param-desc>
 </param>
 <param>
  <param-def>p_algorithm varchar2 default 'RC4'</param-def>
  <param-desc>The encryption algorithm, possible values are RC4 and AES</param-desc>
 </param>
 <param>
  <param-def>p_keylength number default 40</param-def>
  <param-desc>The encryption key length in bit, possible values are 40 and 128</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function DigSignEncrypt(
   p_inputfile blob,
   p_keystore blob,
   p_certAlias varchar2 default null,
   p_keystorePassword varchar2 default null,
   p_privkeyPassword varchar2 default null,
   p_name varchar2 default null,
   p_location varchar2 default null,
   p_reason varchar2 default null,
   p_contactInfo varchar2 default null,
   p_page number default 0,
   p_x number default 0,
   p_y number default 0,
   p_width number default 0,
   p_height number default 0,
   p_accessPerms number default 1,
   p_password varchar2 default null,
   p_opassword varchar2,
   p_upassword varchar2 default null,
   p_canassemble boolean default false,
   p_canextractcontent boolean default false,
   p_canextractforaccessibility boolean default false,
   p_canfillinform boolean default false,
   p_canmodify boolean default false,
   p_canmodifyannotations boolean default false,
   p_canprint boolean default false,
   p_canmodifyprintresolution boolean default false, --v1.8.0
   p_algorithm varchar2 default 'RC4',
   p_keylength number default 40
  ) return blob;

/**
<h2>Rebuild</h2>
<type>Function</type>
<desc>
  Rebuild any PDF document into a new PDF.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function Rebuild(
  p_inputfile blob,
  p_password varchar2 default null
  ) return blob;

/**
<name>Get_Version</name>
<type>Function</type>
<desc>
  Get version number of the toolkit.
</desc>
<version>v2.0.0</version>
<return>
 <return-def>varchar2</return-def>
 <return-desc>version number</return-desc>
</return>
*/
function get_Version return varchar2;

/**
<name>Get_VersionDate</name>
<type>Function</type>
<desc>
  Get release date of the toolkit.
</desc>
<version>v2.0.0</version>
<return>
 <return-def>varchar2</return-def>
 <return-desc>release date</return-desc>
</return>
*/
function get_VersionDate return varchar2;


/**
<h2>setFieldsReadonly</h2>
<type>Function</type>
<desc>
  Set the PDF form fields to read-only.
</desc>
<version>v2.0.1</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function setFieldsReadonly(
  p_inputfile blob,
  p_password varchar2 default null
  ) return blob;


/**
<h2>getPDFACompliant</h2>
<type>Function</type>
<desc>
  Get the PDF/A Compliant information.
</desc>
<version>v2.0.1</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>The Compliant info</return-def>
 <return-desc>Format is part + conf, example 1B</return-desc>
</return>
*/
function getPDFACompliant(
  p_inputfile blob,
  p_password varchar2 default null
  ) return varchar2;

-- end of package

-------------------------------------------------------
/**
 <newpage/>
 <h1>Version History</h1>
 <br/>
 */
-------------------------------------------------------

/**
 <h2>03-DEC-2012, v1.7.0</h2>
 <p>- JPGStamp: new parameter: p_opacity</p>
 <p>- JPGWaterMark: new parameter: p_opacity</p>
 <p>- TextStamp: new parameter: p_opacity</p>
 <p>- TextWaterMark: new parameter: p_opacity</p>
 <h2>01-FEB-2013, v1.8.0</h2>
 <p>- code optimalization</p>
 <h2>01-OKT-2013, v2.0.0</h2>
 <p>- code optimalization (Oracle 11g)</p>
 <p>- new function: TextStampTTF</p>
 <p>- Encrypt128: parameter rename: old name: p_canprintdegraded, new name: p_canmodifyprintresolution</p>
 <p>- AESEncrypt128: parameter rename: old name: p_canprintdegraded, new name: p_canmodifyprintresolution</p>
 <p>- PublicKeyEncrypt128: parameter rename: old name: p_canprintdegraded, new name: p_canmodifyprintresolution</p>
 <p>- JPGStamp: top-left origin coordinate system, p_y:=-2 is bottom Y coordinate</p>
 <p>- JPGWatermark: top-left origin coordinate system, p_y:=-2 is bottom Y coordinate</p>
 <p>- TextStamp: top-left origin coordinate system, p_y:=-2 is bottom Y coordinate</p>
 <p>- TextStampTTF: top-left origin coordinate system, p_y:=-2 is bottom Y coordinate</p>
 <p>- TextWatermark: top-left origin coordinate system, p_y:=-2 is bottom Y coordinate</p>
 <p>- DigSign: top-left origin coordinate system</p>
 <p>- DigSignEncrypt: top-left origin coordinate system</p>
 <h2>18-DEC-2013, v2.0.0</h2>
 <p>- new function: get_Version</p>
 <p>- new function: get_VersionDate</p>
 <p>- ImportXFDF: new parameter: p_needapp</p>
 <p>- TextWaterMark: new parameter: p_reencrypt</p>
*/

end;
/

CREATE OR REPLACE PACKAGE BODY plpdf_toolkit wrapped 
a000000
aa
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
b
f87f 7900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/
