create or replace package plx_sc is
  /* XML Simple Composer */

  --types
  subtype maxv2 is varchar2(32767 char);
  subtype normalv2 is varchar2(255 char);
  type type_attrs is table of maxv2 index by normalv2;
  type type_xdoc is record(
    clobvar   clob,
    buffervar maxv2
    );
  type type_pck is table of type_xdoc index by pls_integer;

  -- variables
  v_newline varchar2(2 char) := chr(13) || chr(10);
  v_pck            type_pck;
  v_doc_index      pls_integer := 0;
  v_xml_version    normalv2 := '1.0';
  v_xml_encoding   normalv2 := 'UTF-8';
  v_xml_standalone normalv2 := null;

  -- constants
  c_ns_sep constant varchar2(1 char) := ':';
  c_xmlns  constant normalv2 := 'xmlns';

  -- procedures
  procedure setNewLine(p_nl varchar2);
  --
  procedure setdefXmlVersion(p_version varchar2);
  --
  procedure setdefXmlEncoding(p_encoding varchar2);
  --
  procedure setdefXmlStandalone(p_standalone varchar2);
  --
  function getheadertext(p_version    varchar2,
                         p_encoding   varchar2,
                         p_standalone varchar2) return varchar2;
  --
  procedure addAttribute(p_attrs in out nocopy type_attrs,
                         p_name  varchar2,
                         p_value varchar2);
  --
  procedure addAttributewNS(p_attrs     in out nocopy type_attrs,
                            p_namespace varchar2,
                            p_name      varchar2,
                            p_value     varchar2);
  --
  procedure addNameSpace(p_attrs in out nocopy type_attrs,
                         p_name  varchar2 default null,
                         p_value varchar2);
  /**************************************************************/
  -- CLOB as XML container
  procedure addtext(p_doc in out nocopy clob, p_text varchar2);
  --
  procedure addline(p_doc in out nocopy clob, p_text varchar2);
  --
  procedure startDocument(p_doc in out nocopy clob);
  --
  procedure startDocumentwHeader(p_doc        in out nocopy clob,
                                 p_version    varchar2 default null,
                                 p_encoding   varchar2 default null,
                                 p_standalone varchar2 default null);
  --
  procedure endDocument(p_doc in out nocopy clob);
  --
  procedure startElement(p_doc   in out nocopy clob,
                         p_tag   varchar2,
                         p_attrs type_attrs,
                         p_close boolean default false);
  --
  procedure startElementwNS(p_doc       in out nocopy clob,
                            p_namespace varchar2,
                            p_tag       varchar2,
                            p_attrs     type_attrs,
                            p_close     boolean default false);
  --
  procedure startElement(p_doc   in out nocopy clob,
                         p_tag   varchar2,
                         p_close boolean default false);
  --
  procedure startElementwNS(p_doc       in out nocopy clob,
                            p_namespace varchar2,
                            p_tag       varchar2,
                            p_close     boolean default false);
  --
  procedure endElement(p_doc in out nocopy clob, p_tag varchar2);
  --
  procedure endElementwNS(p_doc       in out nocopy clob,
                          p_namespace varchar2,
                          p_tag       varchar2);
  --
  procedure characters(p_doc in out nocopy clob, p_chars varchar2);
  --
  function getXML(p_doc in out nocopy clob) return sys.xmltype;
  --
  procedure getXMLBLOB(p_doc     in out nocopy clob,
                       p_blob    out nocopy blob,
                       p_charset varchar2 default 'UTF8');
  --
  procedure getBLOB(p_doc     in out nocopy clob,
                    p_blob    out nocopy blob,
                    p_charset varchar2 default 'UTF8');
  --
  /**************************************************************/
  -- XDOC as XML container
  procedure addtext(p_doc in out nocopy type_xdoc, p_text varchar2);
  --
  procedure addline(p_doc in out nocopy type_xdoc, p_text varchar2);
  --
  procedure startDocument(p_doc in out nocopy type_xdoc);
  --
  procedure startDocumentwHeader(p_doc        in out nocopy type_xdoc,
                                 p_version    varchar2 default null,
                                 p_encoding   varchar2 default null,
                                 p_standalone varchar2 default null);
  --
  procedure endDocument(p_doc in out nocopy type_xdoc);
  --
  procedure startElement(p_doc   in out nocopy type_xdoc,
                         p_tag   varchar2,
                         p_attrs type_attrs,
                         p_close boolean default false);
  --
  procedure startElementwNS(p_doc       in out nocopy type_xdoc,
                            p_namespace varchar2,
                            p_tag       varchar2,
                            p_attrs     type_attrs,
                            p_close     boolean default false);
  --
  procedure startElement(p_doc   in out nocopy type_xdoc,
                         p_tag   varchar2,
                         p_close boolean default false);
  --
  procedure startElementwNS(p_doc       in out nocopy type_xdoc,
                            p_namespace varchar2,
                            p_tag       varchar2,
                            p_close     boolean default false);
  --
  procedure endElement(p_doc in out nocopy type_xdoc, p_tag varchar2);
  --
  procedure endElementwNS(p_doc       in out nocopy type_xdoc,
                          p_namespace varchar2,
                          p_tag       varchar2);
  --
  procedure characters(p_doc in out nocopy type_xdoc, p_chars varchar2);
  --
  function getXML(p_doc in out nocopy type_xdoc) return sys.xmltype;
  --
  procedure getXMLBLOB(p_doc     in out nocopy type_xdoc,
                       p_blob    out nocopy blob,
                       p_charset varchar2 default 'UTF8');
  --
  procedure getBLOB(p_doc     in out nocopy type_xdoc,
                    p_blob    out nocopy blob,
                    p_charset varchar2 default 'UTF8');
  --
  /**************************************************************/
  -- PCK package as XML container
  procedure InitPackage;
  --
  procedure addtext(p_id pls_integer, p_text varchar2);
  --
  procedure addline(p_id pls_integer, p_text varchar2);
  --
  function startDocument return pls_integer;
  --
  function startDocumentwHeader(p_version    varchar2 default null,
                                p_encoding   varchar2 default null,
                                p_standalone varchar2 default null)
    return pls_integer;
  --
  procedure endDocument(p_id pls_integer);
  --
  procedure startElement(p_id    pls_integer,
                         p_tag   varchar2,
                         p_attrs type_attrs,
                         p_close boolean default false);
  --
  procedure startElementwNS(p_id        pls_integer,
                            p_namespace varchar2,
                            p_tag       varchar2,
                            p_attrs     type_attrs,
                            p_close     boolean default false);
  --
  procedure startElement(p_id    pls_integer,
                         p_tag   varchar2,
                         p_close boolean default false);
  --
  procedure startElementwNS(p_id        pls_integer,
                            p_namespace varchar2,
                            p_tag       varchar2,
                            p_close     boolean default false);
  --
  procedure endElement(p_id pls_integer, p_tag varchar2);
  --
  procedure endElementwNS(p_id        pls_integer,
                          p_namespace varchar2,
                          p_tag       varchar2);
  --
  procedure characters(p_id pls_integer, p_chars varchar2);
  --
  function getXML(p_id pls_integer) return sys.xmltype;
  --
  procedure getXMLBLOB(p_id      pls_integer,
                       p_blob    out nocopy blob,
                       p_charset varchar2 default 'UTF8');
  --
  procedure getBLOB(p_id      pls_integer,
                    p_blob    out nocopy blob,
                    p_charset varchar2 default 'UTF8');
  /**************************************************************/
  -- utils
  function str2cp(p_str varchar2) return varchar2;
  --
  function replacetags(p_str varchar2) return varchar2;
  --
  function xmlascii(p_str varchar2) return varchar2;
  --
  function num2char(p_number number,
                    p_digits number default null,
                    p_round  boolean default false) return varchar2;
  -- xsd:dateTime: [-]CCYY-MM-DDThh:mm:ss[Z|(+|-)hh:mm]
  function date2dateTime2char(p_date date) return varchar2;
  -- xsd:long
  function num2long2char(p_number number) return varchar2;
  --
end plx_sc;
/

create or replace package body plx_sc wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
b
9200000
1
4
0 
98
2 :e:
1PACKAGE:
1BODY:
1PLX_SC:
1SETNEWLINE:
1P_NL:
1VARCHAR2:
1V_NEWLINE:
1SETDEFXMLVERSION:
1P_VERSION:
1V_XML_VERSION:
1SETDEFXMLENCODING:
1P_ENCODING:
1V_XML_ENCODING:
1SETDEFXMLSTANDALONE:
1P_STANDALONE:
1V_XML_STANDALONE:
1FUNCTION:
1GETHEADERTEXT:
1RETURN:
1L_RET:
1CHAR:
1255:
1<?xml:
1IS NOT NULL:
1||:
1 version=":
1":
1ELSIF:
1 encoding=":
1 standalone=":
1?>:
1ADDATTRIBUTE:
1P_ATTRS:
1OUT:
1NOCOPY:
1TYPE_ATTRS:
1P_NAME:
1P_VALUE:
1ADDATTRIBUTEWNS:
1P_NAMESPACE:
1C_NS_SEP:
1ADDNAMESPACE:
1C_XMLNS:
1ADDTEXT:
1P_DOC:
1CLOB:
1P_TEXT:
1ADDLINE:
1STARTDOCUMENT:
1:
1STARTDOCUMENTWHEADER:
1ENDDOCUMENT:
1STARTELEMENT:
1P_TAG:
1P_CLOSE:
1BOOLEAN:
1FALSE:
1L_NM:
1NORMALV2:
1L_VAL:
1MAXV2:
1<:
1FIRST:
1LOOP:
1IS NULL:
1EXIT:
1 :
1=":
1NEXT:
1/:
1>:
1STARTELEMENTWNS:
1L_TAG:
1ENDELEMENT:
1</:
1ENDELEMENTWNS:
1CHARACTERS:
1P_CHARS:
1GETXML:
1SYS:
1XMLTYPE:
1GETXMLBLOB:
1P_BLOB:
1BLOB:
1P_CHARSET:
1UTF8:
1L_XML:
1DBMS_LOB:
1CREATETEMPORARY:
1CACHE:
1TRUE:
10:
1GETBLOBVAL:
1NLS_CHARSET_ID:
1GETBLOB:
1L_IN:
1PLS_INTEGER:
11:
1L_OUT:
1L_LANG:
1L_WARNING:
1CONVERTTOBLOB:
1GETLENGTH:
1TYPE_XDOC:
1BUFFERVAR:
1VALUE_ERROR:
1CLOBVAR:
1INITPACKAGE:
1V_PCK:
1DELETE:
1V_DOC_INDEX:
1P_ID:
1+:
1STR2CP:
1P_STR:
1REGEXP_REPLACE:
1ASCIISTR:
1(\\)([[::xdigit::]][[::xdigit::]][[::xdigit::]][[::xdigit::]]):
1&#x\2;:
1REPLACETAGS:
1REPLACE:
1&:
1&#x0026;:
1&#x0022;:
1':
1&#x0027;:
1&#x003C;:
1&#x003E;:
1XMLASCII:
1NUM2CHAR:
1P_NUMBER:
1NUMBER:
1P_DIGITS:
1P_ROUND:
1L_NLS:
140:
1NLS_NUMERIC_CHARACTERS = '.,' :
1L_NUM:
1ROUND:
1TRUNC:
1TO_CHAR:
1TM9:
1SUBSTR:
1=:
1.:
1DATE2DATETIME2CHAR:
1P_DATE:
1DATE:
1YYYY-MM-DD:
1T:
1HH24::MI::SS:
1NUM2LONG2CHAR:
0

0
0
be8
2
0 :2 a0 97 9a 8f a0 b0 3d
b4 55 6a :2 a0 d b7 a4 b1
11 68 4f 9a 8f a0 b0 3d
b4 55 6a :2 a0 d b7 a4 b1
11 68 4f 9a 8f a0 b0 3d
b4 55 6a :2 a0 d b7 a4 b1
11 68 4f 9a 8f a0 b0 3d
b4 55 6a :2 a0 d b7 a4 b1
11 68 4f a0 8d 8f a0 b0
3d 8f a0 b0 3d 8f a0 b0
3d b4 :2 a0 2c 6a a3 :2 a0 51
a5 1c 81 b0 a0 6e d a0
7e b4 2e :2 a0 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
d a0 b7 a0 7e b4 2e :2 a0
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e d b7 :2 19 3c
a0 7e b4 2e :2 a0 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e d a0 b7 a0 7e b4 2e
:2 a0 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e d b7 :2 19
3c a0 7e b4 2e :2 a0 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e d a0 b7 a0 7e b4
2e :2 a0 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e d b7
:2 19 3c :2 a0 7e 6e b4 2e d
:2 a0 65 b7 a4 b1 11 68 4f
9a 90 :3 a0 b0 3f 8f a0 b0
3d 8f a0 b0 3d b4 55 6a
a0 7e b4 2e :2 a0 a5 b a0
d b7 19 3c b7 a4 b1 11
68 4f 9a 90 :3 a0 b0 3f 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d b4 55 6a a0 7e
b4 2e a0 7e b4 2e :2 a0 7e
a0 b4 2e 7e a0 b4 2e a5
b a0 d b7 :2 a0 a5 b a0
d b7 :2 19 3c b7 19 3c b7
a4 b1 11 68 4f 9a 90 :3 a0
b0 3f 8f a0 4d b0 3d 8f
a0 b0 3d b4 55 6a a0 7e
b4 2e a0 7e b4 2e :2 a0 7e
a0 b4 2e 7e a0 b4 2e a5
b a0 d b7 :2 a0 a5 b a0
d b7 :2 19 3c b7 19 3c b7
a4 b1 11 68 4f 9a 90 :3 a0
b0 3f 8f a0 b0 3d b4 55
6a :2 a0 7e a0 b4 2e d b7
a4 b1 11 68 4f 9a 90 :3 a0
b0 3f 8f a0 b0 3d b4 55
6a :2 a0 7e a0 b4 2e 7e a0
b4 2e d b7 a4 b1 11 68
4f 9a 90 :3 a0 b0 3f b4 55
6a a0 6e d b7 a4 b1 11
68 4f 9a 90 :3 a0 b0 3f 8f
a0 4d b0 3d 8f a0 4d b0
3d 8f a0 4d b0 3d b4 55
6a :5 a0 a5 b d b7 a4 b1
11 68 4f 9a 90 :3 a0 b0 3f
b4 55 6a 4f b7 a4 b1 11
68 4f 9a 90 :3 a0 b0 3f 8f
a0 b0 3d 8f a0 b0 3d 8f
:2 a0 b0 3d b4 55 6a a3 a0
1c 81 b0 a3 a0 1c 81 b0
:2 a0 6e 7e a0 b4 2e a5 57
:3 a0 6b d :2 a0 7e b4 2e a0
2b b7 19 3c :3 a0 a5 b d
:2 a0 6e 7e a0 b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 :3 a0 6b a0 a5
b d b7 a0 47 :3 a0 6e a5
57 b7 19 3c :2 a0 6e a5 57
b7 a4 b1 11 68 4f 9a 90
:3 a0 b0 3f 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
:2 a0 b0 3d b4 55 6a a3 a0
1c 81 b0 a0 7e b4 2e :2 a0
7e a0 b4 2e 7e a0 b4 2e
d b7 :2 a0 d b7 :2 19 3c :3 a0
e :2 a0 e :2 a0 e :2 a0 e a5
57 b7 a4 b1 11 68 4f 9a
90 :3 a0 b0 3f 8f a0 b0 3d
8f :2 a0 b0 3d b4 55 6a :2 a0
6e 7e a0 b4 2e a5 57 :3 a0
6e a5 57 b7 19 3c :2 a0 6e
a5 57 b7 a4 b1 11 68 4f
9a 90 :3 a0 b0 3f 8f a0 b0
3d 8f a0 b0 3d 8f :2 a0 b0
3d b4 55 6a a3 a0 1c 81
b0 a0 7e b4 2e :2 a0 7e a0
b4 2e 7e a0 b4 2e d b7
:2 a0 d b7 :2 19 3c :3 a0 e :2 a0
e :2 a0 e a5 57 b7 a4 b1
11 68 4f 9a 90 :3 a0 b0 3f
8f a0 b0 3d b4 55 6a :2 a0
6e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 a4 b1 11 68
4f 9a 90 :3 a0 b0 3f 8f a0
b0 3d 8f a0 b0 3d b4 55
6a a0 7e b4 2e :2 a0 6e 7e
a0 b4 2e 7e a0 b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 :2 a0 6e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 :2 19
3c b7 a4 b1 11 68 4f 9a
90 :3 a0 b0 3f 8f a0 b0 3d
b4 55 6a :3 a0 a5 57 b7 a4
b1 11 68 4f a0 8d 90 :3 a0
b0 3f b4 :3 a0 6b 2c 6a :3 a0
a5 b 65 b7 a4 b1 11 68
4f 9a 90 :3 a0 b0 3f 96 :3 a0
b0 54 8f a0 6e b0 3d b4
55 6a a3 :2 a0 6b 1c 81 b0
:2 a0 6b :3 a0 e a5 57 :3 a0 4d
:2 51 a5 b d :3 a0 6b :2 a0 a5
b a5 b d b7 a4 b1 11
68 4f 9a 90 :3 a0 b0 3f 96
:3 a0 b0 54 8f a0 6e b0 3d
b4 55 6a a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 :2 a0 6b :3 a0 e a5
57 :2 a0 6b :4 a0 6b a0 a5 b
:4 a0 a5 b :2 a0 a5 57 b7 a4
b1 11 68 4f 9a 90 :3 a0 b0
3f 8f a0 b0 3d b4 55 6a
:2 a0 6b :2 a0 6b 7e a0 b4 2e
d b7 :3 a0 6b :2 a0 6b 7e :2 a0
6b b4 2e d :2 a0 6b a0 d
b7 a6 9 a4 b1 11 4f b7
a4 b1 11 68 4f 9a 90 :3 a0
b0 3f 8f a0 b0 3d b4 55
6a :3 a0 e :2 a0 7e a0 b4 2e
e a5 57 b7 a4 b1 11 68
4f 9a 90 :3 a0 b0 3f b4 55
6a :2 a0 6b 6e d :2 a0 6b 6e
d b7 a4 b1 11 68 4f 9a
90 :3 a0 b0 3f 8f a0 4d b0
3d 8f a0 4d b0 3d 8f a0
4d b0 3d b4 55 6a :2 a0 6b
6e d :2 a0 6b :4 a0 a5 b d
b7 a4 b1 11 68 4f 9a 90
:3 a0 b0 3f b4 55 6a :2 a0 6b
:2 a0 6b 7e :2 a0 6b b4 2e d
:2 a0 6b 6e d b7 a4 b1 11
68 4f 9a 90 :3 a0 b0 3f 8f
a0 b0 3d 8f a0 b0 3d 8f
:2 a0 b0 3d b4 55 6a a3 a0
1c 81 b0 a3 a0 1c 81 b0
:2 a0 6e 7e a0 b4 2e a5 57
:3 a0 6b d :2 a0 7e b4 2e a0
2b b7 19 3c :3 a0 a5 b d
:2 a0 6e 7e a0 b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 :3 a0 6b a0 a5
b d b7 a0 47 :3 a0 6e a5
57 b7 19 3c :2 a0 6e a5 57
b7 a4 b1 11 68 4f 9a 90
:3 a0 b0 3f 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
:2 a0 b0 3d b4 55 6a a3 a0
1c 81 b0 a0 7e b4 2e :2 a0
7e a0 b4 2e 7e a0 b4 2e
d b7 :2 a0 d b7 :2 19 3c :3 a0
e :2 a0 e :2 a0 e :2 a0 e a5
57 b7 a4 b1 11 68 4f 9a
90 :3 a0 b0 3f 8f a0 b0 3d
8f :2 a0 b0 3d b4 55 6a :2 a0
6e 7e a0 b4 2e a5 57 :3 a0
6e a5 57 b7 19 3c :2 a0 6e
a5 57 b7 a4 b1 11 68 4f
9a 90 :3 a0 b0 3f 8f a0 b0
3d 8f a0 b0 3d 8f :2 a0 b0
3d b4 55 6a a3 a0 1c 81
b0 a0 7e b4 2e :2 a0 7e a0
b4 2e 7e a0 b4 2e d b7
:2 a0 d b7 :2 19 3c :3 a0 e :2 a0
e :2 a0 e a5 57 b7 a4 b1
11 68 4f 9a 90 :3 a0 b0 3f
8f a0 b0 3d b4 55 6a :2 a0
6e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 a4 b1 11 68
4f 9a 90 :3 a0 b0 3f 8f a0
b0 3d 8f a0 b0 3d b4 55
6a a0 7e b4 2e :2 a0 6e 7e
a0 b4 2e 7e a0 b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 :2 a0 6e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 :2 19
3c b7 a4 b1 11 68 4f 9a
90 :3 a0 b0 3f 8f a0 b0 3d
b4 55 6a :3 a0 a5 57 b7 a4
b1 11 68 4f a0 8d 90 :3 a0
b0 3f b4 :3 a0 6b 2c 6a :4 a0
6b a5 b 65 b7 a4 b1 11
68 4f 9a 90 :3 a0 b0 3f 96
:3 a0 b0 54 8f a0 6e b0 3d
b4 55 6a a3 :2 a0 6b 1c 81
b0 :4 a0 6b e :2 a0 e :2 a0 e
a5 57 b7 a4 b1 11 68 4f
9a 90 :3 a0 b0 3f 96 :3 a0 b0
54 8f a0 6e b0 3d b4 55
6a :4 a0 6b e :2 a0 e :2 a0 e
a5 57 b7 a4 b1 11 68 4f
9a b4 55 6a :2 a0 6b 57 b3
a0 51 d b7 a4 b1 11 68
4f 9a 8f a0 b0 3d 8f a0
b0 3d b4 55 6a :2 a0 a5 b
a0 6b :2 a0 a5 b a0 6b 7e
a0 b4 2e d b7 :3 a0 a5 b
a0 6b :2 a0 a5 b a0 6b 7e
:2 a0 a5 b a0 6b b4 2e d
:2 a0 a5 b a0 6b a0 d b7
a6 9 a4 b1 11 4f b7 a4
b1 11 68 4f 9a 8f a0 b0
3d 8f a0 b0 3d b4 55 6a
:3 a0 e :2 a0 7e a0 b4 2e e
a5 57 b7 a4 b1 11 68 4f
a0 8d a0 b4 a0 2c 6a :2 a0
7e 51 b4 2e d :2 a0 a5 b
a0 6b 6e d :2 a0 a5 b a0
6b 6e d :2 a0 65 b7 a4 b1
11 68 4f a0 8d 8f a0 4d
b0 3d 8f a0 4d b0 3d 8f
a0 4d b0 3d b4 :2 a0 2c 6a
:2 a0 7e 51 b4 2e d :2 a0 a5
b a0 6b 6e d :2 a0 a5 b
a0 6b :4 a0 a5 b d :2 a0 65
b7 a4 b1 11 68 4f 9a 8f
a0 b0 3d b4 55 6a :2 a0 a5
b a0 6b :2 a0 a5 b a0 6b
7e :2 a0 a5 b a0 6b b4 2e
d :2 a0 a5 b a0 6b 6e d
b7 a4 b1 11 68 4f 9a 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f :2 a0 b0 3d b4
55 6a a3 a0 1c 81 b0 a3
a0 1c 81 b0 :2 a0 6e 7e a0
b4 2e a5 57 :3 a0 6b d :2 a0
7e b4 2e a0 2b b7 19 3c
:3 a0 a5 b d :2 a0 6e 7e a0
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
:3 a0 6b a0 a5 b d b7 a0
47 :3 a0 6e a5 57 b7 19 3c
:2 a0 6e a5 57 b7 a4 b1 11
68 4f 9a 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f :2 a0 b0 3d b4
55 6a a3 a0 1c 81 b0 a0
7e b4 2e :2 a0 7e a0 b4 2e
7e a0 b4 2e d b7 :2 a0 d
b7 :2 19 3c :3 a0 e :2 a0 e :2 a0
e :2 a0 e a5 57 b7 a4 b1
11 68 4f 9a 8f a0 b0 3d
8f a0 b0 3d 8f :2 a0 b0 3d
b4 55 6a :2 a0 6e 7e a0 b4
2e a5 57 :3 a0 6e a5 57 b7
19 3c :2 a0 6e a5 57 b7 a4
b1 11 68 4f 9a 8f a0 b0
3d 8f a0 b0 3d 8f a0 b0
3d 8f :2 a0 b0 3d b4 55 6a
a3 a0 1c 81 b0 a0 7e b4
2e :2 a0 7e a0 b4 2e 7e a0
b4 2e d b7 :2 a0 d b7 :2 19
3c :3 a0 e :2 a0 e :2 a0 e a5
57 b7 a4 b1 11 68 4f 9a
8f a0 b0 3d 8f a0 b0 3d
b4 55 6a :2 a0 6e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
a4 b1 11 68 4f 9a 8f a0
b0 3d 8f a0 b0 3d 8f a0
b0 3d b4 55 6a a0 7e b4
2e :2 a0 6e 7e a0 b4 2e 7e
a0 b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 :2 a0 6e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 :2 19 3c b7 a4 b1
11 68 4f 9a 8f a0 b0 3d
8f a0 b0 3d b4 55 6a :3 a0
a5 57 b7 a4 b1 11 68 4f
a0 8d 8f a0 b0 3d b4 :3 a0
6b 2c 6a :4 a0 a5 b a0 6b
a5 b 65 b7 a4 b1 11 68
4f 9a 8f a0 b0 3d 96 :3 a0
b0 54 8f a0 6e b0 3d b4
55 6a a3 :2 a0 6b 1c 81 b0
:4 a0 a5 b a0 6b e :2 a0 e
:2 a0 e a5 57 b7 a4 b1 11
68 4f 9a 8f a0 b0 3d 96
:3 a0 b0 54 8f a0 6e b0 3d
b4 55 6a :4 a0 a5 b a0 6b
e :2 a0 e :2 a0 e a5 57 b7
a4 b1 11 68 4f a0 8d 8f
a0 b0 3d b4 :2 a0 2c 6a a0
7e b4 2e :4 a0 a5 b :2 6e a5
b 65 b7 a0 4d 65 b7 :2 19
3c b7 a4 b1 11 68 4f a0
8d 8f a0 b0 3d b4 :2 a0 2c
6a a3 a0 1c 81 b0 :3 a0 :2 6e
a5 b d :3 a0 :2 6e a5 b d
:3 a0 :2 6e a5 b d :3 a0 :2 6e a5
b d :3 a0 :2 6e a5 b d :2 a0
65 b7 a4 b1 11 68 4f a0
8d 8f a0 b0 3d b4 :2 a0 2c
6a :4 a0 a5 b a5 b 65 b7
a4 b1 11 68 4f a0 8d 8f
a0 b0 3d 8f a0 4d b0 3d
8f :2 a0 b0 3d b4 :2 a0 2c 6a
a3 a0 51 a5 1c 6e 81 b0
a3 :2 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a0 7e b4 2e
a0 7e b4 2e :5 a0 a5 b d
b7 :4 a0 a5 b d b7 :2 19 3c
b7 :2 a0 d b7 :2 19 3c :3 a0 6e
a0 a5 b d :2 a0 :2 51 a5 b
7e 6e b4 2e a0 6e 7e a0
b4 2e d b7 19 3c b7 a0
4d d b7 :2 19 3c :2 a0 65 b7
a4 b1 11 68 4f a0 8d 8f
a0 b0 3d b4 :2 a0 2c 6a a0
7e b4 2e :3 a0 6e a5 b 7e
6e b4 2e 7e :2 a0 6e a5 b
b4 2e 65 b7 a0 4d 65 b7
:2 19 3c b7 a4 b1 11 68 4f
a0 8d 8f a0 b0 3d b4 :2 a0
2c 6a :3 a0 6b :2 a0 e a0 51
e :2 a0 e a5 b 65 b7 a4
b1 11 68 4f b1 b7 a4 11
a0 b1 56 4f 1d 17 b5 
be8
2
0 3 7 b 15 31 2d 2c
39 29 3e 42 46 4a 4e 52
54 58 5a 66 6a 6c 88 84
83 90 80 95 99 9d a1 a5
a9 ab af b1 bd c1 c3 df
db da e7 d7 ec f0 f4 f8
fc 100 102 106 108 114 118 11a
136 132 131 13e 12e 143 147 14b
14f 153 157 159 15d 15f 16b 16f
171 175 191 18d 18c 199 1a6 1a2
189 1ae 1b7 1b3 1a1 1bf 19e 1c4
1c8 1cc 1d0 1f1 1d8 1dc 1e0 1e3
1e4 1ec 1d7 1f8 1fc 201 205 1d4
209 20a 20f 213 217 21a 21f 220
225 228 22c 22d 232 235 23a 23b
240 244 248 24a 24e 251 252 257
25b 25f 262 267 268 26d 270 274
275 27a 27d 282 283 288 28c 28e
292 296 299 29d 2a0 2a1 2a6 2aa
2ae 2b1 2b6 2b7 2bc 2bf 2c3 2c4
2c9 2cc 2d1 2d2 2d7 2db 2df 2e1
2e5 2e8 2e9 2ee 2f2 2f6 2f9 2fe
2ff 304 307 30b 30c 311 314 319
31a 31f 323 325 329 32d 330 334
337 338 33d 341 345 348 34d 34e
353 356 35a 35b 360 363 368 369
36e 372 376 378 37c 37f 380 385
389 38d 390 395 396 39b 39e 3a2
3a3 3a8 3ab 3b0 3b1 3b6 3ba 3bc
3c0 3c4 3c7 3cb 3cf 3d2 3d7 3d8
3dd 3e1 3e5 3e9 3ed 3ef 3f3 3f5
401 405 407 42b 41f 423 427 41e
432 43f 43b 41b 447 450 44c 43a
458 437 45d 461 465 469 46c 46d
472 476 47a 47b 47d 481 485 487
48b 48e 490 494 496 4a2 4a6 4a8
4cc 4c0 4c4 4c8 4bf 4d3 4e0 4dc
4bc 4e8 4f1 4ed 4db 4f9 506 502
4d8 50e 501 513 517 51b 4fe 51f
520 525 529 52c 52d 532 536 53a
53d 541 542 547 54a 54e 54f 554
555 557 55b 55f 561 565 569 56a
56c 570 574 576 57a 57e 581 583
587 58a 58c 590 592 59e 5a2 5a4
5c8 5bc 5c0 5c4 5bb 5cf 5dc 5d8
5b8 5d7 5e4 5f1 5ed 5d4 5f9 5ec
5fe 602 606 5e9 60a 60b 610 614
617 618 61d 621 625 628 62c 62d
632 635 639 63a 63f 640 642 646
64a 64c 650 654 655 657 65b 65f
661 665 669 66c 66e 672 675 677
67b 67d 689 68d 68f 6b3 6a7 6ab
6af 6a6 6ba 6c7 6c3 6a3 6cf 6c2
6d4 6d8 6dc 6e0 6bf 6e4 6e8 6e9
6ee 6f2 6f4 6f8 6fa 706 70a 70c
730 724 728 72c 723 737 744 740
720 74c 73f 751 755 759 75d 73c
761 765 766 76b 76e 772 773 778
77c 77e 782 784 790 794 796 7ba
7ae 7b2 7b6 7ad 7c1 7aa 7c6 7ca
7ce 7d2 7d7 7db 7dd 7e1 7e3 7ef
7f3 7f5 819 80d 811 815 80c 820
82d 829 809 828 835 842 83e 825
83d 84a 857 853 83a 852 85f 84f
864 868 86c 870 874 878 87c 880
881 883 887 889 88d 88f 89b 89f
8a1 8c5 8b9 8bd 8c1 8b8 8cc 8b5
8d1 8d5 8d9 8db 8dd 8e1 8e3 8ef
8f3 8f5 919 90d 911 915 90c 920
92d 929 909 935 93e 93a 928 946
957 94f 953 925 95f 94e 964 968
981 970 974 97c 94b 999 988 98c
994 96f 9a0 9a4 9a8 96c 9ad 9b1
9b2 9b7 9b8 9bd 9c1 9c5 9c9 9cc
9d0 9d4 9d8 9db 9dc 9e1 9e5 9eb
9ed 9f1 9f4 9f8 9fc a00 a01 a03
a07 a0b a0f a14 a17 a1b a1c a21
a24 a29 a2a a2f a32 a36 a37 a3c
a3f a44 a45 a4a a4b a50 a54 a58
a5c a5f a63 a64 a66 a6a a6c a70
a77 a7b a7f a83 a88 a89 a8e a90
a94 a97 a9b a9f aa4 aa5 aaa aac
ab0 ab2 abe ac2 ac4 ae8 adc ae0
ae4 adb aef afc af8 ad8 b04 b0d
b09 af7 b15 b22 b1e af4 b2a b37
b2f b33 b1d b3f b1a b44 b48 b61
b50 b54 b5c b4f b68 b4c b6c b6d
b72 b76 b7a b7d b81 b82 b87 b8a
b8e b8f b94 b98 b9a b9e ba2 ba6
ba8 bac bb0 bb3 bb7 bbb bbf bc1
bc5 bc9 bcb bcf bd3 bd5 bd9 bdd
bdf be0 be5 be7 beb bed bf9 bfd
bff c23 c17 c1b c1f c16 c2a c37
c33 c13 c3f c4c c44 c48 c32 c54
c2f c59 c5d c61 c65 c69 c6e c71
c75 c76 c7b c7c c81 c85 c89 c8d
c92 c93 c98 c9a c9e ca1 ca5 ca9
cae caf cb4 cb6 cba cbc cc8 ccc
cce cf2 ce6 cea cee ce5 cf9 d06
d02 ce2 d0e d17 d13 d01 d1f d30
d28 d2c cfe d38 d27 d3d d41 d5a
d49 d4d d55 d24 d45 d61 d64 d65
d6a d6e d72 d75 d79 d7a d7f d82
d86 d87 d8c d90 d92 d96 d9a d9e
da0 da4 da8 dab daf db3 db7 db9
dbd dc1 dc3 dc7 dcb dcd dce dd3
dd5 dd9 ddb de7 deb ded e11 e05
e09 e0d e04 e18 e25 e21 e01 e2d
e20 e32 e36 e3a e3e e42 e1d e47
e4b e4c e51 e54 e59 e5a e5f e60
e65 e67 e6b e6d e79 e7d e7f ea3
e97 e9b e9f e96 eaa eb7 eb3 e93
ebf ec8 ec4 eb2 ed0 eaf ed5 ed9
edd ee1 ee4 ee5 eea eee ef2 ef7
efa efe eff f04 f07 f0b f0c f11
f14 f18 f19 f1e f21 f26 f27 f2c
f2d f32 f34 f38 f3c f41 f44 f48
f49 f4e f51 f56 f57 f5c f5d f62
f64 f68 f6c f6f f71 f75 f77 f83
f87 f89 fad fa1 fa5 fa9 fa0 fb4
fc1 fbd f9d fc9 fbc fce fd2 fd6
fda fde fb9 fe2 fe7 fe9 fed fef
ffb fff 1001 1005 1029 101d 1021 1025
101c 1030 1019 1035 1039 103d 1041 1044
1048 104c 1050 1054 1058 1059 105b 105f
1061 1065 1067 1073 1077 1079 109d 1091
1095 1099 1090 10a4 10b9 10ad 10b1 10b5
108d 10c0 10ce 10c5 10c9 10ac 10d6 10a9
10db 10df 10ff 10e7 10eb 10ef 10f2 10fa
10e6 1106 110a 10e3 110e 1112 1116 111a
111c 111d 1122 1126 112a 112e 112f 1132
1135 1136 1138 113c 1140 1144 1148 114b
114f 1153 1154 1156 1157 1159 115d 115f
1163 1165 1171 1175 1177 119b 118f 1193
1197 118e 11a2 11b7 11ab 11af 11b3 118b
11be 11cc 11c3 11c7 11aa 11d4 11a7 11d9
11dd 11f9 11e5 11e9 11f1 11f4 11e4 1215
1204 1208 11e1 1210 1203 1231 1220 1224
1200 122c 121f 124d 123c 1240 121c 1248
123b 1254 1258 1238 125c 1260 1264 1268
126a 126b 1270 1274 1278 127b 127f 1283
1287 128b 128e 1292 1293 1295 1299 129d
12a1 12a5 12a6 12a8 12ac 12b0 12b1 12b6
12b8 12bc 12be 12ca 12ce 12d0 12f4 12e8
12ec 12f0 12e7 12fb 1308 1304 12e4 1310
1303 1315 1319 131d 1321 1300 1325 1329
132d 1330 1333 1337 1338 133d 1341 1343
1347 134b 134f 1352 1356 135a 135d 1360
1364 1368 136b 136c 1371 1375 1379 137d
1380 1384 1388 138a 138b 1390 1394 1396
13a2 13a4 13a6 13aa 13ac 13b8 13bc 13be
13e2 13d6 13da 13de 13d5 13e9 13f6 13f2
13d2 13fe 13f1 1403 1407 140b 140f 1413
13ee 1417 141b 141f 1422 1426 1427 142c
142e 142f 1434 1436 143a 143c 1448 144c
144e 1472 1466 146a 146e 1465 1479 1462
147e 1482 1486 148a 148e 1491 1496 149a
149e 14a2 14a5 14aa 14ae 14b0 14b4 14b6
14c2 14c6 14c8 14ec 14e0 14e4 14e8 14df
14f3 1500 14fc 14dc 14fb 1508 1515 1511
14f8 1510 151d 152a 1526 150d 1525 1532
1522 1537 153b 153f 1543 1547 154a 154f
1553 1557 155b 155e 1562 1566 156a 156e
156f 1571 1575 1577 157b 157d 1589 158d
158f 15b3 15a7 15ab 15af 15a6 15ba 15a3
15bf 15c3 15c7 15cb 15cf 15d2 15d6 15da
15dd 15e0 15e4 15e8 15eb 15ec 15f1 15f5
15f9 15fd 1600 1605 1609 160b 160f 1611
161d 1621 1623 1647 163b 163f 1643 163a
164e 165b 1657 1637 1663 166c 1668 1656
1674 1685 167d 1681 1653 168d 167c 1692
1696 16af 169e 16a2 16aa 1679 16c7 16b6
16ba 16c2 169d 16ce 16d2 16d6 169a 16db
16df 16e0 16e5 16e6 16eb 16ef 16f3 16f7
16fa 16fe 1702 1706 1709 170a 170f 1713
1719 171b 171f 1722 1726 172a 172e 172f
1731 1735 1739 173d 1742 1745 1749 174a
174f 1752 1757 1758 175d 1760 1764 1765
176a 176d 1772 1773 1778 1779 177e 1782
1786 178a 178d 1791 1792 1794 1798 179a
179e 17a5 17a9 17ad 17b1 17b6 17b7 17bc
17be 17c2 17c5 17c9 17cd 17d2 17d3 17d8
17da 17de 17e0 17ec 17f0 17f2 1816 180a
180e 1812 1809 181d 182a 1826 1806 1832
183b 1837 1825 1843 1850 184c 1822 1858
1865 185d 1861 184b 186d 1848 1872 1876
188f 187e 1882 188a 187d 1896 187a 189a
189b 18a0 18a4 18a8 18ab 18af 18b0 18b5
18b8 18bc 18bd 18c2 18c6 18c8 18cc 18d0
18d4 18d6 18da 18de 18e1 18e5 18e9 18ed
18ef 18f3 18f7 18f9 18fd 1901 1903 1907
190b 190d 190e 1913 1915 1919 191b 1927
192b 192d 1951 1945 1949 194d 1944 1958
1965 1961 1941 196d 197a 1972 1976 1960
1982 195d 1987 198b 198f 1993 1997 199c
199f 19a3 19a4 19a9 19aa 19af 19b3 19b7
19bb 19c0 19c1 19c6 19c8 19cc 19cf 19d3
19d7 19dc 19dd 19e2 19e4 19e8 19ea 19f6
19fa 19fc 1a20 1a14 1a18 1a1c 1a13 1a27
1a34 1a30 1a10 1a3c 1a45 1a41 1a2f 1a4d
1a5e 1a56 1a5a 1a2c 1a66 1a55 1a6b 1a6f
1a88 1a77 1a7b 1a83 1a52 1a73 1a8f 1a92
1a93 1a98 1a9c 1aa0 1aa3 1aa7 1aa8 1aad
1ab0 1ab4 1ab5 1aba 1abe 1ac0 1ac4 1ac8
1acc 1ace 1ad2 1ad6 1ad9 1add 1ae1 1ae5
1ae7 1aeb 1aef 1af1 1af5 1af9 1afb 1afc
1b01 1b03 1b07 1b09 1b15 1b19 1b1b 1b3f
1b33 1b37 1b3b 1b32 1b46 1b53 1b4f 1b2f
1b5b 1b4e 1b60 1b64 1b68 1b6c 1b70 1b4b
1b75 1b79 1b7a 1b7f 1b82 1b87 1b88 1b8d
1b8e 1b93 1b95 1b99 1b9b 1ba7 1bab 1bad
1bd1 1bc5 1bc9 1bcd 1bc4 1bd8 1be5 1be1
1bc1 1bed 1bf6 1bf2 1be0 1bfe 1bdd 1c03
1c07 1c0b 1c0f 1c12 1c13 1c18 1c1c 1c20
1c25 1c28 1c2c 1c2d 1c32 1c35 1c39 1c3a
1c3f 1c42 1c46 1c47 1c4c 1c4f 1c54 1c55
1c5a 1c5b 1c60 1c62 1c66 1c6a 1c6f 1c72
1c76 1c77 1c7c 1c7f 1c84 1c85 1c8a 1c8b
1c90 1c92 1c96 1c9a 1c9d 1c9f 1ca3 1ca5
1cb1 1cb5 1cb7 1cdb 1ccf 1cd3 1cd7 1cce
1ce2 1cef 1ceb 1ccb 1cf7 1cea 1cfc 1d00
1d04 1d08 1d0c 1ce7 1d10 1d15 1d17 1d1b
1d1d 1d29 1d2d 1d2f 1d33 1d57 1d4b 1d4f
1d53 1d4a 1d5e 1d47 1d63 1d67 1d6b 1d6f
1d72 1d76 1d7a 1d7e 1d82 1d86 1d8a 1d8d
1d8e 1d90 1d94 1d96 1d9a 1d9c 1da8 1dac
1dae 1dd2 1dc6 1dca 1dce 1dc5 1dd9 1dee
1de2 1de6 1dea 1dc2 1df5 1e03 1dfa 1dfe
1de1 1e0b 1dde 1e10 1e14 1e34 1e1c 1e20
1e24 1e27 1e2f 1e1b 1e3b 1e3f 1e43 1e47
1e18 1e4b 1e4d 1e51 1e55 1e57 1e5b 1e5f
1e61 1e62 1e67 1e69 1e6d 1e6f 1e7b 1e7f
1e81 1ea5 1e99 1e9d 1ea1 1e98 1eac 1ec1
1eb5 1eb9 1ebd 1e95 1ec8 1ed6 1ecd 1ed1
1eb4 1ede 1eb1 1ee3 1ee7 1eeb 1eef 1ef3
1ef7 1efb 1efe 1f00 1f04 1f08 1f0a 1f0e
1f12 1f14 1f15 1f1a 1f1c 1f20 1f22 1f2e
1f32 1f34 1f48 1f49 1f4d 1f51 1f55 1f59
1f5c 1f61 1f62 1f66 1f69 1f6d 1f6f 1f73
1f75 1f81 1f85 1f87 1fa3 1f9f 1f9e 1fab
1fb8 1fb4 1f9b 1fc0 1fb3 1fc5 1fc9 1fcd
1fd1 1fb0 1fd5 1fd7 1fdb 1fde 1fe2 1fe6
1fe7 1fe9 1fed 1ff0 1ff3 1ff7 1ff8 1ffd
2001 2003 2007 200b 200f 2010 2012 2016
2019 201d 2021 2022 2024 2028 202b 202e
2032 2036 2037 2039 203d 2040 2041 2046
204a 204e 2052 2053 2055 2059 205c 2060
2064 2066 2067 206c 2070 2072 207e 2080
2082 2086 2088 2094 2098 209a 20b6 20b2
20b1 20be 20cb 20c7 20ae 20d3 20c6 20d8
20dc 20e0 20e4 20e8 20c3 20ec 20f0 20f4
20f7 20fb 20fc 2101 2103 2104 2109 210b
210f 2111 211d 2121 2123 2127 213b 213f
2140 2144 2148 214c 2150 2154 2157 215a
215b 2160 2164 2168 216c 216d 216f 2173
2176 217b 217f 2183 2187 2188 218a 218e
2191 2196 219a 219e 21a2 21a6 21a8 21ac
21ae 21ba 21be 21c0 21c4 21e1 21dc 21e0
21db 21e9 21f6 21f2 21d8 21f1 21fe 220b
2207 21ee 2206 2213 2203 2218 221c 2220
2224 2228 222c 2230 2233 2236 2237 223c
2240 2244 2248 2249 224b 224f 2252 2257
225b 225f 2263 2264 2266 226a 226d 2271
2275 2279 227d 227e 2280 2284 2288 228c
2290 2292 2296 2298 22a4 22a8 22aa 22c6
22c2 22c1 22ce 22be 22d3 22d7 22db 22df
22e3 22e4 22e6 22ea 22ed 22f1 22f5 22f6
22f8 22fc 22ff 2302 2306 230a 230b 230d
2311 2314 2315 231a 231e 2322 2326 2327
2329 232d 2330 2335 2339 233b 233f 2341
234d 2351 2353 236f 236b 236a 2377 2384
2380 2367 238c 2395 2391 237f 239d 23ae
23a6 23aa 237c 23b6 23a5 23bb 23bf 23d8
23c7 23cb 23d3 23a2 23f0 23df 23e3 23eb
23c6 23f7 23fb 23ff 23c3 2404 2408 2409
240e 240f 2414 2418 241c 2420 2423 2427
242b 242f 2432 2433 2438 243c 2442 2444
2448 244b 244f 2453 2457 2458 245a 245e
2462 2466 246b 246e 2472 2473 2478 247b
2480 2481 2486 2489 248d 248e 2493 2496
249b 249c 24a1 24a2 24a7 24ab 24af 24b3
24b6 24ba 24bb 24bd 24c1 24c3 24c7 24ce
24d2 24d6 24da 24df 24e0 24e5 24e7 24eb
24ee 24f2 24f6 24fb 24fc 2501 2503 2507
2509 2515 2519 251b 2537 2533 2532 253f
254c 2548 252f 2554 255d 2559 2547 2565
2572 256e 2544 257a 2587 257f 2583 256d
258f 256a 2594 2598 25b1 25a0 25a4 25ac
259f 25b8 259c 25bc 25bd 25c2 25c6 25ca
25cd 25d1 25d2 25d7 25da 25de 25df 25e4
25e8 25ea 25ee 25f2 25f6 25f8 25fc 2600
2603 2607 260b 260f 2611 2615 2619 261b
261f 2623 2625 2629 262d 262f 2630 2635
2637 263b 263d 2649 264d 264f 266b 2667
2666 2673 2680 267c 2663 2688 2695 268d
2691 267b 269d 2678 26a2 26a6 26aa 26ae
26b2 26b7 26ba 26be 26bf 26c4 26c5 26ca
26ce 26d2 26d6 26db 26dc 26e1 26e3 26e7
26ea 26ee 26f2 26f7 26f8 26fd 26ff 2703
2705 2711 2715 2717 2733 272f 272e 273b
2748 2744 272b 2750 2759 2755 2743 2761
2772 276a 276e 2740 277a 2769 277f 2783
279c 278b 278f 2797 2766 2787 27a3 27a6
27a7 27ac 27b0 27b4 27b7 27bb 27bc 27c1
27c4 27c8 27c9 27ce 27d2 27d4 27d8 27dc
27e0 27e2 27e6 27ea 27ed 27f1 27f5 27f9
27fb 27ff 2803 2805 2809 280d 280f 2810
2815 2817 281b 281d 2829 282d 282f 284b
2847 2846 2853 2860 285c 2843 2868 285b
286d 2871 2875 2879 287d 2858 2882 2886
2887 288c 288f 2894 2895 289a 289b 28a0
28a2 28a6 28a8 28b4 28b8 28ba 28d6 28d2
28d1 28de 28eb 28e7 28ce 28f3 28fc 28f8
28e6 2904 28e3 2909 290d 2911 2915 2918
2919 291e 2922 2926 292b 292e 2932 2933
2938 293b 293f 2940 2945 2948 294c 294d
2952 2955 295a 295b 2960 2961 2966 2968
296c 2970 2975 2978 297c 297d 2982 2985
298a 298b 2990 2991 2996 2998 299c 29a0
29a3 29a5 29a9 29ab 29b7 29bb 29bd 29d9
29d5 29d4 29e1 29ee 29ea 29d1 29f6 29e9
29fb 29ff 2a03 2a07 2a0b 29e6 2a0f 2a14
2a16 2a1a 2a1c 2a28 2a2c 2a2e 2a32 2a4e
2a4a 2a49 2a56 2a46 2a5b 2a5f 2a63 2a67
2a6a 2a6e 2a72 2a76 2a7a 2a7e 2a82 2a83
2a85 2a89 2a8c 2a8d 2a8f 2a93 2a95 2a99
2a9b 2aa7 2aab 2aad 2ac9 2ac5 2ac4 2ad1
2ae6 2ada 2ade 2ae2 2ac1 2aed 2afb 2af2
2af6 2ad9 2b03 2ad6 2b08 2b0c 2b2c 2b14
2b18 2b1c 2b1f 2b27 2b13 2b33 2b37 2b3b
2b3f 2b10 2b43 2b45 2b49 2b4c 2b4e 2b52
2b56 2b58 2b5c 2b60 2b62 2b63 2b68 2b6a
2b6e 2b70 2b7c 2b80 2b82 2b9e 2b9a 2b99
2ba6 2bbb 2baf 2bb3 2bb7 2b96 2bc2 2bd0
2bc7 2bcb 2bae 2bd8 2bab 2bdd 2be1 2be5
2be9 2bed 2bf1 2bf5 2bf6 2bf8 2bfc 2bff
2c01 2c05 2c09 2c0b 2c0f 2c13 2c15 2c16
2c1b 2c1d 2c21 2c23 2c2f 2c33 2c35 2c39
2c55 2c51 2c50 2c5d 2c4d 2c62 2c66 2c6a
2c6e 2c72 2c76 2c79 2c7a 2c7f 2c83 2c87
2c8b 2c8f 2c90 2c92 2c97 2c9c 2c9d 2c9f
2ca3 2ca5 2ca9 2caa 2cae 2cb0 2cb4 2cb8
2cbb 2cbd 2cc1 2cc3 2ccf 2cd3 2cd5 2cd9
2cf5 2cf1 2cf0 2cfd 2ced 2d02 2d06 2d0a
2d0e 2d27 2d16 2d1a 2d22 2d15 2d2e 2d32
2d36 2d3a 2d3f 2d12 2d44 2d46 2d4a 2d4e
2d52 2d56 2d5b 2d60 2d61 2d63 2d67 2d6b
2d6f 2d73 2d78 2d7d 2d7e 2d80 2d84 2d88
2d8c 2d90 2d95 2d9a 2d9b 2d9d 2da1 2da5
2da9 2dad 2db2 2db7 2db8 2dba 2dbe 2dc2
2dc6 2dca 2dcc 2dd0 2dd2 2dde 2de2 2de4
2de8 2e04 2e00 2dff 2e0c 2dfc 2e11 2e15
2e19 2e1d 2e21 2e25 2e29 2e2d 2e31 2e32
2e34 2e35 2e37 2e3b 2e3d 2e41 2e43 2e4f
2e53 2e55 2e59 2e75 2e71 2e70 2e7d 2e8a
2e86 2e6d 2e85 2e92 2ea3 2e9b 2e9f 2e82
2eab 2e9a 2eb0 2eb4 2eb8 2ebc 2edb 2ec4
2e97 2ec8 2ec9 2ed1 2ed6 2ec3 2efc 2ee6
2eea 2ec0 2eee 2eef 2ef7 2ee5 2f18 2f07
2f0b 2f13 2ee2 2f03 2f1f 2f22 2f23 2f28
2f2c 2f2f 2f30 2f35 2f39 2f3d 2f41 2f45
2f49 2f4a 2f4c 2f50 2f52 2f56 2f5a 2f5e
2f62 2f63 2f65 2f69 2f6b 2f6f 2f73 2f76
2f78 2f7c 2f80 2f84 2f86 2f8a 2f8e 2f91
2f95 2f99 2f9d 2fa2 2fa6 2fa7 2fa9 2fad
2fb1 2fb5 2fb8 2fbb 2fbc 2fbe 2fc1 2fc6
2fc7 2fcc 2fd0 2fd5 2fd8 2fdc 2fdd 2fe2
2fe6 2fe8 2fec 2fef 2ff1 2ff5 2ff6 2ffa
2ffc 3000 3004 3007 300b 300f 3013 3015
3019 301b 3027 302b 302d 3031 304d 3049
3048 3055 3045 305a 305e 3062 3066 306a
306e 3071 3072 3077 307b 307f 3083 3088
3089 308b 308e 3093 3094 3099 309c 30a0
30a4 30a9 30aa 30ac 30ad 30b2 30b6 30b8
30bc 30bd 30c1 30c3 30c7 30cb 30ce 30d0
30d4 30d6 30e2 30e6 30e8 30ec 3108 3104
3103 3110 3100 3115 3119 311d 3121 3125
3129 312d 3131 3134 3138 313c 313e 3142
3145 3147 314b 314f 3151 3152 3154 3158
315a 315e 3160 316c 3170 3172 3174 3176
317a 3186 318a 318c 318f 3191 3192 319b 
be8
2
0 1 9 e d 18 1d :2 18
17 :2 3 5 12 5 :6 3 d 1e
28 :2 1e 1d :2 3 5 16 5 :6 3
d 1f 2a :2 1f 1e :2 3 5 17
5 :6 3 d 21 2e :2 21 20 :2 3
5 19 5 :7 3 c 1a 27 :3 1a
27 :3 1a 27 :2 1a 19 31 38 :2 3
5 b 18 :2 13 :2 b :2 5 e 5
:4 8 7 10 16 19 :2 10 26 29
:2 10 33 36 :2 10 7 5 1e :4 b
7 10 16 19 :2 10 26 29 :2 10
37 3a :2 10 7 25 1e :2 5 :4 8
7 10 16 19 :2 10 27 2a :2 10
35 38 :2 10 7 5 1f :4 b 7
10 16 19 :2 10 27 2a :2 10 39
3c :2 10 7 26 1f :2 5 :4 8 7
10 16 19 :2 10 29 2c :2 10 39
3c :2 10 7 5 21 :4 b 7 10
16 19 :2 10 29 2c :2 10 3d 40
:2 10 7 28 21 :3 5 e 14 17
:2 e :2 5 c 5 :6 3 d 1a 25
29 30 :3 1a 22 :3 1a 22 :2 1a 19
:2 3 :4 8 7 f :2 7 1a 7 1c
:2 5 :6 3 d 1d 2c 30 37 :3 1d
29 :3 1d 29 :3 1d 29 :2 1d 1c :2 3
:4 8 :4 a 9 11 1d 20 :2 11 29
2c :2 11 :2 9 37 9 22 9 11
:2 9 1c 9 :4 7 1c :2 5 :6 3 d
1a 25 29 30 :3 1a 22 33 :3 1a
22 :2 1a 19 :2 3 :4 8 :4 a 9 11
19 1c :2 11 25 28 :2 11 :2 9 33
9 1d 9 11 :2 9 1d 9 :4 7
1c :2 5 :6 3 d 15 1e 22 29
:2 15 2f 36 :2 2f 14 :2 3 5 e
14 17 :2 e 5 :6 3 d 15 1e
22 29 :2 15 2f 36 :2 2f 14 :2 3
5 e 14 17 :2 e 1e 21 :2 e
5 :6 3 d 1b 24 28 2f :2 1b
1a :2 3 5 e 5 :6 3 d 22
32 36 3d :3 22 2f 40 :3 22 2f
40 :3 22 2f 40 :2 22 21 :2 3 5
e 1c 27 33 :2 e 5 :6 3 d
19 22 26 2d :2 19 18 :2 3 5
:6 3 d 1a 25 29 30 :3 1a 22
:3 1a 22 :3 1a 22 32 :2 1a 19 :2 3
5 :3 b :2 5 :3 b :2 5 d 14 18
1b :2 14 :3 5 d :2 15 :2 5 :4 a :2 9
17 :3 7 10 18 :2 10 :2 7 f 16
1a 1d :2 16 22 25 :2 16 2a 2d
:2 16 33 36 :2 16 :3 7 f :2 17 1c
:2 f 7 5 9 3 8 7 f
16 :2 7 10 :3 5 d 14 :2 5 :6 3
d 1d 2c 30 37 :3 1d 29 :3 1d
29 :3 1d 29 :3 1d 29 39 :2 1d 1c
:2 3 5 :3 b 5 :4 8 7 10 1c
1f :2 10 28 2b :2 10 7 20 7
10 7 :5 5 12 1d :2 12 1d :2 12
1d :2 12 1d 12 :2 5 :6 3 d 1a
25 29 30 :3 1a 22 :3 1a 22 32
:2 1a 19 :2 3 5 d 14 18 1b
:2 14 :2 5 8 7 f 16 :2 7 10
:3 5 d 14 :2 5 :6 3 d 1d 2c
30 37 :3 1d 29 :3 1d 29 :3 1d 29
39 :2 1d 1c :2 3 5 :3 b 5 :4 8
7 10 1c 1f :2 10 28 2b :2 10
7 20 7 10 7 :5 5 12 1b
12 22 2b 22 32 3d 32 :2 5
:6 3 d 18 21 25 2c :2 18 32
38 :2 32 17 :2 3 5 d 14 19
1c :2 14 22 25 :2 14 :2 5 :6 3 d
1b 2a 2e 35 :3 1b 27 :3 1b 27
:2 1b 1a :2 3 :4 8 7 f 16 1b
1e :2 16 2a 2d :2 16 36 39 :2 16
3f 42 :2 16 :2 7 20 7 f 16
1b 1e :2 16 24 27 :2 16 :2 7 :4 5
:6 3 d 18 21 25 2c :2 18 32
3a :2 32 17 :2 3 5 d 14 :2 5
:7 3 c 13 1c 20 27 :2 13 12
2d 34 38 34 :2 3 5 c 14
:2 c 5 :6 3 d 18 25 29 30
:3 18 22 26 2d :3 18 22 33 :2 18
17 :2 3 5 b f :3 b :2 5 :2 e
1e 26 2f 26 :3 5 f 17 1e
24 27 :2 f :2 5 f :2 15 20 2f
:2 20 :2 f 5 :6 3 d 15 22 26
2d :3 15 1f 23 2a :3 15 1f 30
:2 15 14 :2 3 5 :2 f 1e f :2 5
:2 f 1e f :2 5 :2 f 1e f :2 5
:2 f 1e f :2 5 :2 e 1e 26 2f
26 :3 5 :2 e :3 1c :2 25 2f :5 1c 2b
:4 1c :2 5 :6 3 d 15 1e 22 29
:2 15 34 3b :2 34 14 :2 3 7 :2 d
1a :2 20 2a 2d :2 1a 7 5 c
9 :2 f 1c :2 22 2a 2d :2 33 :2 1c
:2 9 :2 f 1c 9 18 :2 7 5 :9 3
d 15 1e 22 29 :2 15 34 3b
:2 34 14 :2 3 5 d 16 d 1d
27 2e 31 :2 27 1d :2 5 :6 3 d
1b 24 28 2f :2 1b 1a :2 3 5
:2 b 18 :2 5 :2 b 18 5 :6 3 d
22 32 36 3d :3 22 2f 40 :3 22
2f 40 :3 22 2f 40 :2 22 21 :2 3
5 :2 b 16 :2 5 :2 b 18 26 31
3d :2 18 5 :6 3 d 19 22 26
2d :2 19 18 :2 3 5 :2 b 18 :2 1e
26 29 :2 2f :2 18 :2 5 :2 b 18 5
:6 3 d 1a 25 29 30 :3 1a 22
:3 1a 22 :3 1a 22 32 :2 1a 19 :2 3
5 :3 b :2 5 :3 b :2 5 d 14 18
1b :2 14 :3 5 d :2 15 :2 5 :4 a :2 9
17 :3 7 10 18 :2 10 :2 7 f 16
1a 1d :2 16 22 25 :2 16 2a 2d
:2 16 33 36 :2 16 :3 7 f :2 17 1c
:2 f 7 5 9 3 8 7 f
16 :2 7 10 :3 5 d 14 :2 5 :6 3
d 1d 2c 30 37 :3 1d 29 :3 1d
29 :3 1d 29 :3 1d 29 39 :2 1d 1c
:2 3 5 :3 b 5 :4 8 7 10 1c
1f :2 10 28 2b :2 10 7 20 7
10 7 :5 5 12 1d :2 12 1d :2 12
1d :2 12 1d 12 :2 5 :6 3 d 1a
25 29 30 :3 1a 22 :3 1a 22 32
:2 1a 19 :2 3 5 d 14 18 1b
:2 14 :2 5 8 7 f 16 :2 7 10
:3 5 d 14 :2 5 :6 3 d 1d 2c
30 37 :3 1d 29 :3 1d 29 :3 1d 29
39 :2 1d 1c :2 3 5 :3 b 5 :4 8
7 10 1c 1f :2 10 28 2b :2 10
7 20 7 10 7 :5 5 12 1b
12 22 2b 22 32 3d 32 :2 5
:6 3 d 18 21 25 2c :2 18 37
3d :2 37 17 :2 3 5 d 14 19
1c :2 14 22 25 :2 14 :2 5 :6 3 d
1b 2a 2e 35 :3 1b 27 :3 1b 27
:2 1b 1a :2 3 :4 8 7 f 16 1b
1e :2 16 2a 2d :2 16 36 39 :2 16
3f 42 :2 16 :2 7 20 7 f 16
1b 1e :2 16 24 27 :2 16 :2 7 :4 5
:6 3 d 18 21 25 2c :2 18 37
3f :2 37 17 :2 3 5 d 14 :2 5
:7 3 c 13 1c 20 27 :2 13 12
32 39 3d 39 :2 3 5 c 14
:2 1a :2 c 5 :6 3 d 18 25 29
30 :3 18 22 26 2d :3 18 22 33
:2 18 17 :2 3 5 b f :3 b :2 5
10 1d :2 23 :2 10 1d :2 10 1d 10
:2 5 :6 3 d 15 22 26 2d :3 15
1f 23 2a :3 15 1f 30 :2 15 14
:2 3 5 d 1a :2 20 :2 d 1a :2 d
1a d :2 5 :6 3 d 0 :2 3 5
:2 b :3 5 14 5 :6 3 d 15 1a
:2 15 27 2e :2 27 14 :2 3 7 d
:2 7 :2 13 20 26 :2 20 :2 2c 36 39
:2 20 7 5 c 9 f :2 9 :2 15
20 26 :2 20 :2 2c 34 37 3d :2 37
:2 43 :2 20 :2 9 f :2 9 :2 15 22 9
18 :2 7 5 :9 3 d 15 1a :2 15
27 2e :2 27 14 :2 3 5 d 15
d 1b 25 2c 2f :2 25 1b :2 5
:7 3 c 1a 0 21 :2 3 5 14
20 22 :2 14 :2 5 b :2 5 :2 18 23
:2 5 b :2 5 :2 18 25 :2 5 c 5
:7 3 c 21 2e 3f :3 21 2e 3f
:3 21 2e 3f :2 21 20 5 c :2 3
5 14 20 22 :2 14 :2 5 b :2 5
:2 18 23 :2 5 b :2 5 :2 18 25 :3 33
:2 25 :2 5 c 5 :6 3 d 19 1e
:2 19 18 :2 3 5 b :2 5 :2 11 1c
22 :2 1c :2 28 30 33 39 :2 33 :2 3f
:2 1c :2 5 b :2 5 :2 11 1e 5 :6 3
d 1a 22 :3 1a 22 :3 1a 22 :3 1a
22 32 :2 1a 19 :2 3 5 :3 b :2 5
:3 b :2 5 d 13 17 1a :2 13 :3 5
d :2 15 :2 5 :4 a :2 9 17 :3 7 10
18 :2 10 :2 7 f 15 19 1c :2 15
21 24 :2 15 29 2c :2 15 32 35
:2 15 :3 7 f :2 17 1c :2 f 7 5
9 3 8 7 f 15 :2 7 10
:3 5 d 13 :2 5 :6 3 d 1d 29
:3 1d 29 :3 1d 29 :3 1d 29 :3 1d 29
39 :2 1d 1c :2 3 5 :3 b 5 :4 8
7 10 1c 1f :2 10 28 2b :2 10
7 20 7 10 7 :5 5 12 1d
:2 12 1d :2 12 1d :2 12 1d 12 :2 5
:6 3 d 1a 22 :3 1a 22 :3 1a 22
32 :2 1a 19 :2 3 5 d 13 17
1a :2 13 :2 5 8 7 f 15 :2 7
10 :3 5 d 13 :2 5 :6 3 d 1d
29 :3 1d 29 :3 1d 29 :3 1d 29 39
:2 1d 1c :2 3 5 :3 b 5 :4 8 7
10 1c 1f :2 10 28 2b :2 10 7
20 7 10 7 :5 5 12 1a 12
20 29 20 30 3b 30 :2 5 :6 3
d 18 1d :2 18 2a 30 :2 2a 17
:2 3 5 d 13 18 1b :2 13 21
24 :2 13 :2 5 :6 3 d 1b 27 :3 1b
27 :3 1b 27 :2 1b 1a :2 3 :4 8 7
f 15 1a 1d :2 15 29 2c :2 15
35 38 :2 15 3e 41 :2 15 :2 7 20
7 f 15 1a 1d :2 15 23 26
:2 15 :2 7 :4 5 :6 3 d 18 1d :2 18
2a 32 :2 2a 17 :2 3 5 d 13
:2 5 :7 3 c 13 18 :2 13 12 25
2c 30 2c :2 3 5 c 14 1a
:2 14 :2 20 :2 c 5 :6 3 d 18 22
:3 18 22 26 2d :3 18 22 33 :2 18
17 :2 3 5 b f :3 b :2 5 10
1d 23 :2 1d :2 29 :2 10 1d :2 10 1d
10 :2 5 :6 3 d 15 1f :3 15 1f
23 2a :3 15 1f 30 :2 15 14 :2 3
5 d 1a 20 :2 1a :2 26 :2 d 1a
:2 d 1a d :2 5 :7 3 c 13 19
:2 13 12 23 2a :2 3 :4 8 7 e
1d 26 :4 1d :2 e 7 1a 7 e
7 :4 5 :7 3 c 18 1e :2 18 17
28 2f :2 3 5 :3 b :2 5 e 16
1d 22 :2 e :2 5 e 16 1d 22
:2 e :2 5 e 16 1d 23 :2 e :2 5
e 16 1d 22 :2 e :2 5 e 16
1d 22 :2 e :2 5 c 5 :7 3 c
15 1b :2 15 14 25 2c :2 3 5
c 13 1f :2 13 :2 c 5 :7 3 c
15 1e :3 15 1e 2d :3 15 1e 2e
:2 15 14 35 3c :2 3 5 b 14
13 b 1b b :2 5 b 18 :2 13
:2 b :2 5 :3 b 5 :4 8 :4 a c b
14 1a 24 :2 14 b 14 b 14
1a 24 :2 14 b :4 9 1f 9 12
9 :5 7 10 18 1f 26 :2 10 7
a 11 18 1b :2 a 1e 20 :2 1e
9 12 16 19 :2 12 9 24 :2 7
1d 7 10 7 :5 5 c 5 :7 3
c 1f 26 :2 1f 1e 2c 33 :2 3
:4 8 7 e 16 1e :2 e 2c 2f
:2 e 33 36 :2 3e :2 36 :2 e 7 1b
7 e 7 :4 5 :7 3 c 1a 23
:2 1a 19 2b 32 :2 3 5 c :2 13
1c 28 :2 1c 28 :2 1c 28 1c :2 c
5 :a 3 5 :6 1 
be8
4
0 :3 1 :8 3 :3 5
:2 4 :4 3 :8 8 :3 a
:2 9 :4 8 :8 d :3 f
:2 e :4 d :8 12 :3 14
:2 13 :4 12 :6 17 :4 18
:4 19 17 :2 19 :2 17
:8 1a :3 1c :4 1d :f 1e
1f 1d :4 1f :f 20
1f :3 1d :4 22 :f 23
24 22 :4 24 :f 25
24 :3 22 :4 27 :f 28
29 27 :4 29 :f 2a
29 :3 27 :7 2c :3 2d
:2 1b :4 17 :7 30 :4 31
:4 32 :3 30 :4 34 :6 35
:3 34 :2 33 :4 30 :7 39
:4 3a :4 3b :4 3c :3 39
:4 3e :4 3f :e 40 3f
:6 42 41 :3 3f :3 3e
:2 3d :4 39 :7 47 :5 48
:4 49 :3 47 :4 4b :4 4c
:e 4d 4c :6 4f 4e
:3 4c :3 4b :2 4a :4 47
:e 55 :7 57 :2 56 :4 55
:e 5a :b 5c :2 5b :4 5a
:a 5f :3 61 :2 60 :4 5f
:7 64 :5 65 :5 66 :5 67
:3 64 :8 6a :2 68 :4 64
:a 6d 6f :2 6e :4 6d
:7 72 :4 73 :4 74 :5 75
:3 72 :5 76 :5 77 :9 79
:5 7a 7b :4 7c :2 7d
:3 7c :6 7f :15 80 :8 81
7b 82 78 83
:5 84 :3 83 :5 86 :2 78
:4 72 :7 89 :4 8a :4 8b
:4 8c :5 8d :3 89 :5 8e
:4 90 :b 91 90 :3 93
92 :3 90 :4 95 :3 96
:3 97 :3 98 :2 95 :2 8f
:4 89 :7 9b :4 9c :5 9d
:3 9b :9 9f a0 :5 a1
:3 a0 :5 a3 :2 9e :4 9b
:7 a6 :4 a7 :4 a8 :5 a9
:3 a6 :5 aa :4 ac :b ad
ac :3 af ae :3 ac
:c b1 :2 ab :4 a6 :e b4
:d b6 :2 b5 :4 b4 :7 b9
:4 ba :4 bb :3 b9 :4 bd
:15 be bd :d c0 bf
:3 bd :2 bc :4 b9 :e c4
:5 c6 :2 c5 :4 c4 :f c9
:6 cb :2 ca :4 c9 :7 ce
:6 cf :5 d0 :3 ce :7 d1
:9 d3 :9 d4 :b d5 :2 d2
:4 ce :7 d8 :6 d9 :5 da
:3 d8 :6 db :6 dc :6 dd
:6 de :9 e0 :4 e1 e2
:6 e3 e4 e5 :4 e6
e7 e8 :2 e1 :2 df
:4 d8 :e ed :b f0 ef
f2 :d f3 :5 f4 :3 f2
f1 :5 ee :4 ed :e f8
:d fa :2 f9 :4 f8 :a fd
:5 ff :5 100 :2 fe :4 fd
:7 103 :5 104 :5 105 :5 106
:3 103 :5 108 :a 10a :2 107
:4 103 :a 10d :d 10f :5 110
:2 10e :4 10d :7 113 :4 114
:4 115 :5 116 :3 113 :5 117
:5 118 :9 11a :5 11b 11c
:4 11d :2 11e :3 11d :6 120
:15 121 :8 122 11c 123
119 124 :5 125 :3 124
:5 127 :2 119 :4 113 :7 12a
:4 12b :4 12c :4 12d :5 12e
:3 12a :5 12f :4 131 :b 132
131 :3 134 133 :3 131
:4 136 :3 137 :3 138 :3 139
:2 136 :2 130 :4 12a :7 13c
:4 13d :5 13e :3 13c :9 140
141 :5 142 :3 141 :5 144
:2 13f :4 13c :7 147 :4 148
:4 149 :5 14a :3 147 :5 14b
:4 14d :b 14e 14d :3 150
14f :3 14d :c 152 :2 14c
:4 147 :e 155 :d 157 :2 156
:4 155 :7 15a :4 15b :4 15c
:3 15a :4 15e :15 15f 15e
:d 161 160 :3 15e :2 15d
:4 15a :e 165 :5 167 :2 166
:4 165 :f 16a :8 16c :2 16b
:4 16a :7 16f :6 170 :5 171
:3 16f :7 172 :6 174 :3 175
:3 176 :2 174 :2 173 :4 16f
:7 179 :6 17a :5 17b :3 179
:6 17d :3 17e :3 17f :2 17d
:2 17c :4 179 184 0
:2 184 :5 186 :3 187 :2 185
:4 184 :c 18a :11 18d 18c
18f :16 190 :8 191 :3 18f
18e :5 18b :4 18a :c 195
:d 197 :2 196 :4 195 :3 19a
0 :3 19a :7 19c :8 19d
:8 19e :3 19f :2 19b :4 19a
:7 1a2 :5 1a3 :5 1a4 1a2
:2 1a5 :2 1a2 :7 1a7 :8 1a8
:8 1aa 1ab 1ac :3 1aa
:3 1ad :2 1a6 :4 1a2 :8 1b0
:16 1b2 :8 1b3 :2 1b1 :4 1b0
:5 1b6 :4 1b7 :4 1b8 :5 1b9
:3 1b6 :5 1ba :5 1bb :9 1bd
:5 1be 1bf :4 1c0 :2 1c1
:3 1c0 :6 1c3 :15 1c4 :8 1c5
1bf 1c6 1bc 1c7
:5 1c8 :3 1c7 :5 1ca :2 1bc
:4 1b6 :5 1cd :4 1ce :4 1cf
:4 1d0 :5 1d1 :3 1cd :5 1d2
:4 1d4 :b 1d5 1d4 :3 1d7
1d6 :3 1d4 :4 1d9 :3 1da
:3 1db :3 1dc :2 1d9 :2 1d3
:4 1cd :5 1df :4 1e0 :5 1e1
:3 1df :9 1e3 1e4 :5 1e5
:3 1e4 :5 1e7 :2 1e2 :4 1df
:5 1ea :4 1eb :4 1ec :5 1ed
:3 1ea :5 1ee :4 1f0 :b 1f1
1f0 :3 1f3 1f2 :3 1f0
:c 1f5 :2 1ef :4 1ea :c 1f8
:d 1fa :2 1f9 :4 1f8 :5 1fd
:4 1fe :4 1ff :3 1fd :4 201
:15 202 201 :d 204 203
:3 201 :2 200 :4 1fd :c 208
:5 20a :2 209 :4 208 :d 20d
:b 20f :2 20e :4 20d :5 212
:6 213 :5 214 :3 212 :7 215
:9 217 :3 218 :3 219 :2 217
:2 216 :4 212 :5 21c :6 21d
:5 21e :3 21c :9 220 :3 221
:3 222 :2 220 :2 21f :4 21c
:b 225 :4 227 :6 228 229
22a :3 228 227 :3 22c
22b :3 227 :2 226 :4 225
:b 23e :5 23f :8 241 :8 242
:8 243 :8 244 :8 245 :3 246
:2 240 :4 23e :b 249 :9 24b
:2 24a :4 249 :6 24e :5 24f
:5 250 24e :2 250 :2 24e
:8 251 :8 252 :5 253 :4 255
:4 256 257 :7 258 257
:7 25a 259 :3 257 256
:3 25d 25c :3 256 :8 25f
:a 260 :7 261 :3 260 255
:3 264 263 :3 255 :3 266
:2 254 :4 24e :2 269 :4 26a
269 :2 26a :2 269 :4 26c
:d 26e 26f :5 26e 26c
:3 271 270 :3 26c :2 26b
:4 269 :b 275 :7 277 :3 278
:3 279 :3 277 :2 276 :4 275
:4 3 27c :6 1 
319d
4
:3 0 1 :3 0 2
:3 0 3 :6 0 1
:2 0 4 :a 0 13
2 :7 0 5 :2 0
3 6 :3 0 5
:7 0 7 6 :3 0
9 :2 0 13 4
a :2 0 7 :3 0
5 :3 0 c d
0 f 7 12
:3 0 12 0 12
11 f 10 :6 0
13 1 0 4
a 12 be2 :2 0
8 :a 0 24 3
:7 0 b :2 0 9
6 :3 0 9 :7 0
18 17 :3 0 1a
:2 0 24 15 1b
:2 0 a :3 0 9
:3 0 1d 1e 0
20 d 23 :3 0
23 0 23 22
20 21 :6 0 24
1 0 15 1b
23 be2 :2 0 b
:a 0 35 4 :7 0
11 :2 0 f 6
:3 0 c :7 0 29
28 :3 0 2b :2 0
35 26 2c :2 0
d :3 0 c :3 0
2e 2f 0 31
13 34 :3 0 34
0 34 33 31
32 :6 0 35 1
0 26 2c 34
be2 :2 0 e :a 0
46 5 :7 0 17
:2 0 15 6 :3 0
f :7 0 3a 39
:3 0 3c :2 0 46
37 3d :2 0 10
:3 0 f :3 0 3f
40 0 42 19
45 :3 0 45 0
45 44 42 43
:6 0 46 1 0
37 3d 45 be2
:2 0 11 :3 0 12
:a 0 f8 6 :7 0
1d 19e 0 1b
6 :3 0 9 :7 0
4c 4b :3 0 21
:2 0 1f 6 :3 0
c :7 0 50 4f
:3 0 6 :3 0 f
:7 0 54 53 :3 0
13 :3 0 6 :3 0
56 58 0 f8
49 59 :2 0 18
:2 0 28 6 :3 0
15 :3 0 16 :2 0
25 5c 5f :6 0
62 60 0 f6
0 14 :6 0 14
:3 0 17 :4 0 63
64 0 f4 9
:3 0 2a 67 68
:3 0 14 :3 0 14
:3 0 19 :2 0 1a
:4 0 2c 6c 6e
:3 0 19 :2 0 9
:3 0 2f 70 72
:3 0 19 :2 0 1b
:4 0 32 74 76
:3 0 6a 77 0
7a 1c :3 0 35
90 a :3 0 18
:2 0 37 7c 7d
:3 0 14 :3 0 14
:3 0 19 :2 0 1a
:4 0 39 81 83
:3 0 19 :2 0 a
:3 0 3c 85 87
:3 0 19 :2 0 1b
:4 0 3f 89 8b
:3 0 7f 8c 0
8e 42 8f 7e
8e 0 91 69
7a 0 91 44
0 f4 c :3 0
18 :2 0 47 93
94 :3 0 14 :3 0
14 :3 0 19 :2 0
1d :4 0 49 98
9a :3 0 19 :2 0
c :3 0 4c 9c
9e :3 0 19 :2 0
1b :4 0 4f a0
a2 :3 0 96 a3
0 a6 1c :3 0
52 bc d :3 0
18 :2 0 54 a8
a9 :3 0 14 :3 0
14 :3 0 19 :2 0
1d :4 0 56 ad
af :3 0 19 :2 0
d :3 0 59 b1
b3 :3 0 19 :2 0
1b :4 0 5c b5
b7 :3 0 ab b8
0 ba 5f bb
aa ba 0 bd
95 a6 0 bd
61 0 f4 f
:3 0 18 :2 0 64
bf c0 :3 0 14
:3 0 14 :3 0 19
:2 0 1e :4 0 66
c4 c6 :3 0 19
:2 0 f :3 0 69
c8 ca :3 0 19
:2 0 1b :4 0 6c
cc ce :3 0 c2
cf 0 d2 1c
:3 0 6f e8 10
:3 0 18 :2 0 71
d4 d5 :3 0 14
:3 0 14 :3 0 19
:2 0 1e :4 0 73
d9 db :3 0 19
:2 0 10 :3 0 76
dd df :3 0 19
:2 0 1b :4 0 79
e1 e3 :3 0 d7
e4 0 e6 7c
e7 d6 e6 0
e9 c1 d2 0
e9 7e 0 f4
14 :3 0 14 :3 0
19 :2 0 1f :4 0
81 ec ee :3 0
ea ef 0 f4
13 :3 0 14 :3 0
f2 :2 0 f4 84
f7 :3 0 f7 8b
f7 f6 f4 f5
:6 0 f8 1 0
49 59 f7 be2
:2 0 20 :a 0 11d
7 :7 0 8f 437
0 8d 22 :3 0
23 :3 0 24 :3 0
21 :5 0 1 ff
fe :3 0 93 :2 0
91 6 :3 0 25
:7 0 103 102 :3 0
6 :3 0 26 :7 0
107 106 :3 0 109
:2 0 11d fa 10a
:2 0 26 :3 0 18
:2 0 97 10d 10e
:3 0 21 :3 0 25
:3 0 99 110 112
26 :3 0 113 114
0 116 9b 117
10f 116 0 118
9d 0 119 9f
11c :3 0 11c 0
11c 11b 119 11a
:6 0 11d 1 0
fa 10a 11c be2
:2 0 27 :a 0 15d
8 :7 0 a3 4d8
0 a1 22 :3 0
23 :3 0 24 :3 0
21 :5 0 1 124
123 :3 0 a7 4fe
0 a5 6 :3 0
28 :7 0 128 127
:3 0 6 :3 0 25
:7 0 12c 12b :3 0
18 :2 0 a9 6
:3 0 26 :7 0 130
12f :3 0 132 :2 0
15d 11f 133 :2 0
26 :3 0 ae 136
137 :3 0 28 :3 0
18 :2 0 b0 13a
13b :3 0 21 :3 0
28 :3 0 19 :2 0
29 :3 0 b2 13f
141 :3 0 19 :2 0
25 :3 0 b5 143
145 :3 0 b8 13d
147 26 :3 0 148
149 0 14b ba
153 21 :3 0 25
:3 0 bc 14c 14e
26 :3 0 14f 150
0 152 be 154
13c 14b 0 155
0 152 0 155
c0 0 156 c3
157 138 156 0
158 c5 0 159
c7 15c :3 0 15c
0 15c 15b 159
15a :6 0 15d 1
0 11f 133 15c
be2 :2 0 2a :a 0
19a 9 :a 0 c9
22 :3 0 23 :3 0
24 :3 0 21 :5 0
1 164 163 :3 0
cd 5e9 0 cb
6 :3 0 25 :7 0
169 167 168 :2 0
18 :2 0 cf 6
:3 0 26 :7 0 16d
16c :3 0 16f :2 0
19a 15f 170 :2 0
26 :3 0 d3 173
174 :3 0 25 :3 0
18 :2 0 d5 177
178 :3 0 21 :3 0
2b :3 0 19 :2 0
29 :3 0 d7 17c
17e :3 0 19 :2 0
25 :3 0 da 180
182 :3 0 dd 17a
184 26 :3 0 185
186 0 188 df
190 21 :3 0 2b
:3 0 e1 189 18b
26 :3 0 18c 18d
0 18f e3 191
179 188 0 192
0 18f 0 192
e5 0 193 e8
194 175 193 0
195 ea 0 196
ec 199 :3 0 199
0 199 198 196
197 :6 0 19a 1
0 15f 170 199
be2 :2 0 2c :a 0
1b5 a :7 0 f0
6bf 0 ee 22
:3 0 23 :3 0 2e
:3 0 2d :5 0 1
1a1 1a0 :3 0 19
:2 0 f2 6 :3 0
2f :7 0 1a5 1a4
:3 0 1a7 :2 0 1b5
19c 1a8 :2 0 2d
:3 0 2d :3 0 2f
:3 0 f5 1ac 1ae
:3 0 1aa 1af 0
1b1 f8 1b4 :3 0
1b4 0 1b4 1b3
1b1 1b2 :6 0 1b5
1 0 19c 1a8
1b4 be2 :2 0 30
:a 0 1d4 b :7 0
fc 73c 0 fa
22 :3 0 23 :3 0
2e :3 0 2d :5 0
1 1bc 1bb :3 0
19 :2 0 fe 6
:3 0 2f :7 0 1c0
1bf :3 0 1c2 :2 0
1d4 1b7 1c3 :2 0
2d :3 0 2d :3 0
2f :3 0 101 1c7
1c9 :3 0 19 :2 0
7 :3 0 104 1cb
1cd :3 0 1c5 1ce
0 1d0 107 1d3
:3 0 1d3 0 1d3
1d2 1d0 1d1 :6 0
1d4 1 0 1b7
1c3 1d3 be2 :2 0
31 :a 0 1e7 c
:7 0 10b :2 0 109
22 :3 0 23 :3 0
2e :3 0 2d :5 0
1 1db 1da :3 0
1dd :2 0 1e7 1d6
1de :2 0 2d :3 0
32 :4 0 1e0 1e1
0 1e3 10d 1e6
:3 0 1e6 0 1e6
1e5 1e3 1e4 :6 0
1e7 1 0 1d6
1de 1e6 be2 :2 0
33 :a 0 20e d
:a 0 10f 22 :3 0
23 :3 0 2e :3 0
2d :5 0 1 1ee
1ed :6 0 111 6
:3 0 9 :7 0 1f3
1f1 1f2 :5 0 113
6 :3 0 c :7 0
1f8 1f6 1f7 :2 0
117 :2 0 115 6
:3 0 f :7 0 1fd
1fb 1fc :2 0 1ff
:2 0 20e 1e9 200
:2 0 2d :3 0 12
:3 0 9 :3 0 c
:3 0 f :3 0 11c
203 207 202 208
0 20a 120 20d
:3 0 20d 0 20d
20c 20a 20b :6 0
20e 1 0 1e9
200 20d be2 :2 0
34 :a 0 21f e
:7 0 124 :2 0 122
22 :3 0 23 :3 0
2e :3 0 2d :5 0
1 215 214 :3 0
217 :2 0 21f 210
218 :3 0 21b 126
21e :3 0 21e 0
21e 21d 21b 21c
:6 0 21f 1 0
210 218 21e be2
:2 0 35 :a 0 292
f :7 0 12a 925
0 128 22 :3 0
23 :3 0 2e :3 0
2d :5 0 1 226
225 :3 0 12e 94b
0 12c 6 :3 0
36 :7 0 22a 229
:3 0 24 :3 0 21
:7 0 22e 22d :3 0
135 96c 0 130
38 :3 0 39 :3 0
37 :7 0 233 231
232 :2 0 235 :2 0
292 221 236 :2 0
19 :2 0 137 3b
:3 0 239 :7 0 23c
23a 0 290 0
3a :6 0 3d :3 0
23e :7 0 241 23f
0 290 0 3c
:6 0 2c :3 0 2d
:3 0 3e :4 0 36
:3 0 139 245 247
:3 0 13c 242 249
:2 0 28e 3a :3 0
21 :3 0 3f :3 0
24c 24d 0 24b
24e 0 28e 40
:3 0 3a :3 0 41
:2 0 13f 252 253
:3 0 42 :8 0 257
141 258 254 257
0 259 143 0
27d 3c :3 0 21
:3 0 3a :3 0 145
25b 25d 25a 25e
0 27d 2c :3 0
2d :3 0 43 :4 0
19 :2 0 3a :3 0
147 263 265 :3 0
19 :2 0 44 :4 0
14a 267 269 :3 0
19 :2 0 3c :3 0
14d 26b 26d :3 0
19 :2 0 1b :4 0
150 26f 271 :3 0
153 260 273 :2 0
27d 3a :3 0 21
:3 0 45 :3 0 276
277 0 3a :3 0
156 278 27a 275
27b 0 27d 158
27f 40 :4 0 27d
:4 0 28e 37 :3 0
2c :3 0 2d :3 0
46 :4 0 15d 281
284 :2 0 286 160
287 280 286 0
288 162 0 28e
2c :3 0 2d :3 0
47 :4 0 164 289
28c :2 0 28e 167
291 :3 0 291 16d
291 290 28e 28f
:6 0 292 1 0
221 236 291 be2
:2 0 48 :a 0 2de
11 :7 0 172 af4
0 170 22 :3 0
23 :3 0 2e :3 0
2d :5 0 1 299
298 :3 0 176 b1a
0 174 6 :3 0
28 :7 0 29d 29c
:3 0 6 :3 0 36
:7 0 2a1 2a0 :3 0
17a :2 0 178 24
:3 0 21 :7 0 2a5
2a4 :3 0 38 :3 0
39 :3 0 37 :7 0
2aa 2a8 2a9 :2 0
2ac :2 0 2de 294
2ad :2 0 18 :2 0
180 3b :3 0 2b0
:7 0 2b3 2b1 0
2dc 0 49 :6 0
28 :3 0 182 2b5
2b6 :3 0 49 :3 0
28 :3 0 19 :2 0
29 :3 0 184 2ba
2bc :3 0 19 :2 0
36 :3 0 187 2be
2c0 :3 0 2b8 2c1
0 2c3 18a 2c8
49 :3 0 36 :3 0
2c4 2c5 0 2c7
18c 2c9 2b7 2c3
0 2ca 0 2c7
0 2ca 18e 0
2da 35 :3 0 2d
:3 0 2d :3 0 2cc
2cd 36 :3 0 49
:3 0 2cf 2d0 21
:3 0 21 :3 0 2d2
2d3 37 :3 0 37
:3 0 2d5 2d6 191
2cb 2d8 :2 0 2da
196 2dd :3 0 2dd
199 2dd 2dc 2da
2db :6 0 2de 1
0 294 2ad 2dd
be2 :2 0 35 :a 0
30e 12 :7 0 19d
c2f 0 19b 22
:3 0 23 :3 0 2e
:3 0 2d :5 0 1
2e5 2e4 :3 0 1a1
:2 0 19f 6 :3 0
36 :7 0 2e9 2e8
:3 0 38 :3 0 39
:3 0 37 :7 0 2ee
2ec 2ed :2 0 2f0
:2 0 30e 2e0 2f1
:2 0 2c :3 0 2d
:3 0 3e :4 0 19
:2 0 36 :3 0 1a5
2f6 2f8 :3 0 1a8
2f3 2fa :2 0 30a
37 :3 0 2c :3 0
2d :3 0 46 :4 0
1ab 2fd 300 :2 0
302 1ae 303 2fc
302 0 304 1b0
0 30a 2c :3 0
2d :3 0 47 :4 0
1b2 305 308 :2 0
30a 1b5 30d :3 0
30d 0 30d 30c
30a 30b :6 0 30e
1 0 2e0 2f1
30d be2 :2 0 48
:a 0 353 13 :7 0
1bb cfe 0 1b9
22 :3 0 23 :3 0
2e :3 0 2d :5 0
1 315 314 :3 0
1bf d24 0 1bd
6 :3 0 28 :7 0
319 318 :3 0 6
:3 0 36 :7 0 31d
31c :3 0 1c6 d45
0 1c1 38 :3 0
39 :3 0 37 :7 0
322 320 321 :2 0
324 :2 0 353 310
325 :2 0 28 :3 0
3b :3 0 328 :7 0
32b 329 0 351
0 49 :6 0 18
:2 0 1c8 32d 32e
:3 0 49 :3 0 28
:3 0 19 :2 0 29
:3 0 1ca 332 334
:3 0 19 :2 0 36
:3 0 1cd 336 338
:3 0 330 339 0
33b 1d0 340 49
:3 0 36 :3 0 33c
33d 0 33f 1d2
341 32f 33b 0
342 0 33f 0
342 1d4 0 34f
35 :3 0 2d :3 0
2d :3 0 344 345
36 :3 0 49 :3 0
347 348 37 :3 0
37 :3 0 34a 34b
1d7 343 34d :2 0
34f 1db 352 :3 0
352 1de 352 351
34f 350 :6 0 353
1 0 310 325
352 be2 :2 0 4a
:a 0 374 14 :7 0
1e2 e1d 0 1e0
22 :3 0 23 :3 0
2e :3 0 2d :5 0
1 35a 359 :3 0
19 :2 0 1e4 6
:3 0 36 :7 0 35e
35d :3 0 360 :2 0
374 355 361 :2 0
2c :3 0 2d :3 0
4b :4 0 36 :3 0
1e7 366 368 :3 0
19 :2 0 47 :4 0
1ea 36a 36c :3 0
1ed 363 36e :2 0
370 1f0 373 :3 0
373 0 373 372
370 371 :6 0 374
1 0 355 361
373 be2 :2 0 4c
:a 0 3b7 15 :7 0
1f4 eaf 0 1f2
22 :3 0 23 :3 0
2e :3 0 2d :5 0
1 37b 37a :3 0
1f8 :2 0 1f6 6
:3 0 28 :7 0 37f
37e :3 0 6 :3 0
36 :7 0 383 382
:3 0 385 :2 0 3b7
376 386 :2 0 28
:3 0 18 :2 0 1fc
389 38a :3 0 2c
:3 0 2d :3 0 4b
:4 0 19 :2 0 28
:3 0 1fe 38f 391
:3 0 19 :2 0 29
:3 0 201 393 395
:3 0 19 :2 0 36
:3 0 204 397 399
:3 0 19 :2 0 47
:4 0 207 39b 39d
:3 0 20a 38c 39f
:2 0 3a1 20d 3b0
2c :3 0 2d :3 0
4b :4 0 19 :2 0
36 :3 0 20f 3a5
3a7 :3 0 19 :2 0
47 :4 0 212 3a9
3ab :3 0 215 3a2
3ad :2 0 3af 218
3b1 38b 3a1 0
3b2 0 3af 0
3b2 21a 0 3b3
21d 3b6 :3 0 3b6
0 3b6 3b5 3b3
3b4 :6 0 3b7 1
0 376 386 3b6
be2 :2 0 4d :a 0
3d0 16 :7 0 221
fb9 0 21f 22
:3 0 23 :3 0 2e
:3 0 2d :5 0 1
3be 3bd :3 0 226
:2 0 223 6 :3 0
4e :7 0 3c2 3c1
:3 0 3c4 :2 0 3d0
3b9 3c5 :2 0 2c
:3 0 2d :3 0 4e
:3 0 3c7 3ca :2 0
3cc 229 3cf :3 0
3cf 0 3cf 3ce
3cc 3cd :6 0 3d0
1 0 3b9 3c5
3cf be2 :2 0 11
:3 0 4f :a 0 3eb
17 :7 0 22d :2 0
22b 22 :3 0 23
:3 0 2e :3 0 2d
:5 0 1 3d8 3d7
:3 0 13 :3 0 50
:3 0 51 :2 0 4
3dc 3dd 0 3da
3de 0 3eb 3d3
3df :2 0 13 :3 0
51 :3 0 2d :3 0
22f 3e2 3e4 3e5
:2 0 3e7 231 3ea
:3 0 3ea 0 3ea
3e9 3e7 3e8 :6 0
3eb 1 0 3d3
3df 3ea be2 :2 0
52 :a 0 42a 18
:7 0 235 10a9 0
233 22 :3 0 23
:3 0 2e :3 0 2d
:5 0 1 3f2 3f1
:3 0 239 :2 0 237
22 :3 0 23 :3 0
54 :3 0 53 :5 0
1 3f8 3f7 :3 0
6 :3 0 56 :4 0
55 :7 0 3fd 3fb
3fc :2 0 3ff :2 0
42a 3ed 400 :2 0
409 40a 0 23d
50 :3 0 51 :2 0
4 403 404 0
405 :7 0 408 406
0 428 0 57
:6 0 58 :3 0 59
:3 0 53 :3 0 5a
:3 0 5b :3 0 40d
40e 23f 40b 410
:2 0 426 57 :3 0
51 :3 0 2d :4 0
5c :2 0 5c :2 0
242 413 418 412
419 0 426 53
:3 0 57 :3 0 5d
:3 0 41c 41d 0
5e :3 0 55 :3 0
247 41f 421 249
41e 423 41b 424
0 426 24b 429
:3 0 429 24f 429
428 426 427 :6 0
42a 1 0 3ed
400 429 be2 :2 0
5f :a 0 47b 19
:7 0 253 11a7 0
251 22 :3 0 23
:3 0 2e :3 0 2d
:5 0 1 431 430
:3 0 257 :2 0 255
22 :3 0 23 :3 0
54 :3 0 53 :5 0
1 437 436 :3 0
6 :3 0 56 :4 0
55 :7 0 43c 43a
43b :2 0 43e :2 0
47b 42c 43f :2 0
62 :2 0 25b 61
:3 0 442 :7 0 62
:2 0 446 443 444
479 0 60 :6 0
5c :2 0 25d 61
:3 0 448 :7 0 44c
449 44a 479 0
63 :6 0 5c :2 0
25f 61 :3 0 44e
:7 0 452 44f 450
479 0 64 :6 0
459 45a 0 261
61 :3 0 454 :7 0
458 455 456 479
0 65 :6 0 58
:3 0 59 :3 0 53
:3 0 5a :3 0 5b
:3 0 45d 45e 263
45b 460 :2 0 477
58 :3 0 66 :3 0
462 463 0 53
:3 0 2d :3 0 58
:3 0 67 :3 0 467
468 0 2d :3 0
266 469 46b 60
:3 0 63 :3 0 5e
:3 0 55 :3 0 268
46f 471 64 :3 0
65 :3 0 26a 464
475 :2 0 477 273
47a :3 0 47a 276
47a 479 477 478
:6 0 47b 1 0
42c 43f 47a be2
:2 0 2c :a 0 4b5
1a :7 0 27d 1300
0 27b 22 :3 0
23 :3 0 68 :3 0
2d :5 0 1 482
481 :3 0 48b 48c
0 27f 6 :3 0
2f :7 0 486 485
:3 0 488 :2 0 4b5
47d 489 :2 0 2d
:3 0 69 :3 0 2d
:3 0 69 :3 0 48e
48f 0 19 :2 0
2f :3 0 282 491
493 :3 0 48d 494
0 496 285 4af
6a :3 0 2d :3 0
6b :3 0 498 499
0 2d :3 0 6b
:3 0 49b 49c 0
19 :2 0 2d :3 0
69 :3 0 49f 4a0
0 287 49e 4a2
:3 0 49a 4a3 0
4aa 2d :3 0 69
:3 0 4a5 4a6 0
2f :3 0 4a7 4a8
0 4aa 28a 4ac
28d 4ab 4aa :2 0
4ad 28f :2 0 4af
0 4af 4ae 496
4ad :6 0 4b1 1a
:3 0 291 4b4 :3 0
4b4 0 4b4 4b3
4b1 4b2 :6 0 4b5
1 0 47d 489
4b4 be2 :2 0 30
:a 0 4d6 1c :7 0
295 13ee 0 293
22 :3 0 23 :3 0
68 :3 0 2d :5 0
1 4bc 4bb :3 0
4c6 4c7 0 297
6 :3 0 2f :7 0
4c0 4bf :3 0 4c2
:2 0 4d6 4b7 4c3
:2 0 2c :3 0 2d
:3 0 2d :3 0 2f
:3 0 2f :3 0 19
:2 0 7 :3 0 29a
4cb 4cd :3 0 4c9
4ce 29d 4c5 4d0
:2 0 4d2 2a0 4d5
:3 0 4d5 0 4d5
4d4 4d2 4d3 :6 0
4d6 1 0 4b7
4c3 4d5 be2 :2 0
31 :a 0 4f0 1d
:7 0 2a4 :2 0 2a2
22 :3 0 23 :3 0
68 :3 0 2d :5 0
1 4dd 4dc :3 0
4df :2 0 4f0 4d8
4e0 :2 0 2d :3 0
6b :3 0 4e2 4e3
0 32 :4 0 4e4
4e5 0 4ec 2d
:3 0 69 :3 0 4e7
4e8 0 32 :4 0
4e9 4ea 0 4ec
2a6 4ef :3 0 4ef
0 4ef 4ee 4ec
4ed :6 0 4f0 1
0 4d8 4e0 4ef
be2 :2 0 33 :a 0
51e 1e :a 0 2a9
22 :3 0 23 :3 0
68 :3 0 2d :5 0
1 4f7 4f6 :6 0
2ab 6 :3 0 9
:7 0 4fc 4fa 4fb
:5 0 2ad 6 :3 0
c :7 0 501 4ff
500 :2 0 2b1 :2 0
2af 6 :3 0 f
:7 0 506 504 505
:2 0 508 :2 0 51e
4f2 509 :2 0 2d
:3 0 6b :3 0 50b
50c 0 32 :4 0
50d 50e 0 51a
2d :3 0 69 :3 0
510 511 0 12
:3 0 9 :3 0 c
:3 0 f :3 0 2b6
513 517 512 518
0 51a 2ba 51d
:3 0 51d 0 51d
51c 51a 51b :6 0
51e 1 0 4f2
509 51d be2 :2 0
34 :a 0 540 1f
:7 0 2bf :2 0 2bd
22 :3 0 23 :3 0
68 :3 0 2d :5 0
1 525 524 :3 0
527 :2 0 540 520
528 :2 0 2d :3 0
6b :3 0 52a 52b
0 2d :3 0 6b
:3 0 52d 52e 0
19 :2 0 2d :3 0
69 :3 0 531 532
0 2c1 530 534
:3 0 52c 535 0
53c 2d :3 0 69
:3 0 537 538 0
32 :4 0 539 53a
0 53c 2c4 53f
:3 0 53f 0 53f
53e 53c 53d :6 0
540 1 0 520
528 53f be2 :2 0
35 :a 0 5b3 20
:7 0 2c9 1653 0
2c7 22 :3 0 23
:3 0 68 :3 0 2d
:5 0 1 547 546
:3 0 2cd 1679 0
2cb 6 :3 0 36
:7 0 54b 54a :3 0
24 :3 0 21 :7 0
54f 54e :3 0 2d4
169a 0 2cf 38
:3 0 39 :3 0 37
:7 0 554 552 553
:2 0 556 :2 0 5b3
542 557 :2 0 19
:2 0 2d6 3b :3 0
55a :7 0 55d 55b
0 5b1 0 3a
:6 0 3d :3 0 55f
:7 0 562 560 0
5b1 0 3c :6 0
2c :3 0 2d :3 0
3e :4 0 36 :3 0
2d8 566 568 :3 0
2db 563 56a :2 0
5af 3a :3 0 21
:3 0 3f :3 0 56d
56e 0 56c 56f
0 5af 40 :3 0
3a :3 0 41 :2 0
2de 573 574 :3 0
42 :8 0 578 2e0
579 575 578 0
57a 2e2 0 59e
3c :3 0 21 :3 0
3a :3 0 2e4 57c
57e 57b 57f 0
59e 2c :3 0 2d
:3 0 43 :4 0 19
:2 0 3a :3 0 2e6
584 586 :3 0 19
:2 0 44 :4 0 2e9
588 58a :3 0 19
:2 0 3c :3 0 2ec
58c 58e :3 0 19
:2 0 1b :4 0 2ef
590 592 :3 0 2f2
581 594 :2 0 59e
3a :3 0 21 :3 0
45 :3 0 597 598
0 3a :3 0 2f5
599 59b 596 59c
0 59e 2f7 5a0
40 :4 0 59e :4 0
5af 37 :3 0 2c
:3 0 2d :3 0 46
:4 0 2fc 5a2 5a5
:2 0 5a7 2ff 5a8
5a1 5a7 0 5a9
301 0 5af 2c
:3 0 2d :3 0 47
:4 0 303 5aa 5ad
:2 0 5af 306 5b2
:3 0 5b2 30c 5b2
5b1 5af 5b0 :6 0
5b3 1 0 542
557 5b2 be2 :2 0
48 :a 0 5ff 22
:7 0 311 1822 0
30f 22 :3 0 23
:3 0 68 :3 0 2d
:5 0 1 5ba 5b9
:3 0 315 1848 0
313 6 :3 0 28
:7 0 5be 5bd :3 0
6 :3 0 36 :7 0
5c2 5c1 :3 0 319
:2 0 317 24 :3 0
21 :7 0 5c6 5c5
:3 0 38 :3 0 39
:3 0 37 :7 0 5cb
5c9 5ca :2 0 5cd
:2 0 5ff 5b5 5ce
:2 0 18 :2 0 31f
3b :3 0 5d1 :7 0
5d4 5d2 0 5fd
0 49 :6 0 28
:3 0 321 5d6 5d7
:3 0 49 :3 0 28
:3 0 19 :2 0 29
:3 0 323 5db 5dd
:3 0 19 :2 0 36
:3 0 326 5df 5e1
:3 0 5d9 5e2 0
5e4 329 5e9 49
:3 0 36 :3 0 5e5
5e6 0 5e8 32b
5ea 5d8 5e4 0
5eb 0 5e8 0
5eb 32d 0 5fb
35 :3 0 2d :3 0
2d :3 0 5ed 5ee
36 :3 0 49 :3 0
5f0 5f1 21 :3 0
21 :3 0 5f3 5f4
37 :3 0 37 :3 0
5f6 5f7 330 5ec
5f9 :2 0 5fb 335
5fe :3 0 5fe 338
5fe 5fd 5fb 5fc
:6 0 5ff 1 0
5b5 5ce 5fe be2
:2 0 35 :a 0 62f
23 :7 0 33c 195d
0 33a 22 :3 0
23 :3 0 68 :3 0
2d :5 0 1 606
605 :3 0 340 :2 0
33e 6 :3 0 36
:7 0 60a 609 :3 0
38 :3 0 39 :3 0
37 :7 0 60f 60d
60e :2 0 611 :2 0
62f 601 612 :2 0
2c :3 0 2d :3 0
3e :4 0 19 :2 0
36 :3 0 344 617
619 :3 0 347 614
61b :2 0 62b 37
:3 0 2c :3 0 2d
:3 0 46 :4 0 34a
61e 621 :2 0 623
34d 624 61d 623
0 625 34f 0
62b 2c :3 0 2d
:3 0 47 :4 0 351
626 629 :2 0 62b
354 62e :3 0 62e
0 62e 62d 62b
62c :6 0 62f 1
0 601 612 62e
be2 :2 0 48 :a 0
674 24 :7 0 35a
1a2c 0 358 22
:3 0 23 :3 0 68
:3 0 2d :5 0 1
636 635 :3 0 35e
1a52 0 35c 6
:3 0 28 :7 0 63a
639 :3 0 6 :3 0
36 :7 0 63e 63d
:3 0 365 1a73 0
360 38 :3 0 39
:3 0 37 :7 0 643
641 642 :2 0 645
:2 0 674 631 646
:2 0 28 :3 0 3b
:3 0 649 :7 0 64c
64a 0 672 0
49 :6 0 18 :2 0
367 64e 64f :3 0
49 :3 0 28 :3 0
19 :2 0 29 :3 0
369 653 655 :3 0
19 :2 0 36 :3 0
36c 657 659 :3 0
651 65a 0 65c
36f 661 49 :3 0
36 :3 0 65d 65e
0 660 371 662
650 65c 0 663
0 660 0 663
373 0 670 35
:3 0 2d :3 0 2d
:3 0 665 666 36
:3 0 49 :3 0 668
669 37 :3 0 37
:3 0 66b 66c 376
664 66e :2 0 670
37a 673 :3 0 673
37d 673 672 670
671 :6 0 674 1
0 631 646 673
be2 :2 0 4a :a 0
695 25 :7 0 381
1b4b 0 37f 22
:3 0 23 :3 0 68
:3 0 2d :5 0 1
67b 67a :3 0 19
:2 0 383 6 :3 0
36 :7 0 67f 67e
:3 0 681 :2 0 695
676 682 :2 0 2c
:3 0 2d :3 0 4b
:4 0 36 :3 0 386
687 689 :3 0 19
:2 0 47 :4 0 389
68b 68d :3 0 38c
684 68f :2 0 691
38f 694 :3 0 694
0 694 693 691
692 :6 0 695 1
0 676 682 694
be2 :2 0 4c :a 0
6d8 26 :7 0 393
1bdd 0 391 22
:3 0 23 :3 0 68
:3 0 2d :5 0 1
69c 69b :3 0 397
:2 0 395 6 :3 0
28 :7 0 6a0 69f
:3 0 6 :3 0 36
:7 0 6a4 6a3 :3 0
6a6 :2 0 6d8 697
6a7 :2 0 28 :3 0
18 :2 0 39b 6aa
6ab :3 0 2c :3 0
2d :3 0 4b :4 0
19 :2 0 28 :3 0
39d 6b0 6b2 :3 0
19 :2 0 29 :3 0
3a0 6b4 6b6 :3 0
19 :2 0 36 :3 0
3a3 6b8 6ba :3 0
19 :2 0 47 :4 0
3a6 6bc 6be :3 0
3a9 6ad 6c0 :2 0
6c2 3ac 6d1 2c
:3 0 2d :3 0 4b
:4 0 19 :2 0 36
:3 0 3ae 6c6 6c8
:3 0 19 :2 0 47
:4 0 3b1 6ca 6cc
:3 0 3b4 6c3 6ce
:2 0 6d0 3b7 6d2
6ac 6c2 0 6d3
0 6d0 0 6d3
3b9 0 6d4 3bc
6d7 :3 0 6d7 0
6d7 6d6 6d4 6d5
:6 0 6d8 1 0
697 6a7 6d7 be2
:2 0 4d :a 0 6f1
27 :7 0 3c0 1ce7
0 3be 22 :3 0
23 :3 0 68 :3 0
2d :5 0 1 6df
6de :3 0 3c5 :2 0
3c2 6 :3 0 4e
:7 0 6e3 6e2 :3 0
6e5 :2 0 6f1 6da
6e6 :2 0 2c :3 0
2d :3 0 4e :3 0
6e8 6eb :2 0 6ed
3c8 6f0 :3 0 6f0
0 6f0 6ef 6ed
6ee :6 0 6f1 1
0 6da 6e6 6f0
be2 :2 0 11 :3 0
4f :a 0 70e 28
:7 0 3cc :2 0 3ca
22 :3 0 23 :3 0
68 :3 0 2d :5 0
1 6f9 6f8 :3 0
13 :3 0 50 :3 0
51 :2 0 4 6fd
6fe 0 6fb 6ff
0 70e 6f4 700
:2 0 13 :3 0 51
:3 0 2d :3 0 6b
:3 0 704 705 0
3ce 703 707 708
:2 0 70a 3d0 70d
:3 0 70d 0 70d
70c 70a 70b :6 0
70e 1 0 6f4
700 70d be2 :2 0
52 :a 0 73e 29
:7 0 3d4 1dde 0
3d2 22 :3 0 23
:3 0 68 :3 0 2d
:5 0 1 715 714
:3 0 3d8 :2 0 3d6
22 :3 0 23 :3 0
54 :3 0 53 :5 0
1 71b 71a :3 0
6 :3 0 56 :4 0
55 :7 0 720 71e
71f :2 0 722 :2 0
73e 710 723 :2 0
72e 72f 0 3dc
50 :3 0 51 :2 0
4 726 727 0
728 :7 0 72b 729
0 73c 0 57
:6 0 52 :3 0 2d
:3 0 2d :3 0 6b
:3 0 72d 730 53
:3 0 53 :3 0 732
733 55 :3 0 55
:3 0 735 736 3de
72c 738 :2 0 73a
3e2 73d :3 0 73d
3e4 73d 73c 73a
73b :6 0 73e 1
0 710 723 73d
be2 :2 0 5f :a 0
767 2a :7 0 3e8
1eb1 0 3e6 22
:3 0 23 :3 0 68
:3 0 2d :5 0 1
745 744 :3 0 3ec
:2 0 3ea 22 :3 0
23 :3 0 54 :3 0
53 :5 0 1 74b
74a :3 0 6 :3 0
56 :4 0 55 :7 0
750 74e 74f :2 0
752 :2 0 767 740
753 :2 0 5f :3 0
2d :3 0 2d :3 0
6b :3 0 757 758
0 756 759 53
:3 0 53 :3 0 75b
75c 55 :3 0 55
:3 0 75e 75f 3f0
755 761 :2 0 763
3f4 766 :3 0 766
0 766 765 763
764 :6 0 767 1
0 740 753 766
be2 :2 0 6c :a 0
779 2b :8 0 76a
:2 0 779 769 76b
:2 0 6d :3 0 6e
:3 0 76d 76e 0
76f 771 :2 0 775
0 6f :3 0 5c
:2 0 772 773 0
775 3f6 778 :3 0
778 0 778 777
775 776 :6 0 779
1 0 769 76b
778 be2 :2 0 2c
:a 0 7c3 2c :7 0
3fb 1fb0 0 3f9
61 :3 0 70 :7 0
77e 77d :3 0 400
:2 0 3fd 6 :3 0
2f :7 0 782 781
:3 0 784 :2 0 7c3
77b 785 :2 0 6d
:3 0 70 :3 0 787
789 69 :3 0 78a
78b 0 6d :3 0
70 :3 0 402 78d
78f 69 :3 0 790
791 0 19 :2 0
2f :3 0 404 793
795 :3 0 78c 796
0 798 407 7bd
6a :3 0 6d :3 0
70 :3 0 409 79a
79c 6b :3 0 79d
79e 0 6d :3 0
70 :3 0 40b 7a0
7a2 6b :3 0 7a3
7a4 0 19 :2 0
6d :3 0 70 :3 0
40d 7a7 7a9 69
:3 0 7aa 7ab 0
40f 7a6 7ad :3 0
79f 7ae 0 7b8
6d :3 0 70 :3 0
412 7b0 7b2 69
:3 0 7b3 7b4 0
2f :3 0 7b5 7b6
0 7b8 414 7ba
417 7b9 7b8 :2 0
7bb 419 :2 0 7bd
0 7bd 7bc 798
7bb :6 0 7bf 2c
:3 0 41b 7c2 :3 0
7c2 0 7c2 7c1
7bf 7c0 :6 0 7c3
1 0 77b 785
7c2 be2 :2 0 30
:a 0 7e2 2e :7 0
41f 20c3 0 41d
61 :3 0 70 :7 0
7c8 7c7 :3 0 7d2
7d3 0 421 6
:3 0 2f :7 0 7cc
7cb :3 0 7ce :2 0
7e2 7c5 7cf :2 0
2c :3 0 70 :3 0
70 :3 0 2f :3 0
2f :3 0 19 :2 0
7 :3 0 424 7d7
7d9 :3 0 7d5 7da
427 7d1 7dc :2 0
7de 42a 7e1 :3 0
7e1 0 7e1 7e0
7de 7df :6 0 7e2
1 0 7c5 7cf
7e1 be2 :2 0 11
:3 0 31 :a 0 809
2f :7 0 13 :4 0
61 :3 0 7e7 7e8
0 809 7e5 7e9
:2 0 6f :3 0 6f
:3 0 71 :2 0 62
:2 0 42c 7ed 7ef
:3 0 7eb 7f0 0
805 6d :3 0 6f
:3 0 42f 7f2 7f4
6b :3 0 7f5 7f6
0 32 :4 0 7f7
7f8 0 805 6d
:3 0 6f :3 0 431
7fa 7fc 69 :3 0
7fd 7fe 0 32
:4 0 7ff 800 0
805 13 :3 0 6f
:3 0 803 :2 0 805
433 808 :3 0 808
0 808 807 805
806 :6 0 809 1
0 7e5 7e9 808
be2 :2 0 11 :3 0
33 :a 0 844 30
:a 0 438 6 :4 0
9 :7 0 810 80e
80f :5 0 43a 6
:3 0 c :7 0 815
813 814 :2 0 43e
:2 0 43c 6 :3 0
f :7 0 81a 818
819 :2 0 13 :3 0
61 :3 0 81c 81e
0 844 80c 81f
:2 0 6f :3 0 6f
:3 0 71 :2 0 62
:2 0 442 823 825
:3 0 821 826 0
840 6d :3 0 6f
:3 0 445 828 82a
6b :3 0 82b 82c
0 32 :4 0 82d
82e 0 840 6d
:3 0 6f :3 0 447
830 832 69 :3 0
833 834 0 12
:3 0 9 :3 0 c
:3 0 f :3 0 449
836 83a 835 83b
0 840 13 :3 0
6f :3 0 83e :2 0
840 44d 843 :3 0
843 0 843 842
840 841 :6 0 844
1 0 80c 81f
843 be2 :2 0 34
:a 0 870 31 :7 0
454 :2 0 452 61
:3 0 70 :7 0 849
848 :3 0 84b :2 0
870 846 84c :2 0
6d :3 0 70 :3 0
456 84e 850 6b
:3 0 851 852 0
6d :3 0 70 :3 0
458 854 856 6b
:3 0 857 858 0
19 :2 0 6d :3 0
70 :3 0 45a 85b
85d 69 :3 0 85e
85f 0 45c 85a
861 :3 0 853 862
0 86c 6d :3 0
70 :3 0 45f 864
866 69 :3 0 867
868 0 32 :4 0
869 86a 0 86c
461 86f :3 0 86f
0 86f 86e 86c
86d :6 0 870 1
0 846 84c 86f
be2 :2 0 35 :a 0
8e1 32 :7 0 466
237c 0 464 61
:3 0 70 :7 0 875
874 :3 0 46a 23a2
0 468 6 :3 0
36 :7 0 879 878
:3 0 24 :3 0 21
:7 0 87d 87c :3 0
471 23c3 0 46c
38 :3 0 39 :3 0
37 :7 0 882 880
881 :2 0 884 :2 0
8e1 872 885 :2 0
19 :2 0 473 3b
:3 0 888 :7 0 88b
889 0 8df 0
3a :6 0 3d :3 0
88d :7 0 890 88e
0 8df 0 3c
:6 0 2c :3 0 70
:3 0 3e :4 0 36
:3 0 475 894 896
:3 0 478 891 898
:2 0 8dd 3a :3 0
21 :3 0 3f :3 0
89b 89c 0 89a
89d 0 8dd 40
:3 0 3a :3 0 41
:2 0 47b 8a1 8a2
:3 0 42 :8 0 8a6
47d 8a7 8a3 8a6
0 8a8 47f 0
8cc 3c :3 0 21
:3 0 3a :3 0 481
8aa 8ac 8a9 8ad
0 8cc 2c :3 0
70 :3 0 43 :4 0
19 :2 0 3a :3 0
483 8b2 8b4 :3 0
19 :2 0 44 :4 0
486 8b6 8b8 :3 0
19 :2 0 3c :3 0
489 8ba 8bc :3 0
19 :2 0 1b :4 0
48c 8be 8c0 :3 0
48f 8af 8c2 :2 0
8cc 3a :3 0 21
:3 0 45 :3 0 8c5
8c6 0 3a :3 0
492 8c7 8c9 8c4
8ca 0 8cc 494
8ce 40 :4 0 8cc
:4 0 8dd 37 :3 0
2c :3 0 70 :3 0
46 :4 0 499 8d0
8d3 :2 0 8d5 49c
8d6 8cf 8d5 0
8d7 49e 0 8dd
2c :3 0 70 :3 0
47 :4 0 4a0 8d8
8db :2 0 8dd 4a3
8e0 :3 0 8e0 4a9
8e0 8df 8dd 8de
:6 0 8e1 1 0
872 885 8e0 be2
:2 0 48 :a 0 92b
34 :7 0 4ae 2544
0 4ac 61 :3 0
70 :7 0 8e6 8e5
:3 0 4b2 256a 0
4b0 6 :3 0 28
:7 0 8ea 8e9 :3 0
6 :3 0 36 :7 0
8ee 8ed :3 0 4b6
:2 0 4b4 24 :3 0
21 :7 0 8f2 8f1
:3 0 38 :3 0 39
:3 0 37 :7 0 8f7
8f5 8f6 :2 0 8f9
:2 0 92b 8e3 8fa
:2 0 18 :2 0 4bc
3b :3 0 8fd :7 0
900 8fe 0 929
0 49 :6 0 28
:3 0 4be 902 903
:3 0 49 :3 0 28
:3 0 19 :2 0 29
:3 0 4c0 907 909
:3 0 19 :2 0 36
:3 0 4c3 90b 90d
:3 0 905 90e 0
910 4c6 915 49
:3 0 36 :3 0 911
912 0 914 4c8
916 904 910 0
917 0 914 0
917 4ca 0 927
35 :3 0 70 :3 0
70 :3 0 919 91a
36 :3 0 49 :3 0
91c 91d 21 :3 0
21 :3 0 91f 920
37 :3 0 37 :3 0
922 923 4cd 918
925 :2 0 927 4d2
92a :3 0 92a 4d5
92a 929 927 928
:6 0 92b 1 0
8e3 8fa 92a be2
:2 0 35 :a 0 959
35 :7 0 4d9 2678
0 4d7 61 :3 0
70 :7 0 930 92f
:3 0 4dd :2 0 4db
6 :3 0 36 :7 0
934 933 :3 0 38
:3 0 39 :3 0 37
:7 0 939 937 938
:2 0 93b :2 0 959
92d 93c :2 0 2c
:3 0 70 :3 0 3e
:4 0 19 :2 0 36
:3 0 4e1 941 943
:3 0 4e4 93e 945
:2 0 955 37 :3 0
2c :3 0 70 :3 0
46 :4 0 4e7 948
94b :2 0 94d 4ea
94e 947 94d 0
94f 4ec 0 955
2c :3 0 70 :3 0
47 :4 0 4ee 950
953 :2 0 955 4f1
958 :3 0 958 0
958 957 955 956
:6 0 959 1 0
92d 93c 958 be2
:2 0 48 :a 0 99c
36 :7 0 4f7 2740
0 4f5 61 :3 0
70 :7 0 95e 95d
:3 0 4fb 2766 0
4f9 6 :3 0 28
:7 0 962 961 :3 0
6 :3 0 36 :7 0
966 965 :3 0 502
2787 0 4fd 38
:3 0 39 :3 0 37
:7 0 96b 969 96a
:2 0 96d :2 0 99c
95b 96e :2 0 28
:3 0 3b :3 0 971
:7 0 974 972 0
99a 0 49 :6 0
18 :2 0 504 976
977 :3 0 49 :3 0
28 :3 0 19 :2 0
29 :3 0 506 97b
97d :3 0 19 :2 0
36 :3 0 509 97f
981 :3 0 979 982
0 984 50c 989
49 :3 0 36 :3 0
985 986 0 988
50e 98a 978 984
0 98b 0 988
0 98b 510 0
998 35 :3 0 70
:3 0 70 :3 0 98d
98e 36 :3 0 49
:3 0 990 991 37
:3 0 37 :3 0 993
994 513 98c 996
:2 0 998 517 99b
:3 0 99b 51a 99b
99a 998 999 :6 0
99c 1 0 95b
96e 99b be2 :2 0
4a :a 0 9bb 37
:7 0 51e 2858 0
51c 61 :3 0 70
:7 0 9a1 9a0 :3 0
19 :2 0 520 6
:3 0 36 :7 0 9a5
9a4 :3 0 9a7 :2 0
9bb 99e 9a8 :2 0
2c :3 0 70 :3 0
4b :4 0 36 :3 0
523 9ad 9af :3 0
19 :2 0 47 :4 0
526 9b1 9b3 :3 0
529 9aa 9b5 :2 0
9b7 52c 9ba :3 0
9ba 0 9ba 9b9
9b7 9b8 :6 0 9bb
1 0 99e 9a8
9ba be2 :2 0 4c
:a 0 9fc 38 :7 0
530 28e3 0 52e
61 :3 0 70 :7 0
9c0 9bf :3 0 534
:2 0 532 6 :3 0
28 :7 0 9c4 9c3
:3 0 6 :3 0 36
:7 0 9c8 9c7 :3 0
9ca :2 0 9fc 9bd
9cb :2 0 28 :3 0
18 :2 0 538 9ce
9cf :3 0 2c :3 0
70 :3 0 4b :4 0
19 :2 0 28 :3 0
53a 9d4 9d6 :3 0
19 :2 0 29 :3 0
53d 9d8 9da :3 0
19 :2 0 36 :3 0
540 9dc 9de :3 0
19 :2 0 47 :4 0
543 9e0 9e2 :3 0
546 9d1 9e4 :2 0
9e6 549 9f5 2c
:3 0 70 :3 0 4b
:4 0 19 :2 0 36
:3 0 54b 9ea 9ec
:3 0 19 :2 0 47
:4 0 54e 9ee 9f0
:3 0 551 9e7 9f2
:2 0 9f4 554 9f6
9d0 9e6 0 9f7
0 9f4 0 9f7
556 0 9f8 559
9fb :3 0 9fb 0
9fb 9fa 9f8 9f9
:6 0 9fc 1 0
9bd 9cb 9fb be2
:2 0 4d :a 0 a13
39 :7 0 55d 29e6
0 55b 61 :3 0
70 :7 0 a01 a00
:3 0 562 :2 0 55f
6 :3 0 4e :7 0
a05 a04 :3 0 a07
:2 0 a13 9fe a08
:2 0 2c :3 0 70
:3 0 4e :3 0 a0a
a0d :2 0 a0f 565
a12 :3 0 a12 0
a12 a11 a0f a10
:6 0 a13 1 0
9fe a08 a12 be2
:2 0 11 :3 0 4f
:a 0 a31 3a :7 0
569 :2 0 567 61
:3 0 70 :7 0 a19
a18 :3 0 13 :3 0
50 :3 0 51 :2 0
4 a1d a1e 0
a1b a1f 0 a31
a16 a20 :2 0 13
:3 0 51 :3 0 6d
:3 0 70 :3 0 56b
a24 a26 6b :3 0
a27 a28 0 56d
a23 a2a a2b :2 0
a2d 56f a30 :3 0
a30 0 a30 a2f
a2d a2e :6 0 a31
1 0 a16 a20
a30 be2 :2 0 52
:a 0 a62 3b :7 0
573 2ad6 0 571
61 :3 0 70 :7 0
a36 a35 :3 0 577
:2 0 575 22 :3 0
23 :3 0 54 :3 0
53 :5 0 1 a3c
a3b :3 0 6 :3 0
56 :4 0 55 :7 0
a41 a3f a40 :2 0
a43 :2 0 a62 a33
a44 :2 0 57d :2 0
57b 50 :3 0 51
:2 0 4 a47 a48
0 a49 :7 0 a4c
a4a 0 a60 0
57 :6 0 52 :3 0
2d :3 0 6d :3 0
70 :3 0 a4f a51
6b :3 0 a52 a53
0 a4e a54 53
:3 0 53 :3 0 a56
a57 55 :3 0 55
:3 0 a59 a5a 57f
a4d a5c :2 0 a5e
583 a61 :3 0 a61
585 a61 a60 a5e
a5f :6 0 a62 1
0 a33 a44 a61
be2 :2 0 5f :a 0
a8c 3c :7 0 589
2bab 0 587 61
:3 0 70 :7 0 a67
a66 :3 0 58d :2 0
58b 22 :3 0 23
:3 0 54 :3 0 53
:5 0 1 a6d a6c
:3 0 6 :3 0 56
:4 0 55 :7 0 a72
a70 a71 :2 0 a74
:2 0 a8c a64 a75
:2 0 5f :3 0 2d
:3 0 6d :3 0 70
:3 0 591 a79 a7b
6b :3 0 a7c a7d
0 a78 a7e 53
:3 0 53 :3 0 a80
a81 55 :3 0 55
:3 0 a83 a84 593
a77 a86 :2 0 a88
597 a8b :3 0 a8b
0 a8b a8a a88
a89 :6 0 a8c 1
0 a64 a75 a8b
be2 :2 0 11 :3 0
72 :a 0 ab4 3d
:7 0 59b :2 0 599
6 :3 0 73 :7 0
a92 a91 :3 0 13
:3 0 6 :3 0 a94
a96 0 ab4 a8f
a97 :2 0 73 :3 0
18 :2 0 59d a9a
a9b :3 0 13 :3 0
74 :3 0 75 :3 0
73 :3 0 59f a9f
aa1 76 :4 0 77
:4 0 5a1 a9e aa5
aa6 :2 0 aa8 5a5
aad 13 :4 0 aaa
:2 0 aac 5a7 aae
a9c aa8 0 aaf
0 aac 0 aaf
5a9 0 ab0 5ac
ab3 :3 0 ab3 0
ab3 ab2 ab0 ab1
:6 0 ab4 1 0
a8f a97 ab3 be2
:2 0 11 :3 0 78
:a 0 af5 3e :7 0
5b0 :2 0 5ae 6
:3 0 73 :7 0 aba
ab9 :3 0 13 :3 0
6 :3 0 abc abe
0 af5 ab7 abf
:2 0 5b4 :2 0 5b2
3d :3 0 ac2 :7 0
ac5 ac3 0 af3
0 14 :6 0 14
:3 0 79 :3 0 73
:3 0 7a :4 0 7b
:4 0 ac7 acb ac6
acc 0 af1 14
:3 0 79 :3 0 14
:3 0 1b :4 0 7c
:4 0 5b8 acf ad3
ace ad4 0 af1
14 :3 0 79 :3 0
14 :3 0 7d :4 0
7e :4 0 5bc ad7
adb ad6 adc 0
af1 14 :3 0 79
:3 0 14 :3 0 3e
:4 0 7f :4 0 5c0
adf ae3 ade ae4
0 af1 14 :3 0
79 :3 0 14 :3 0
47 :4 0 80 :4 0
5c4 ae7 aeb ae6
aec 0 af1 13
:3 0 14 :3 0 aef
:2 0 af1 5c8 af4
:3 0 af4 5cf af4
af3 af1 af2 :6 0
af5 1 0 ab7
abf af4 be2 :2 0
11 :3 0 81 :a 0
b0f 3f :7 0 5d3
:2 0 5d1 6 :3 0
73 :7 0 afb afa
:3 0 13 :3 0 6
:3 0 afd aff 0
b0f af8 b00 :2 0
13 :3 0 72 :3 0
78 :3 0 73 :3 0
5d5 b04 b06 5d7
b03 b08 b09 :2 0
b0b 5d9 b0e :3 0
b0e 0 b0e b0d
b0b b0c :6 0 b0f
1 0 af8 b00
b0e be2 :2 0 11
:3 0 82 :a 0 b8a
40 :a 0 5db 84
:3 0 83 :7 0 b15
b14 :3 0 5df 2e97
0 5dd 84 :3 0
85 :7 0 b1a b18
b19 :2 0 88 :2 0
5e1 38 :3 0 39
:3 0 86 :7 0 b1f
b1d b1e :2 0 13
:3 0 6 :3 0 b21
b23 0 b8a b12
b24 :2 0 16 :2 0
5e7 6 :3 0 5e5
b27 b29 :6 0 89
:4 0 b2d b2a b2b
b88 0 87 :6 0
5ee 2f03 0 5ec
6 :3 0 15 :3 0
5e9 b2f b32 :6 0
b35 b33 0 b88
0 14 :6 0 83
:3 0 84 :3 0 b37
:7 0 b3a b38 0
b88 0 8a :6 0
18 :2 0 5f0 b3c
b3d :3 0 85 :3 0
18 :2 0 5f2 b40
b41 :3 0 86 :3 0
8a :3 0 8b :3 0
83 :3 0 85 :3 0
5f4 b45 b48 b44
b49 0 b4b 5f7
b54 8a :3 0 8c
:3 0 83 :3 0 85
:3 0 5f9 b4d b50
b4c b51 0 b53
5fc b55 b43 b4b
0 b56 0 b53
0 b56 5fe 0
b57 601 b5c 8a
:3 0 83 :3 0 b58
b59 0 b5b 603
b5d b42 b57 0
b5e 0 b5b 0
b5e 605 0 b7b
14 :3 0 8d :3 0
8a :3 0 8e :4 0
87 :3 0 608 b60
b64 b5f b65 0
b7b 8f :3 0 14
:3 0 62 :2 0 62
:2 0 60c b67 b6b
90 :2 0 91 :4 0
612 b6d b6f :3 0
14 :3 0 5c :4 0
19 :2 0 14 :3 0
615 b73 b75 :3 0
b71 b76 0 b78
618 b79 b70 b78
0 b7a 61a 0
b7b 61c b80 14
:4 0 b7c b7d 0
b7f 620 b81 b3e
b7b 0 b82 0
b7f 0 b82 622
0 b86 13 :3 0
14 :3 0 b84 :2 0
b86 625 b89 :3 0
b89 628 b89 b88
b86 b87 :6 0 b8a
1 0 b12 b24
b89 be2 :2 0 11
:3 0 92 :a 0 bba
41 :7 0 62e :2 0
62c 94 :3 0 93
:7 0 b90 b8f :3 0
13 :3 0 6 :3 0
b92 b94 0 bba
b8d b95 :2 0 93
:3 0 18 :2 0 630
b98 b99 :3 0 13
:3 0 8d :3 0 93
:3 0 95 :4 0 632
b9c b9f 19 :2 0
96 :4 0 635 ba1
ba3 :3 0 19 :2 0
8d :3 0 93 :3 0
97 :4 0 638 ba6
ba9 63b ba5 bab
:3 0 bac :2 0 bae
63e bb3 13 :4 0
bb0 :2 0 bb2 640
bb4 b9a bae 0
bb5 0 bb2 0
bb5 642 0 bb6
645 bb9 :3 0 bb9
0 bb9 bb8 bb6
bb7 :6 0 bba 1
0 b8d b95 bb9
be2 :2 0 11 :3 0
98 :a 0 bdb 42
:7 0 649 :2 0 647
84 :3 0 83 :7 0
bc0 bbf :3 0 13
:3 0 6 :3 0 bc2
bc4 0 bdb bbd
bc5 :2 0 13 :3 0
3 :3 0 82 :3 0
bc8 bc9 0 83
:3 0 83 :3 0 bcb
bcc 85 :3 0 5c
:2 0 bce bcf 86
:3 0 39 :3 0 bd1
bd2 64b bca bd4
bd5 :2 0 bd7 64f
bda :3 0 bda 0
bda bd9 bd7 bd8
:6 0 bdb 1 0
bbd bc5 bda be2
:3 0 be0 0 be0
:3 0 be0 be2 bde
bdf :6 0 be3 :2 0
3 :3 0 651 0
3 be0 be6 :3 0
be5 be3 be7 :8 0

68e
4
:3 0 1 5 1
8 1 e 1
16 1 19 1
1f 1 27 1
2a 1 30 1
38 1 3b 1
41 1 4a 1
4e 1 52 3
4d 51 55 2
5e 5d 1 5b
1 66 2 6b
6d 2 6f 71
2 73 75 1
78 1 7b 2
80 82 2 84
86 2 88 8a
1 8d 2 90
8f 1 92 2
97 99 2 9b
9d 2 9f a1
1 a4 1 a7
2 ac ae 2
b0 b2 2 b4
b6 1 b9 2
bc bb 1 be
2 c3 c5 2
c7 c9 2 cb
cd 1 d0 1
d3 2 d8 da
2 dc de 2
e0 e2 1 e5
2 e8 e7 2
eb ed 6 65
91 bd e9 f0
f3 1 61 1
fb 1 101 1
105 3 100 104
108 1 10c 1
111 1 115 1
117 1 118 1
120 1 126 1
12a 1 12e 4
125 129 12d 131
1 135 1 139
2 13e 140 2
142 144 1 146
1 14a 1 14d
1 151 2 153
154 1 155 1
157 1 158 1
160 1 166 1
16b 3 165 16a
16e 1 172 1
176 2 17b 17d
2 17f 181 1
183 1 187 1
18a 1 18e 2
190 191 1 192
1 194 1 195
1 19d 1 1a3
2 1a2 1a6 2
1ab 1ad 1 1b0
1 1b8 1 1be
2 1bd 1c1 2
1c6 1c8 2 1ca
1cc 1 1cf 1
1d7 1 1dc 1
1e2 1 1ea 1
1f0 1 1f5 1
1fa 4 1ef 1f4
1f9 1fe 3 204
205 206 1 209
1 211 1 216
1 21a 1 222
1 228 1 22c
1 230 4 227
22b 22f 234 1
238 1 23d 2
244 246 2 243
248 1 251 1
256 1 258 1
25c 2 262 264
2 266 268 2
26a 26c 2 26e
270 2 261 272
1 279 4 259
25f 274 27c 2
282 283 1 285
1 287 2 28a
28b 5 24a 24f
27f 288 28d 2
23b 240 1 295
1 29b 1 29f
1 2a3 1 2a7
5 29a 29e 2a2
2a6 2ab 1 2af
1 2b4 2 2b9
2bb 2 2bd 2bf
1 2c2 1 2c6
2 2c8 2c9 4
2ce 2d1 2d4 2d7
2 2ca 2d9 1
2b2 1 2e1 1
2e7 1 2eb 3
2e6 2ea 2ef 2
2f5 2f7 2 2f4
2f9 2 2fe 2ff
1 301 1 303
2 306 307 3
2fb 304 309 1
311 1 317 1
31b 1 31f 4
316 31a 31e 323
1 327 1 32c
2 331 333 2
335 337 1 33a
1 33e 2 340
341 3 346 349
34c 2 342 34e
1 32a 1 356
1 35c 2 35b
35f 2 365 367
2 369 36b 2
364 36d 1 36f
1 377 1 37d
1 381 3 37c
380 384 1 388
2 38e 390 2
392 394 2 396
398 2 39a 39c
2 38d 39e 1
3a0 2 3a4 3a6
2 3a8 3aa 2
3a3 3ac 1 3ae
2 3b0 3b1 1
3b2 1 3ba 1
3c0 2 3bf 3c3
2 3c8 3c9 1
3cb 1 3d4 1
3d9 1 3e3 1
3e6 1 3ee 1
3f4 1 3fa 3
3f3 3f9 3fe 1
402 2 40c 40f
4 414 415 416
417 1 420 1
422 3 411 41a
425 1 407 1
42d 1 433 1
439 3 432 438
43d 1 441 1
447 1 44d 1
453 2 45c 45f
1 46a 1 470
8 465 466 46c
46d 46e 472 473
474 2 461 476
4 445 44b 451
457 1 47e 1
484 2 483 487
2 490 492 1
495 2 49d 4a1
2 4a4 4a9 1
497 1 4ac 1
4af 1 4b8 1
4be 2 4bd 4c1
2 4ca 4cc 2
4c8 4cf 1 4d1
1 4d9 1 4de
2 4e6 4eb 1
4f3 1 4f9 1
4fe 1 503 4
4f8 4fd 502 507
3 514 515 516
2 50f 519 1
521 1 526 2
52f 533 2 536
53b 1 543 1
549 1 54d 1
551 4 548 54c
550 555 1 559
1 55e 2 565
567 2 564 569
1 572 1 577
1 579 1 57d
2 583 585 2
587 589 2 58b
58d 2 58f 591
2 582 593 1
59a 4 57a 580
595 59d 2 5a3
5a4 1 5a6 1
5a8 2 5ab 5ac
5 56b 570 5a0
5a9 5ae 2 55c
561 1 5b6 1
5bc 1 5c0 1
5c4 1 5c8 5
5bb 5bf 5c3 5c7
5cc 1 5d0 1
5d5 2 5da 5dc
2 5de 5e0 1
5e3 1 5e7 2
5e9 5ea 4 5ef
5f2 5f5 5f8 2
5eb 5fa 1 5d3
1 602 1 608
1 60c 3 607
60b 610 2 616
618 2 615 61a
2 61f 620 1
622 1 624 2
627 628 3 61c
625 62a 1 632
1 638 1 63c
1 640 4 637
63b 63f 644 1
648 1 64d 2
652 654 2 656
658 1 65b 1
65f 2 661 662
3 667 66a 66d
2 663 66f 1
64b 1 677 1
67d 2 67c 680
2 686 688 2
68a 68c 2 685
68e 1 690 1
698 1 69e 1
6a2 3 69d 6a1
6a5 1 6a9 2
6af 6b1 2 6b3
6b5 2 6b7 6b9
2 6bb 6bd 2
6ae 6bf 1 6c1
2 6c5 6c7 2
6c9 6cb 2 6c4
6cd 1 6cf 2
6d1 6d2 1 6d3
1 6db 1 6e1
2 6e0 6e4 2
6e9 6ea 1 6ec
1 6f5 1 6fa
1 706 1 709
1 711 1 717
1 71d 3 716
71c 721 1 725
3 731 734 737
1 739 1 72a
1 741 1 747
1 74d 3 746
74c 751 3 75a
75d 760 1 762
2 770 774 1
77c 1 780 2
77f 783 1 788
1 78e 2 792
794 1 797 1
79b 1 7a1 1
7a8 2 7a5 7ac
1 7b1 2 7af
7b7 1 799 1
7ba 1 7bd 1
7c6 1 7ca 2
7c9 7cd 2 7d6
7d8 2 7d4 7db
1 7dd 2 7ec
7ee 1 7f3 1
7fb 4 7f1 7f9
801 804 1 80d
1 812 1 817
3 811 816 81b
2 822 824 1
829 1 831 3
837 838 839 4
827 82f 83c 83f
1 847 1 84a
1 84f 1 855
1 85c 2 859
860 1 865 2
863 86b 1 873
1 877 1 87b
1 87f 4 876
87a 87e 883 1
887 1 88c 2
893 895 2 892
897 1 8a0 1
8a5 1 8a7 1
8ab 2 8b1 8b3
2 8b5 8b7 2
8b9 8bb 2 8bd
8bf 2 8b0 8c1
1 8c8 4 8a8
8ae 8c3 8cb 2
8d1 8d2 1 8d4
1 8d6 2 8d9
8da 5 899 89e
8ce 8d7 8dc 2
88a 88f 1 8e4
1 8e8 1 8ec
1 8f0 1 8f4
5 8e7 8eb 8ef
8f3 8f8 1 8fc
1 901 2 906
908 2 90a 90c
1 90f 1 913
2 915 916 4
91b 91e 921 924
2 917 926 1
8ff 1 92e 1
932 1 936 3
931 935 93a 2
940 942 2 93f
944 2 949 94a
1 94c 1 94e
2 951 952 3
946 94f 954 1
95c 1 960 1
964 1 968 4
95f 963 967 96c
1 970 1 975
2 97a 97c 2
97e 980 1 983
1 987 2 989
98a 3 98f 992
995 2 98b 997
1 973 1 99f
1 9a3 2 9a2
9a6 2 9ac 9ae
2 9b0 9b2 2
9ab 9b4 1 9b6
1 9be 1 9c2
1 9c6 3 9c1
9c5 9c9 1 9cd
2 9d3 9d5 2
9d7 9d9 2 9db
9dd 2 9df 9e1
2 9d2 9e3 1
9e5 2 9e9 9eb
2 9ed 9ef 2
9e8 9f1 1 9f3
2 9f5 9f6 1
9f7 1 9ff 1
a03 2 a02 a06
2 a0b a0c 1
a0e 1 a17 1
a1a 1 a25 1
a29 1 a2c 1
a34 1 a38 1
a3e 3 a37 a3d
a42 1 a46 1
a50 3 a55 a58
a5b 1 a5d 1
a4b 1 a65 1
a69 1 a6f 3
a68 a6e a73 1
a7a 3 a7f a82
a85 1 a87 1
a90 1 a93 1
a99 1 aa0 3
aa2 aa3 aa4 1
aa7 1 aab 2
aad aae 1 aaf
1 ab8 1 abb
1 ac1 3 ac8
ac9 aca 3 ad0
ad1 ad2 3 ad8
ad9 ada 3 ae0
ae1 ae2 3 ae8
ae9 aea 6 acd
ad5 add ae5 aed
af0 1 ac4 1
af9 1 afc 1
b05 1 b07 1
b0a 1 b13 1
b17 1 b1c 3
b16 b1b b20 1
b28 1 b26 2
b31 b30 1 b2e
1 b36 1 b3b
1 b3f 2 b46
b47 1 b4a 2
b4e b4f 1 b52
2 b54 b55 1
b56 1 b5a 2
b5c b5d 3 b61
b62 b63 3 b68
b69 b6a 1 b6e
2 b6c b6e 2
b72 b74 1 b77
1 b79 3 b5e
b66 b7a 1 b7e
2 b80 b81 2
b82 b85 3 b2c
b34 b39 1 b8e
1 b91 1 b97
2 b9d b9e 2
ba0 ba2 2 ba7
ba8 2 ba4 baa
1 bad 1 bb1
2 bb3 bb4 1
bb5 1 bbe 1
bc1 3 bcd bd0
bd3 1 bd6 3c
13 24 35 46
f8 11d 15d 19a
1b5 1d4 1e7 20e
21f 292 2de 30e
353 374 3b7 3d0
3eb 42a 47b 4b5
4d6 4f0 51e 540
5b3 5ff 62f 674
695 6d8 6f1 70e
73e 767 779 7c3
7e2 809 844 870
8e1 92b 959 99c
9bb 9fc a13 a31
a62 a8c ab4 af5
b0f b8a bba bdb

1
4
0 
be6
0
1
50
42
e4
0 1 1 1 1 1 1 1
1 1 1 1 1 1 1 f
1 1 1 1 1 1 1 1
1 1 1a 1 1 1 1 1
20 1 1 1 1 1 1 1
1 1 1 1 2c 1 1 1
1 1 32 1 1 1 1 1
1 1 1 1 1 1 1 1
1 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0

15 1 3
92d 1 35
872 1 32
601 1 23
542 1 20
2e0 1 12
221 1 f
441 19 0
970 36 0
8fc 34 0
648 24 0
5d0 22 0
327 13 0
2af 11 0
a03 39 0
9c2 38 0
960 36 0
8e8 34 0
6e1 27 0
69e 26 0
638 24 0
5bc 22 0
3c0 16 0
37d 15 0
317 13 0
29b 11 0
126 8 0
af8 1 3f
453 19 0
80c 1 30
4f2 1 1e
1e9 1 d
b8e 41 0
887 32 0
559 20 0
238 f 0
af9 3f 0
ab8 3e 0
a90 3d 0
b26 40 0
15f 1 9
b12 1 40
b2e 40 0
ac1 3e 0
88c 32 0
55e 20 0
23d f 0
5b 6 0
4 1 2
a16 1 3a
6f4 1 28
3d3 1 17
77b 1 2c
47d 1 1a
19c 1 a
fa 1 7
a65 3c 0
a34 3b 0
a17 3a 0
9ff 39 0
9be 38 0
99f 37 0
95c 36 0
92e 35 0
8e4 34 0
873 32 0
847 31 0
7c6 2e 0
77c 2c 0
b36 40 0
a69 3c 0
a38 3b 0
747 2a 0
717 29 0
433 19 0
3f4 18 0
a33 1 3b
710 1 29
3ed 1 18
741 2a 0
711 29 0
6f5 28 0
6db 27 0
698 26 0
677 25 0
632 24 0
602 23 0
5b6 22 0
543 20 0
521 1f 0
4f3 1e 0
4d9 1d 0
4b8 1c 0
47e 1a 0
42d 19 0
3ee 18 0
3d4 17 0
3ba 16 0
377 15 0
356 14 0
311 13 0
2e1 12 0
295 11 0
222 f 0
211 e 0
1ea d 0
1d7 c 0
1b8 b 0
19d a 0
7e5 1 2f
4d8 1 1d
1d6 1 c
447 19 0
44d 19 0
7c5 1 2e
4b7 1 1c
1b7 1 b
37 1 5
9fe 1 39
95b 1 36
8e3 1 34
6da 1 27
631 1 24
5b5 1 22
3b9 1 16
310 1 13
294 1 11
11f 1 8
5 2 0
a64 1 3c
740 1 2a
42c 1 19
8f0 34 0
87b 32 0
5c4 22 0
54d 20 0
2a3 11 0
22c f 0
160 9 0
120 8 0
fb 7 0
80d 30 0
4f9 1e 0
1f0 d 0
4a 6 0
16 3 0
b8d 1 41
a46 3b 0
725 29 0
402 18 0
9bd 1 38
697 1 26
376 1 15
26 1 4
b1c 40 0
ab7 1 3e
a8f 1 3d
769 1 2b
49 1 6
b17 40 0
812 30 0
4fe 1e 0
1f5 d 0
4e 6 0
27 4 0
bbe 42 0
b13 40 0
9c6 38 0
9a3 37 0
964 36 0
932 35 0
8ec 34 0
877 32 0
6a2 26 0
67d 25 0
63c 24 0
608 23 0
5c0 22 0
549 20 0
381 15 0
35c 14 0
31b 13 0
2e7 12 0
29f 11 0
228 f 0
a6f 3c 0
a3e 3b 0
74d 2a 0
71d 29 0
439 19 0
3fa 18 0
bbd 1 42
99e 1 37
676 1 25
355 1 14
166 9 0
12a 8 0
101 7 0
7ca 2e 0
780 2c 0
4be 1c 0
484 1a 0
1be b 0
1a3 a 0
968 36 0
936 35 0
8f4 34 0
87f 32 0
640 24 0
60c 23 0
5c8 22 0
551 20 0
31f 13 0
2eb 12 0
2a7 11 0
230 f 0
3 0 1
846 1 31
520 1 1f
210 1 e
817 30 0
503 1e 0
1fa d 0
52 6 0
38 5 0
16b 9 0
12e 8 0
105 7 0
0

/
